@@ -19,15 +19,16 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodeblock.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/collection.h>
 #include <ccode/valaccodeblock.h>
 
 struct _ValaCCodeBlockPrivate {
 	gboolean _suppress_newline;
-	GList* statements;
+	GeeList* statements;
 };
 #define VALA_CCODE_BLOCK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_BLOCK, ValaCCodeBlockPrivate))
 enum  {
@@ -46,7 +47,7 @@ void vala_ccode_block_prepend_statement (ValaCCodeBlock* self, ValaCCodeNode* st
 {
 	g_return_if_fail (VALA_IS_CCODE_BLOCK (self));
 	g_return_if_fail (VALA_IS_CCODE_NODE (statement));
-	self->priv->statements = g_list_prepend (self->priv->statements, g_object_ref (statement));
+	gee_list_insert (self->priv->statements, 0, statement);
 }
 
 
@@ -58,41 +59,45 @@ void vala_ccode_block_add_statement (ValaCCodeBlock* self, ValaCCodeNode* statem
 	g_return_if_fail (VALA_IS_CCODE_BLOCK (self));
 	g_return_if_fail (VALA_IS_CCODE_NODE (statement));
 	/* allow generic nodes to include comments */
-	self->priv->statements = g_list_append (self->priv->statements, g_object_ref (statement));
+	gee_collection_add (GEE_COLLECTION (self->priv->statements), statement);
 }
 
 
 static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeBlock * self;
-	self = VALA_CCODE_BLOCK (base);
+	self = ((ValaCCodeBlock*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_begin_block (writer);
 	{
-		GList* __temp0;
-		GList* statement_it;
-		__temp0 = NULL;
-		__temp0 = self->priv->statements;
-		for (statement_it = __temp0; statement_it != NULL; statement_it = statement_it->next) {
+		GeeList* statement_collection;
+		GeeIterator* statement_it;
+		statement_collection = self->priv->statements;
+		statement_it = gee_iterable_iterator (GEE_ITERABLE (statement_collection));
+		while (gee_iterator_next (statement_it)) {
 			ValaCCodeNode* statement;
-			statement = statement_it->data;
+			statement = gee_iterator_get (statement_it);
 			{
 				vala_ccode_node_write_declaration (statement, writer);
+				(statement == NULL ? NULL : (statement = (g_object_unref (statement), NULL)));
 			}
 		}
+		(statement_it == NULL ? NULL : (statement_it = (g_object_unref (statement_it), NULL)));
 	}
 	{
-		GList* __temp1;
-		GList* statement_it;
-		__temp1 = NULL;
-		__temp1 = self->priv->statements;
-		for (statement_it = __temp1; statement_it != NULL; statement_it = statement_it->next) {
+		GeeList* statement_collection;
+		GeeIterator* statement_it;
+		statement_collection = self->priv->statements;
+		statement_it = gee_iterable_iterator (GEE_ITERABLE (statement_collection));
+		while (gee_iterator_next (statement_it)) {
 			ValaCCodeNode* statement;
-			statement = statement_it->data;
+			statement = gee_iterator_get (statement_it);
 			{
 				vala_ccode_node_write (statement, writer);
+				(statement == NULL ? NULL : (statement = (g_object_unref (statement), NULL)));
 			}
 		}
+		(statement_it == NULL ? NULL : (statement_it = (g_object_unref (statement_it), NULL)));
 	}
 	vala_ccode_writer_write_end_block (writer);
 	if (!vala_ccode_block_get_suppress_newline (self)) {
@@ -123,6 +128,9 @@ static void vala_ccode_block_get_property (GObject * object, guint property_id,
 		case VALA_CCODE_BLOCK_SUPPRESS_NEWLINE:
 		g_value_set_boolean (value, vala_ccode_block_get_suppress_newline (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -135,6 +143,9 @@ static void vala_ccode_block_set_property (GObject * object, guint property_id,
 		case VALA_CCODE_BLOCK_SUPPRESS_NEWLINE:
 		vala_ccode_block_set_suppress_newline (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -154,6 +165,7 @@ static void vala_ccode_block_class_init (ValaCCodeBlockClass * klass)
 static void vala_ccode_block_init (ValaCCodeBlock * self)
 {
 	self->priv = VALA_CCODE_BLOCK_GET_PRIVATE (self);
+	self->priv->statements = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
@@ -163,14 +175,14 @@ static void vala_ccode_block_dispose (GObject * obj)
 	ValaCCodeBlockClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_CCODE_BLOCK (obj);
-	(self->priv->statements == NULL ? NULL : (self->priv->statements = (g_list_foreach (self->priv->statements, (GFunc) g_object_unref, NULL), g_list_free (self->priv->statements), NULL)));
+	(self->priv->statements == NULL ? NULL : (self->priv->statements = (g_object_unref (self->priv->statements), NULL)));
 	klass = VALA_CCODE_BLOCK_CLASS (g_type_class_peek (VALA_TYPE_CCODE_BLOCK));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_block_get_type ()
+GType vala_ccode_block_get_type (void)
 {
 	static GType vala_ccode_block_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_block_type_id == 0)) {
