@@ -19,10 +19,11 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodecasestatement.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/collection.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodecasestatement.h>
@@ -30,7 +31,7 @@
 
 struct _ValaCCodeCaseStatementPrivate {
 	ValaCCodeExpression* _expression;
-	GList* statements;
+	GeeList* statements;
 };
 #define VALA_CCODE_CASE_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_CASE_STATEMENT, ValaCCodeCaseStatementPrivate))
 enum  {
@@ -42,16 +43,12 @@ static gpointer vala_ccode_case_statement_parent_class = NULL;
 static void vala_ccode_case_statement_dispose (GObject * obj);
 
 
-ValaCCodeCaseStatement* vala_ccode_case_statement_new (ValaCCodeExpression* expr)
+ValaCCodeCaseStatement* vala_ccode_case_statement_new (ValaCCodeExpression* expression)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaCCodeCaseStatement * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	(__params_it->name = "expression", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
-	self = g_object_newv (VALA_TYPE_CCODE_CASE_STATEMENT, __params_it - __params, __params);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expression), NULL);
+	self = g_object_newv (VALA_TYPE_CCODE_CASE_STATEMENT, 0, NULL);
+	vala_ccode_case_statement_set_expression (self, expression);
 	return self;
 }
 
@@ -65,14 +62,14 @@ void vala_ccode_case_statement_add_statement (ValaCCodeCaseStatement* self, Vala
 {
 	g_return_if_fail (VALA_IS_CCODE_CASE_STATEMENT (self));
 	g_return_if_fail (VALA_IS_CCODE_STATEMENT (stmt));
-	self->priv->statements = g_list_append (self->priv->statements, g_object_ref (stmt));
+	gee_collection_add (GEE_COLLECTION (self->priv->statements), stmt);
 }
 
 
 static void vala_ccode_case_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeCaseStatement * self;
-	self = VALA_CCODE_CASE_STATEMENT (base);
+	self = ((ValaCCodeCaseStatement*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	vala_ccode_writer_write_string (writer, "case ");
@@ -80,17 +77,19 @@ static void vala_ccode_case_statement_real_write (ValaCCodeNode* base, ValaCCode
 	vala_ccode_writer_write_string (writer, ":");
 	vala_ccode_writer_write_newline (writer);
 	{
-		GList* __temp0;
-		GList* stmt_it;
-		__temp0 = NULL;
-		__temp0 = self->priv->statements;
-		for (stmt_it = __temp0; stmt_it != NULL; stmt_it = stmt_it->next) {
+		GeeList* stmt_collection;
+		GeeIterator* stmt_it;
+		stmt_collection = self->priv->statements;
+		stmt_it = gee_iterable_iterator (GEE_ITERABLE (stmt_collection));
+		while (gee_iterator_next (stmt_it)) {
 			ValaCCodeStatement* stmt;
-			stmt = stmt_it->data;
+			stmt = gee_iterator_get (stmt_it);
 			{
 				vala_ccode_node_write (VALA_CCODE_NODE (stmt), writer);
+				(stmt == NULL ? NULL : (stmt = (g_object_unref (stmt), NULL)));
 			}
 		}
+		(stmt_it == NULL ? NULL : (stmt_it = (g_object_unref (stmt_it), NULL)));
 	}
 }
 
@@ -104,10 +103,10 @@ ValaCCodeExpression* vala_ccode_case_statement_get_expression (ValaCCodeCaseStat
 
 void vala_ccode_case_statement_set_expression (ValaCCodeCaseStatement* self, ValaCCodeExpression* value)
 {
-	ValaCCodeExpression* __temp2;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_CASE_STATEMENT (self));
-	__temp2 = NULL;
-	self->priv->_expression = (__temp2 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), __temp2);
+	_tmp1 = NULL;
+	self->priv->_expression = (_tmp1 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp1);
 }
 
 
@@ -119,6 +118,9 @@ static void vala_ccode_case_statement_get_property (GObject * object, guint prop
 		case VALA_CCODE_CASE_STATEMENT_EXPRESSION:
 		g_value_set_object (value, vala_ccode_case_statement_get_expression (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -131,6 +133,9 @@ static void vala_ccode_case_statement_set_property (GObject * object, guint prop
 		case VALA_CCODE_CASE_STATEMENT_EXPRESSION:
 		vala_ccode_case_statement_set_expression (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -143,13 +148,14 @@ static void vala_ccode_case_statement_class_init (ValaCCodeCaseStatementClass *
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_case_statement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_case_statement_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_case_statement_real_write;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_CASE_STATEMENT_EXPRESSION, g_param_spec_object ("expression", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_CASE_STATEMENT_EXPRESSION, g_param_spec_object ("expression", "foo", "bar", VALA_TYPE_CCODE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_ccode_case_statement_init (ValaCCodeCaseStatement * self)
 {
 	self->priv = VALA_CCODE_CASE_STATEMENT_GET_PRIVATE (self);
+	self->priv->statements = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
@@ -160,14 +166,14 @@ static void vala_ccode_case_statement_dispose (GObject * obj)
 	GObjectClass * parent_class;
 	self = VALA_CCODE_CASE_STATEMENT (obj);
 	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
-	(self->priv->statements == NULL ? NULL : (self->priv->statements = (g_list_foreach (self->priv->statements, (GFunc) g_object_unref, NULL), g_list_free (self->priv->statements), NULL)));
+	(self->priv->statements == NULL ? NULL : (self->priv->statements = (g_object_unref (self->priv->statements), NULL)));
 	klass = VALA_CCODE_CASE_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_CASE_STATEMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_case_statement_get_type ()
+GType vala_ccode_case_statement_get_type (void)
 {
 	static GType vala_ccode_case_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_case_statement_type_id == 0)) {
