@@ -73,10 +73,10 @@ char* vala_ccode_comment_get_text (ValaCCodeComment* self)
 
 void vala_ccode_comment_set_text (ValaCCodeComment* self, const char* value)
 {
-	char* __temp1;
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_COMMENT (self));
-	__temp1 = NULL;
-	self->priv->_text = (__temp1 = g_strdup (value), (self->priv->_text = (g_free (self->priv->_text), NULL)), __temp1);
+	_tmp1 = NULL;
+	self->priv->_text = (_tmp1 = g_strdup (value), (self->priv->_text = (g_free (self->priv->_text), NULL)), _tmp1);
 }
 
 
@@ -88,6 +88,9 @@ static void vala_ccode_comment_get_property (GObject * object, guint property_id
 		case VALA_CCODE_COMMENT_TEXT:
 		g_value_set_string (value, vala_ccode_comment_get_text (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -100,6 +103,9 @@ static void vala_ccode_comment_set_property (GObject * object, guint property_id
 		case VALA_CCODE_COMMENT_TEXT:
 		vala_ccode_comment_set_text (self, g_value_get_string (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
