@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodedostatement.h"
 #include <stdlib.h>
@@ -37,7 +35,7 @@ struct _ValaCCodeDoStatementPrivate {
 enum  {
 	VALA_CCODE_DO_STATEMENT_DUMMY_PROPERTY,
 	VALA_CCODE_DO_STATEMENT_BODY,
-	VALA_CCODE_DO_STATEMENT_CONDITION,
+	VALA_CCODE_DO_STATEMENT_CONDITION
 };
 static void vala_ccode_do_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_do_statement_parent_class = NULL;
@@ -46,28 +44,39 @@ static void vala_ccode_do_statement_dispose (GObject * obj);
 
 ValaCCodeDoStatement* vala_ccode_do_statement_new (ValaCCodeStatement* stmt, ValaCCodeExpression* cond)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaCCodeDoStatement * self;
 	g_return_val_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt), NULL);
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
-	(__params_it->name = "body", g_value_init (&__params_it->value, VALA_TYPE_CCODE_STATEMENT), g_value_set_object (&__params_it->value, stmt), __params_it++);
+	__params = g_new0 (GParameter, 1);
+	__params_it = __params;
 	(__params_it->name = "condition", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, cond), __params_it++);
-	ValaCCodeDoStatement * self = g_object_newv (VALA_TYPE_CCODE_DO_STATEMENT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_DO_STATEMENT, __params_it - __params, __params);
+	vala_ccode_do_statement_set_body (self, stmt);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
 
 static void vala_ccode_do_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeDoStatement * self = VALA_CCODE_DO_STATEMENT (base);
+	ValaCCodeDoStatement * self;
+	self = ((ValaCCodeDoStatement*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	vala_ccode_writer_write_string (writer, "do");
 	/* while shouldn't be on a separate line */
 	if (VALA_IS_CCODE_BLOCK (vala_ccode_do_statement_get_body (self))) {
-		ValaCCodeBlock* __temp0 = NULL;
-		ValaCCodeBlock* cblock = (__temp0 = VALA_CCODE_BLOCK (vala_ccode_do_statement_get_body (self)), (__temp0 == NULL ? NULL : g_object_ref (__temp0)));
-		(vala_ccode_block_set_suppress_newline (cblock, TRUE), vala_ccode_block_get_suppress_newline (cblock));
+		ValaCCodeBlock* _tmp0;
+		ValaCCodeBlock* cblock;
+		_tmp0 = NULL;
+		cblock = (_tmp0 = VALA_CCODE_BLOCK (vala_ccode_do_statement_get_body (self)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+		vala_ccode_block_set_suppress_newline (cblock, TRUE);
 		(cblock == NULL ? NULL : (cblock = (g_object_unref (cblock), NULL)));
 	}
 	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_do_statement_get_body (self)), writer);
@@ -86,10 +95,12 @@ ValaCCodeStatement* vala_ccode_do_statement_get_body (ValaCCodeDoStatement* self
 
 void vala_ccode_do_statement_set_body (ValaCCodeDoStatement* self, ValaCCodeStatement* value)
 {
+	ValaCCodeStatement* _tmp2;
+	ValaCCodeStatement* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_DO_STATEMENT (self));
-	ValaCCodeStatement* __temp3 = NULL;
-	ValaCCodeStatement* __temp2 = NULL;
-	self->priv->_body = (__temp3 = (__temp2 = value, (__temp2 == NULL ? NULL : g_object_ref (__temp2))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp3);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
 }
 
 
@@ -102,15 +113,17 @@ ValaCCodeExpression* vala_ccode_do_statement_get_condition (ValaCCodeDoStatement
 
 void vala_ccode_do_statement_set_condition (ValaCCodeDoStatement* self, ValaCCodeExpression* value)
 {
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_DO_STATEMENT (self));
-	ValaCCodeExpression* __temp5 = NULL;
-	self->priv->_condition = (__temp5 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), __temp5);
+	_tmp1 = NULL;
+	self->priv->_condition = (_tmp1 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp1);
 }
 
 
 static void vala_ccode_do_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeDoStatement * self = VALA_CCODE_DO_STATEMENT (object);
+	ValaCCodeDoStatement * self;
+	self = VALA_CCODE_DO_STATEMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_DO_STATEMENT_BODY:
 		g_value_set_object (value, vala_ccode_do_statement_get_body (self));
@@ -118,13 +131,17 @@ static void vala_ccode_do_statement_get_property (GObject * object, guint proper
 		case VALA_CCODE_DO_STATEMENT_CONDITION:
 		g_value_set_object (value, vala_ccode_do_statement_get_condition (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
 static void vala_ccode_do_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeDoStatement * self = VALA_CCODE_DO_STATEMENT (object);
+	ValaCCodeDoStatement * self;
+	self = VALA_CCODE_DO_STATEMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_DO_STATEMENT_BODY:
 		vala_ccode_do_statement_set_body (self, g_value_get_object (value));
@@ -132,6 +149,9 @@ static void vala_ccode_do_statement_set_property (GObject * object, guint proper
 		case VALA_CCODE_DO_STATEMENT_CONDITION:
 		vala_ccode_do_statement_set_condition (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -157,18 +177,19 @@ static void vala_ccode_do_statement_init (ValaCCodeDoStatement * self)
 
 static void vala_ccode_do_statement_dispose (GObject * obj)
 {
-	ValaCCodeDoStatement * self = VALA_CCODE_DO_STATEMENT (obj);
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
+	ValaCCodeDoStatement * self;
 	ValaCCodeDoStatementClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_DO_STATEMENT (obj);
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
+	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
 	klass = VALA_CCODE_DO_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_DO_STATEMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_do_statement_get_type ()
+GType vala_ccode_do_statement_get_type (void)
 {
 	static GType vala_ccode_do_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_do_statement_type_id == 0)) {
