@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodeexpressionstatement.h"
 #include <stdlib.h>
@@ -34,7 +32,7 @@ struct _ValaCCodeExpressionStatementPrivate {
 #define VALA_CCODE_EXPRESSION_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_EXPRESSION_STATEMENT, ValaCCodeExpressionStatementPrivate))
 enum  {
 	VALA_CCODE_EXPRESSION_STATEMENT_DUMMY_PROPERTY,
-	VALA_CCODE_EXPRESSION_STATEMENT_EXPRESSION,
+	VALA_CCODE_EXPRESSION_STATEMENT_EXPRESSION
 };
 static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_expression_statement_parent_class = NULL;
@@ -43,18 +41,27 @@ static void vala_ccode_expression_statement_dispose (GObject * obj);
 
 ValaCCodeExpressionStatement* vala_ccode_expression_statement_new (ValaCCodeExpression* expr)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaCCodeExpressionStatement * self;
 	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
-	GParameter * __params = g_new0 (GParameter, 1);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 1);
+	__params_it = __params;
 	(__params_it->name = "expression", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
-	ValaCCodeExpressionStatement * self = g_object_newv (VALA_TYPE_CCODE_EXPRESSION_STATEMENT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_EXPRESSION_STATEMENT, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
 
 static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeExpressionStatement * self = VALA_CCODE_EXPRESSION_STATEMENT (base);
+	ValaCCodeExpressionStatement * self;
+	self = ((ValaCCodeExpressionStatement*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	if (vala_ccode_expression_statement_get_expression (self) != NULL) {
@@ -74,30 +81,39 @@ ValaCCodeExpression* vala_ccode_expression_statement_get_expression (ValaCCodeEx
 
 void vala_ccode_expression_statement_set_expression (ValaCCodeExpressionStatement* self, ValaCCodeExpression* value)
 {
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_EXPRESSION_STATEMENT (self));
-	ValaCCodeExpression* __temp1 = NULL;
-	self->priv->_expression = (__temp1 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), __temp1);
+	_tmp1 = NULL;
+	self->priv->_expression = (_tmp1 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp1);
 }
 
 
 static void vala_ccode_expression_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeExpressionStatement * self = VALA_CCODE_EXPRESSION_STATEMENT (object);
+	ValaCCodeExpressionStatement * self;
+	self = VALA_CCODE_EXPRESSION_STATEMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_EXPRESSION_STATEMENT_EXPRESSION:
 		g_value_set_object (value, vala_ccode_expression_statement_get_expression (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
 static void vala_ccode_expression_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeExpressionStatement * self = VALA_CCODE_EXPRESSION_STATEMENT (object);
+	ValaCCodeExpressionStatement * self;
+	self = VALA_CCODE_EXPRESSION_STATEMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_EXPRESSION_STATEMENT_EXPRESSION:
 		vala_ccode_expression_statement_set_expression (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -122,17 +138,18 @@ static void vala_ccode_expression_statement_init (ValaCCodeExpressionStatement *
 
 static void vala_ccode_expression_statement_dispose (GObject * obj)
 {
-	ValaCCodeExpressionStatement * self = VALA_CCODE_EXPRESSION_STATEMENT (obj);
-	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
+	ValaCCodeExpressionStatement * self;
 	ValaCCodeExpressionStatementClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_EXPRESSION_STATEMENT (obj);
+	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
 	klass = VALA_CCODE_EXPRESSION_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_EXPRESSION_STATEMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_expression_statement_get_type ()
+GType vala_ccode_expression_statement_get_type (void)
 {
 	static GType vala_ccode_expression_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_expression_statement_type_id == 0)) {
