@@ -122,12 +122,12 @@ ValaCCodeExpression* vala_ccode_function_call_get_call (ValaCCodeFunctionCall* s
 
 void vala_ccode_function_call_set_call (ValaCCodeFunctionCall* self, ValaCCodeExpression* value)
 {
-	ValaCCodeExpression* __temp3;
-	ValaCCodeExpression* __temp2;
+	ValaCCodeExpression* _tmp2;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self));
-	__temp3 = NULL;
-	__temp2 = NULL;
-	self->priv->_call = (__temp3 = (__temp2 = value, (__temp2 == NULL ? NULL : g_object_ref (__temp2))), (self->priv->_call == NULL ? NULL : (self->priv->_call = (g_object_unref (self->priv->_call), NULL))), __temp3);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_call = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_call == NULL ? NULL : (self->priv->_call = (g_object_unref (self->priv->_call), NULL))), _tmp2);
 }
 
 
@@ -139,6 +139,9 @@ static void vala_ccode_function_call_get_property (GObject * object, guint prope
 		case VALA_CCODE_FUNCTION_CALL_CALL:
 		g_value_set_object (value, vala_ccode_function_call_get_call (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -151,6 +154,9 @@ static void vala_ccode_function_call_set_property (GObject * object, guint prope
 		case VALA_CCODE_FUNCTION_CALL_CALL:
 		vala_ccode_function_call_set_call (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
