@@ -89,10 +89,10 @@ char* vala_ccode_include_directive_get_filename (ValaCCodeIncludeDirective* self
 
 void vala_ccode_include_directive_set_filename (ValaCCodeIncludeDirective* self, const char* value)
 {
-	char* __temp1;
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_INCLUDE_DIRECTIVE (self));
-	__temp1 = NULL;
-	self->priv->_filename = (__temp1 = g_strdup (value), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), __temp1);
+	_tmp1 = NULL;
+	self->priv->_filename = (_tmp1 = g_strdup (value), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), _tmp1);
 }
 
 
@@ -121,6 +121,9 @@ static void vala_ccode_include_directive_get_property (GObject * object, guint p
 		case VALA_CCODE_INCLUDE_DIRECTIVE_LOCAL:
 		g_value_set_boolean (value, vala_ccode_include_directive_get_local (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -136,6 +139,9 @@ static void vala_ccode_include_directive_set_property (GObject * object, guint p
 		case VALA_CCODE_INCLUDE_DIRECTIVE_LOCAL:
 		vala_ccode_include_directive_set_local (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
