@@ -61,15 +61,15 @@ ValaCCodeLineDirective* vala_ccode_line_directive_new (const char* _filename, gi
 static void vala_ccode_line_directive_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeLineDirective * self;
-	char* __temp0;
+	char* _tmp0;
 	self = ((ValaCCodeLineDirective*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if (!vala_ccode_writer_get_bol (writer)) {
 		vala_ccode_writer_write_newline (writer);
 	}
-	__temp0 = NULL;
-	vala_ccode_writer_write_string (writer, (__temp0 = g_strdup_printf ("#line %d \"%s\"", vala_ccode_line_directive_get_line (self), vala_ccode_line_directive_get_filename (self))));
-	(__temp0 = (g_free (__temp0), NULL));
+	_tmp0 = NULL;
+	vala_ccode_writer_write_string (writer, (_tmp0 = g_strdup_printf ("#line %d \"%s\"", vala_ccode_line_directive_get_line (self), vala_ccode_line_directive_get_filename (self))));
+	(_tmp0 = (g_free (_tmp0), NULL));
 	vala_ccode_writer_write_newline (writer);
 }
 
@@ -83,10 +83,10 @@ char* vala_ccode_line_directive_get_filename (ValaCCodeLineDirective* self)
 
 void vala_ccode_line_directive_set_filename (ValaCCodeLineDirective* self, const char* value)
 {
-	char* __temp2;
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_LINE_DIRECTIVE (self));
-	__temp2 = NULL;
-	self->priv->_filename = (__temp2 = g_strdup (value), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), __temp2);
+	_tmp1 = NULL;
+	self->priv->_filename = (_tmp1 = g_strdup (value), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), _tmp1);
 }
 
 
@@ -115,6 +115,9 @@ static void vala_ccode_line_directive_get_property (GObject * object, guint prop
 		case VALA_CCODE_LINE_DIRECTIVE_LINE:
 		g_value_set_int (value, vala_ccode_line_directive_get_line (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -130,6 +133,9 @@ static void vala_ccode_line_directive_set_property (GObject * object, guint prop
 		case VALA_CCODE_LINE_DIRECTIVE_LINE:
 		vala_ccode_line_directive_set_line (self, g_value_get_int (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
