@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodemacroreplacement.h"
 #include <ccode/valaccodemacroreplacement.h>
@@ -33,7 +31,7 @@ struct _ValaCCodeMacroReplacementPrivate {
 enum  {
 	VALA_CCODE_MACRO_REPLACEMENT_DUMMY_PROPERTY,
 	VALA_CCODE_MACRO_REPLACEMENT_NAME,
-	VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT,
+	VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT
 };
 static void vala_ccode_macro_replacement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_macro_replacement_parent_class = NULL;
@@ -42,20 +40,29 @@ static void vala_ccode_macro_replacement_dispose (GObject * obj);
 
 ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* n, const char* replace)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaCCodeMacroReplacement * self;
 	g_return_val_if_fail (n != NULL, NULL);
 	g_return_val_if_fail (replace != NULL, NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, n), __params_it++);
 	(__params_it->name = "replacement", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, replace), __params_it++);
-	ValaCCodeMacroReplacement * self = g_object_newv (VALA_TYPE_CCODE_MACRO_REPLACEMENT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_MACRO_REPLACEMENT, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
 
 static void vala_ccode_macro_replacement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeMacroReplacement * self = VALA_CCODE_MACRO_REPLACEMENT (base);
+	ValaCCodeMacroReplacement * self;
+	self = ((ValaCCodeMacroReplacement*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	vala_ccode_writer_write_string (writer, "#define ");
@@ -75,9 +82,10 @@ char* vala_ccode_macro_replacement_get_name (ValaCCodeMacroReplacement* self)
 
 void vala_ccode_macro_replacement_set_name (ValaCCodeMacroReplacement* self, const char* value)
 {
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_MACRO_REPLACEMENT (self));
-	char* __temp1 = NULL;
-	self->priv->_name = (__temp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp1);
+	_tmp1 = NULL;
+	self->priv->_name = (_tmp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp1);
 }
 
 
@@ -90,15 +98,17 @@ char* vala_ccode_macro_replacement_get_replacement (ValaCCodeMacroReplacement* s
 
 void vala_ccode_macro_replacement_set_replacement (ValaCCodeMacroReplacement* self, const char* value)
 {
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_MACRO_REPLACEMENT (self));
-	char* __temp3 = NULL;
-	self->priv->_replacement = (__temp3 = g_strdup (value), (self->priv->_replacement = (g_free (self->priv->_replacement), NULL)), __temp3);
+	_tmp1 = NULL;
+	self->priv->_replacement = (_tmp1 = g_strdup (value), (self->priv->_replacement = (g_free (self->priv->_replacement), NULL)), _tmp1);
 }
 
 
 static void vala_ccode_macro_replacement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeMacroReplacement * self = VALA_CCODE_MACRO_REPLACEMENT (object);
+	ValaCCodeMacroReplacement * self;
+	self = VALA_CCODE_MACRO_REPLACEMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_MACRO_REPLACEMENT_NAME:
 		g_value_set_string (value, vala_ccode_macro_replacement_get_name (self));
@@ -106,13 +116,17 @@ static void vala_ccode_macro_replacement_get_property (GObject * object, guint p
 		case VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT:
 		g_value_set_string (value, vala_ccode_macro_replacement_get_replacement (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
 static void vala_ccode_macro_replacement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeMacroReplacement * self = VALA_CCODE_MACRO_REPLACEMENT (object);
+	ValaCCodeMacroReplacement * self;
+	self = VALA_CCODE_MACRO_REPLACEMENT (object);
 	switch (property_id) {
 		case VALA_CCODE_MACRO_REPLACEMENT_NAME:
 		vala_ccode_macro_replacement_set_name (self, g_value_get_string (value));
@@ -120,6 +134,9 @@ static void vala_ccode_macro_replacement_set_property (GObject * object, guint p
 		case VALA_CCODE_MACRO_REPLACEMENT_REPLACEMENT:
 		vala_ccode_macro_replacement_set_replacement (self, g_value_get_string (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -145,18 +162,19 @@ static void vala_ccode_macro_replacement_init (ValaCCodeMacroReplacement * self)
 
 static void vala_ccode_macro_replacement_dispose (GObject * obj)
 {
-	ValaCCodeMacroReplacement * self = VALA_CCODE_MACRO_REPLACEMENT (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
-	(self->priv->_replacement = (g_free (self->priv->_replacement), NULL));
+	ValaCCodeMacroReplacement * self;
 	ValaCCodeMacroReplacementClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_MACRO_REPLACEMENT (obj);
+	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	(self->priv->_replacement = (g_free (self->priv->_replacement), NULL));
 	klass = VALA_CCODE_MACRO_REPLACEMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_MACRO_REPLACEMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_macro_replacement_get_type ()
+GType vala_ccode_macro_replacement_get_type (void)
 {
 	static GType vala_ccode_macro_replacement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_macro_replacement_type_id == 0)) {
