@@ -1,5 +1,4 @@
-/* flags 
- valaccodenewline.vala
+/* valaccodenewline.vala
  *
  * Copyright (C) 2006  Jürg Billeter
  *
