@@ -1,5 +1,4 @@
-/* flags 
- valaccodenewline.vala
+/* valaccodenewline.vala
  *
  * Copyright (C) 2006  Jürg Billeter
  *
@@ -54,7 +53,7 @@ struct _ValaCCodeNewlineClass {
 	ValaCCodeNodeClass parent;
 };
 
-GType vala_ccode_newline_get_type ();
+GType vala_ccode_newline_get_type (void);
 
 G_END_DECLS
 
