@@ -93,12 +93,12 @@ ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self)
 
 void vala_ccode_node_set_line (ValaCCodeNode* self, ValaCCodeLineDirective* value)
 {
-	ValaCCodeLineDirective* __temp2;
-	ValaCCodeLineDirective* __temp1;
+	ValaCCodeLineDirective* _tmp2;
+	ValaCCodeLineDirective* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_NODE (self));
-	__temp2 = NULL;
-	__temp1 = NULL;
-	self->priv->_line = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_line == NULL ? NULL : (self->priv->_line = (g_object_unref (self->priv->_line), NULL))), __temp2);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_line = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_line == NULL ? NULL : (self->priv->_line = (g_object_unref (self->priv->_line), NULL))), _tmp2);
 }
 
 
@@ -110,6 +110,9 @@ static void vala_ccode_node_get_property (GObject * object, guint property_id, G
 		case VALA_CCODE_NODE_LINE:
 		g_value_set_object (value, vala_ccode_node_get_line (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -122,6 +125,9 @@ static void vala_ccode_node_set_property (GObject * object, guint property_id, c
 		case VALA_CCODE_NODE_LINE:
 		vala_ccode_node_set_line (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
