@@ -108,10 +108,10 @@ char* vala_ccode_once_section_get_define (ValaCCodeOnceSection* self)
 
 void vala_ccode_once_section_set_define (ValaCCodeOnceSection* self, const char* value)
 {
-	char* __temp1;
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_ONCE_SECTION (self));
-	__temp1 = NULL;
-	self->priv->_define = (__temp1 = g_strdup (value), (self->priv->_define = (g_free (self->priv->_define), NULL)), __temp1);
+	_tmp1 = NULL;
+	self->priv->_define = (_tmp1 = g_strdup (value), (self->priv->_define = (g_free (self->priv->_define), NULL)), _tmp1);
 }
 
 
@@ -123,6 +123,9 @@ static void vala_ccode_once_section_get_property (GObject * object, guint proper
 		case VALA_CCODE_ONCE_SECTION_DEFINE:
 		g_value_set_string (value, vala_ccode_once_section_get_define (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -135,6 +138,9 @@ static void vala_ccode_once_section_set_property (GObject * object, guint proper
 		case VALA_CCODE_ONCE_SECTION_DEFINE:
 		vala_ccode_once_section_set_define (self, g_value_get_string (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
