@@ -78,10 +78,10 @@ ValaCCodeExpression* vala_ccode_parenthesized_expression_get_inner (ValaCCodePar
 
 void vala_ccode_parenthesized_expression_set_inner (ValaCCodeParenthesizedExpression* self, ValaCCodeExpression* value)
 {
-	ValaCCodeExpression* __temp1;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (self));
-	__temp1 = NULL;
-	self->priv->_inner = (__temp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp1);
+	_tmp1 = NULL;
+	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
 }
 
 
@@ -93,6 +93,9 @@ static void vala_ccode_parenthesized_expression_get_property (GObject * object,
 		case VALA_CCODE_PARENTHESIZED_EXPRESSION_INNER:
 		g_value_set_object (value, vala_ccode_parenthesized_expression_get_inner (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -105,6 +108,9 @@ static void vala_ccode_parenthesized_expression_set_property (GObject * object,
 		case VALA_CCODE_PARENTHESIZED_EXPRESSION_INNER:
 		vala_ccode_parenthesized_expression_set_inner (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
