@@ -32,6 +32,7 @@
 struct _ValaCCodeSwitchStatementPrivate {
 	ValaCCodeExpression* _expression;
 	GeeList* case_statements;
+	GeeList* default_statements;
 };
 #define VALA_CCODE_SWITCH_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_SWITCH_STATEMENT, ValaCCodeSwitchStatementPrivate))
 enum  {
@@ -66,6 +67,19 @@ void vala_ccode_switch_statement_add_case (ValaCCodeSwitchStatement* self, ValaC
 }
 
 
+/**
+ * Append the specified statement to the default clause.
+ *
+ * @param stmt a statement
+ */
+void vala_ccode_switch_statement_add_default_statement (ValaCCodeSwitchStatement* self, ValaCCodeStatement* stmt)
+{
+	g_return_if_fail (VALA_IS_CCODE_SWITCH_STATEMENT (self));
+	g_return_if_fail (VALA_IS_CCODE_STATEMENT (stmt));
+	gee_collection_add (GEE_COLLECTION (self->priv->default_statements), stmt);
+}
+
+
 static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeSwitchStatement * self;
@@ -91,6 +105,26 @@ static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCo
 		}
 		(case_stmt_it == NULL ? NULL : (case_stmt_it = (g_object_unref (case_stmt_it), NULL)));
 	}
+	if (gee_collection_get_size (((GeeCollection*) self->priv->default_statements)) > 0) {
+		vala_ccode_writer_write_indent (writer);
+		vala_ccode_writer_write_string (writer, "default:");
+		vala_ccode_writer_write_newline (writer);
+		{
+			GeeList* stmt_collection;
+			GeeIterator* stmt_it;
+			stmt_collection = self->priv->default_statements;
+			stmt_it = gee_iterable_iterator (GEE_ITERABLE (stmt_collection));
+			while (gee_iterator_next (stmt_it)) {
+				ValaCCodeStatement* stmt;
+				stmt = gee_iterator_get (stmt_it);
+				{
+					vala_ccode_node_write (VALA_CCODE_NODE (stmt), writer);
+					(stmt == NULL ? NULL : (stmt = (g_object_unref (stmt), NULL)));
+				}
+			}
+			(stmt_it == NULL ? NULL : (stmt_it = (g_object_unref (stmt_it), NULL)));
+		}
+	}
 	vala_ccode_writer_write_end_block (writer);
 }
 
@@ -104,10 +138,10 @@ ValaCCodeExpression* vala_ccode_switch_statement_get_expression (ValaCCodeSwitch
 
 void vala_ccode_switch_statement_set_expression (ValaCCodeSwitchStatement* self, ValaCCodeExpression* value)
 {
-	ValaCCodeExpression* __temp1;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_SWITCH_STATEMENT (self));
-	__temp1 = NULL;
-	self->priv->_expression = (__temp1 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), __temp1);
+	_tmp1 = NULL;
+	self->priv->_expression = (_tmp1 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp1);
 }
 
 
@@ -119,6 +153,9 @@ static void vala_ccode_switch_statement_get_property (GObject * object, guint pr
 		case VALA_CCODE_SWITCH_STATEMENT_EXPRESSION:
 		g_value_set_object (value, vala_ccode_switch_statement_get_expression (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -131,6 +168,9 @@ static void vala_ccode_switch_statement_set_property (GObject * object, guint pr
 		case VALA_CCODE_SWITCH_STATEMENT_EXPRESSION:
 		vala_ccode_switch_statement_set_expression (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -151,6 +191,7 @@ static void vala_ccode_switch_statement_init (ValaCCodeSwitchStatement * self)
 {
 	self->priv = VALA_CCODE_SWITCH_STATEMENT_GET_PRIVATE (self);
 	self->priv->case_statements = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->default_statements = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
@@ -162,6 +203,7 @@ static void vala_ccode_switch_statement_dispose (GObject * obj)
 	self = VALA_CCODE_SWITCH_STATEMENT (obj);
 	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
 	(self->priv->case_statements == NULL ? NULL : (self->priv->case_statements = (g_object_unref (self->priv->case_statements), NULL)));
+	(self->priv->default_statements == NULL ? NULL : (self->priv->default_statements = (g_object_unref (self->priv->default_statements), NULL)));
 	klass = VALA_CCODE_SWITCH_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_SWITCH_STATEMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
