@@ -128,10 +128,10 @@ char* vala_ccode_variable_declarator_get_name (ValaCCodeVariableDeclarator* self
 
 void vala_ccode_variable_declarator_set_name (ValaCCodeVariableDeclarator* self, const char* value)
 {
-	char* __temp1;
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_VARIABLE_DECLARATOR (self));
-	__temp1 = NULL;
-	self->priv->_name = (__temp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp1);
+	_tmp1 = NULL;
+	self->priv->_name = (_tmp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp1);
 }
 
 
@@ -144,12 +144,12 @@ ValaCCodeExpression* vala_ccode_variable_declarator_get_initializer (ValaCCodeVa
 
 void vala_ccode_variable_declarator_set_initializer (ValaCCodeVariableDeclarator* self, ValaCCodeExpression* value)
 {
-	ValaCCodeExpression* __temp4;
-	ValaCCodeExpression* __temp3;
+	ValaCCodeExpression* _tmp2;
+	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_VARIABLE_DECLARATOR (self));
-	__temp4 = NULL;
-	__temp3 = NULL;
-	self->priv->_initializer = (__temp4 = (__temp3 = value, (__temp3 == NULL ? NULL : g_object_ref (__temp3))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), __temp4);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), _tmp2);
 }
 
 
@@ -164,6 +164,9 @@ static void vala_ccode_variable_declarator_get_property (GObject * object, guint
 		case VALA_CCODE_VARIABLE_DECLARATOR_INITIALIZER:
 		g_value_set_object (value, vala_ccode_variable_declarator_get_initializer (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -179,6 +182,9 @@ static void vala_ccode_variable_declarator_set_property (GObject * object, guint
 		case VALA_CCODE_VARIABLE_DECLARATOR_INITIALIZER:
 		vala_ccode_variable_declarator_set_initializer (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
