@@ -62,7 +62,7 @@ char* vala_ccode_variable_declarator_get_name (ValaCCodeVariableDeclarator* self
 void vala_ccode_variable_declarator_set_name (ValaCCodeVariableDeclarator* self, const char* value);
 ValaCCodeExpression* vala_ccode_variable_declarator_get_initializer (ValaCCodeVariableDeclarator* self);
 void vala_ccode_variable_declarator_set_initializer (ValaCCodeVariableDeclarator* self, ValaCCodeExpression* value);
-GType vala_ccode_variable_declarator_get_type ();
+GType vala_ccode_variable_declarator_get_type (void);
 
 G_END_DECLS
 
