@@ -22,9 +22,6 @@
 
 #ifndef __VALACCODEWRITER_H__
 #define __VALACCODEWRITER_H__
-typedef struct _ValaCCodeWriter ValaCCodeWriter;
-typedef struct _ValaCCodeWriterClass ValaCCodeWriterClass;
-typedef struct _ValaCCodeWriterPrivate ValaCCodeWriterPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -41,6 +38,9 @@ G_BEGIN_DECLS
 #define VALA_IS_CCODE_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_WRITER))
 #define VALA_CCODE_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_WRITER, ValaCCodeWriterClass))
 
+typedef struct _ValaCCodeWriter ValaCCodeWriter;
+typedef struct _ValaCCodeWriterClass ValaCCodeWriterClass;
+typedef struct _ValaCCodeWriterPrivate ValaCCodeWriterPrivate;
 
 /**
  * Represents a writer to write C source files.
@@ -64,7 +64,7 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text);
 char* vala_ccode_writer_get_filename (ValaCCodeWriter* self);
 void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value);
 gboolean vala_ccode_writer_get_bol (ValaCCodeWriter* self);
-GType vala_ccode_writer_get_type ();
+GType vala_ccode_writer_get_type (void);
 
 G_END_DECLS
 
