@@ -95,7 +95,7 @@ static void gee_array_list_iterator_set_list (GeeArrayListIterator* self, GeeArr
 static gpointer gee_array_list_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_array_list_iterator_gee_iterator_parent_iface = NULL;
 static void gee_array_list_iterator_dispose (GObject * obj);
-GType gee_array_list_iterator_get_type (void);
+static GType gee_array_list_iterator_get_type (void);
 static gpointer gee_array_list_parent_class = NULL;
 static GeeIterableIface* gee_array_list_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_array_list_gee_collection_parent_iface = NULL;
@@ -152,35 +152,35 @@ static gint gee_array_list_real_index_of (GeeList* base, gpointer item)
 static gpointer gee_array_list_real_get (GeeList* base, gint index)
 {
 	GeeArrayList * self;
-	gpointer __temp4;
+	gpointer _tmp0;
 	self = ((GeeArrayList*) base);
 	g_assert (index >= 0 && index < self->priv->_size);
-	return (__temp4 = self->priv->_items[index], (__temp4 == NULL || self->priv->g_dup_func == NULL ? __temp4 : self->priv->g_dup_func (__temp4)));
+	return (_tmp0 = self->priv->_items[index], (_tmp0 == NULL || self->priv->g_dup_func == NULL ? _tmp0 : self->priv->g_dup_func (_tmp0)));
 }
 
 
 static void gee_array_list_real_set (GeeList* base, gint index, gpointer item)
 {
 	GeeArrayList * self;
-	gpointer __temp7;
-	gpointer __temp6;
+	gpointer _tmp1;
+	gpointer _tmp0;
 	self = ((GeeArrayList*) base);
 	g_assert (index >= 0 && index < self->priv->_size);
-	self->priv->_items[index] = (__temp7 = (__temp6 = item, (__temp6 == NULL || self->priv->g_dup_func == NULL ? __temp6 : self->priv->g_dup_func (__temp6))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), __temp7);
+	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? _tmp0 : self->priv->g_dup_func (_tmp0))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
 }
 
 
 static gboolean gee_array_list_real_add (GeeCollection* base, gpointer item)
 {
 	GeeArrayList * self;
-	gint __temp10;
-	gpointer __temp9;
-	gpointer __temp8;
+	gint _tmp2;
+	gpointer _tmp1;
+	gpointer _tmp0;
 	self = ((GeeArrayList*) base);
 	if (self->priv->_size == self->priv->_items_length1) {
 		gee_array_list_grow_if_needed (self, 1);
 	}
-	(__temp10 = self->priv->_size++, self->priv->_items[__temp10] = (__temp9 = (__temp8 = item, (__temp8 == NULL || self->priv->g_dup_func == NULL ? __temp8 : self->priv->g_dup_func (__temp8))), (self->priv->_items[__temp10] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[__temp10] = (self->priv->g_destroy_func (self->priv->_items[__temp10]), NULL))), __temp9));
+	(_tmp2 = self->priv->_size++, self->priv->_items[_tmp2] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? _tmp0 : self->priv->g_dup_func (_tmp0))), (self->priv->_items[_tmp2] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[_tmp2] = (self->priv->g_destroy_func (self->priv->_items[_tmp2]), NULL))), _tmp1));
 	self->priv->_stamp++;
 	return TRUE;
 }
@@ -189,15 +189,15 @@ static gboolean gee_array_list_real_add (GeeCollection* base, gpointer item)
 static void gee_array_list_real_insert (GeeList* base, gint index, gpointer item)
 {
 	GeeArrayList * self;
-	gpointer __temp13;
-	gpointer __temp12;
+	gpointer _tmp1;
+	gpointer _tmp0;
 	self = ((GeeArrayList*) base);
 	g_assert (index >= 0 && index <= self->priv->_size);
 	if (self->priv->_size == self->priv->_items_length1) {
 		gee_array_list_grow_if_needed (self, 1);
 	}
 	gee_array_list_shift (self, index, 1);
-	self->priv->_items[index] = (__temp13 = (__temp12 = item, (__temp12 == NULL || self->priv->g_dup_func == NULL ? __temp12 : self->priv->g_dup_func (__temp12))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), __temp13);
+	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? _tmp0 : self->priv->g_dup_func (_tmp0))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
 	self->priv->_stamp++;
 }
 
@@ -223,10 +223,10 @@ static gboolean gee_array_list_real_remove (GeeCollection* base, gpointer item)
 static void gee_array_list_real_remove_at (GeeList* base, gint index)
 {
 	GeeArrayList * self;
-	gpointer __temp16;
+	gpointer _tmp0;
 	self = ((GeeArrayList*) base);
 	g_assert (index >= 0 && index < self->priv->_size);
-	self->priv->_items[index] = (__temp16 = NULL, (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), __temp16);
+	self->priv->_items[index] = (_tmp0 = NULL, (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp0);
 	gee_array_list_shift (self, index + 1, -1);
 	self->priv->_stamp++;
 }
@@ -240,8 +240,8 @@ static void gee_array_list_real_clear (GeeCollection* base)
 		gint index;
 		index = 0;
 		for (index = 0; index < self->priv->_size; index++) {
-			gpointer __temp17;
-			self->priv->_items[index] = (__temp17 = NULL, (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), __temp17);
+			gpointer _tmp0;
+			self->priv->_items[index] = (_tmp0 = NULL, (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp0);
 		}
 	}
 	self->priv->_size = 0;
@@ -273,10 +273,10 @@ static void gee_array_list_grow_if_needed (GeeArrayList* self, gint new_count)
 
 static void gee_array_list_set_capacity (GeeArrayList* self, gint value)
 {
-	gint __temp18;
+	gint _tmp0;
 	g_return_if_fail (GEE_IS_ARRAY_LIST (self));
 	g_assert (value >= self->priv->_size);
-	(__temp18 = value, self->priv->_items = g_renew (gpointer, self->priv->_items, value), (__temp18 > self->priv->_items_length1 ? memset (self->priv->_items + self->priv->_items_length1, 0, sizeof (gpointer) * (__temp18 - self->priv->_items_length1)) : NULL), self->priv->_items_length1 = __temp18);
+	(_tmp0 = value, self->priv->_items = g_renew (gpointer, self->priv->_items, value), (_tmp0 > self->priv->_items_length1 ? memset (self->priv->_items + self->priv->_items_length1, 0, sizeof (gpointer) * (_tmp0 - self->priv->_items_length1)) : NULL), self->priv->_items_length1 = _tmp0);
 }
 
 
@@ -332,16 +332,28 @@ static gpointer gee_array_list_iterator_real_get (GeeIterator* base)
 
 static void gee_array_list_iterator_set_list (GeeArrayListIterator* self, GeeArrayList* value)
 {
-	GeeArrayList* __temp24;
-	GeeArrayList* __temp23;
+	GeeArrayList* _tmp1;
+	GeeArrayList* _tmp0;
 	g_return_if_fail (GEE_ARRAY_LIST_IS_ITERATOR (self));
-	__temp24 = NULL;
-	__temp23 = NULL;
-	self->priv->_list = (__temp24 = (__temp23 = value, (__temp23 == NULL ? NULL : g_object_ref (__temp23))), (self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL))), __temp24);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL))), _tmp1);
 	self->_stamp = self->priv->_list->priv->_stamp;
 }
 
 
+static void gee_array_list_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
+{
+	GeeArrayListIterator * self;
+	self = GEE_ARRAY_LIST_ITERATOR (object);
+	switch (property_id) {
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
 static void gee_array_list_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
 	GeeArrayListIterator * self;
@@ -353,6 +365,9 @@ static void gee_array_list_iterator_set_property (GObject * object, guint proper
 		case GEE_ARRAY_LIST_ITERATOR_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -361,6 +376,7 @@ static void gee_array_list_iterator_class_init (GeeArrayListIteratorClass * klas
 {
 	gee_array_list_iterator_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeArrayListIteratorPrivate));
+	G_OBJECT_CLASS (klass)->get_property = gee_array_list_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_array_list_iterator_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_array_list_iterator_dispose;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
@@ -398,7 +414,7 @@ static void gee_array_list_iterator_dispose (GObject * obj)
 }
 
 
-GType gee_array_list_iterator_get_type (void)
+static GType gee_array_list_iterator_get_type (void)
 {
 	static GType gee_array_list_iterator_type_id = 0;
 	if (G_UNLIKELY (gee_array_list_iterator_type_id == 0)) {
@@ -419,6 +435,9 @@ static void gee_array_list_get_property (GObject * object, guint property_id, GV
 		case GEE_ARRAY_LIST_SIZE:
 		g_value_set_int (value, gee_array_list_real_get_size (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -434,6 +453,9 @@ static void gee_array_list_set_property (GObject * object, guint property_id, co
 		case GEE_ARRAY_LIST_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -523,10 +545,15 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 {
 	if (array != NULL && destroy_func != NULL) {
 		int i;
+		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
 			if (((gpointer*) array)[i] != NULL)
 			destroy_func (((gpointer*) array)[i]);
 		}
+		else
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
+		}
 	}
 	g_free (array);
 }
