@@ -59,6 +59,11 @@ struct _GeeReadOnlySetIterator {
 struct _GeeReadOnlySetIteratorClass {
 	GObjectClass parent;
 };
+struct _GeeReadOnlySetIteratorPrivate {
+	GBoxedCopyFunc g_dup_func;
+	GDestroyNotify g_destroy_func;
+};
+#define GEE_READ_ONLY_SET_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIteratorPrivate))
 enum  {
 	GEE_READ_ONLY_SET_ITERATOR_DUMMY_PROPERTY,
 	GEE_READ_ONLY_SET_ITERATOR_G_DUP_FUNC,
@@ -68,7 +73,7 @@ static gboolean gee_read_only_set_iterator_real_next (GeeIterator* base);
 static gpointer gee_read_only_set_iterator_real_get (GeeIterator* base);
 static gpointer gee_read_only_set_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_read_only_set_iterator_gee_iterator_parent_iface = NULL;
-GType gee_read_only_set_iterator_get_type (void);
+static GType gee_read_only_set_iterator_get_type (void);
 static gpointer gee_read_only_set_parent_class = NULL;
 static GeeIterableIface* gee_read_only_set_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_read_only_set_gee_collection_parent_iface = NULL;
@@ -145,12 +150,12 @@ static gint gee_read_only_set_real_get_size (GeeReadOnlySet* self)
 
 void gee_read_only_set_set_set (GeeReadOnlySet* self, GeeSet* value)
 {
-	GeeSet* __temp8;
-	GeeSet* __temp7;
+	GeeSet* _tmp1;
+	GeeSet* _tmp0;
 	g_return_if_fail (GEE_IS_READ_ONLY_SET (self));
-	__temp8 = NULL;
-	__temp7 = NULL;
-	self->priv->_set = (__temp8 = (__temp7 = value, (__temp7 == NULL ? NULL : g_object_ref (__temp7))), (self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL))), __temp8);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->_set = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_set == NULL ? NULL : (self->priv->_set = (g_object_unref (self->priv->_set), NULL))), _tmp1);
 }
 
 
@@ -170,9 +175,39 @@ static gpointer gee_read_only_set_iterator_real_get (GeeIterator* base)
 }
 
 
+static void gee_read_only_set_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
+{
+	GeeReadOnlySetIterator * self;
+	self = GEE_READ_ONLY_SET_ITERATOR (object);
+	switch (property_id) {
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
+static void gee_read_only_set_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
+{
+	GeeReadOnlySetIterator * self;
+	self = GEE_READ_ONLY_SET_ITERATOR (object);
+	switch (property_id) {
+		case GEE_READ_ONLY_SET_ITERATOR_G_DESTROY_FUNC:
+		self->priv->g_destroy_func = g_value_get_pointer (value);
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
 static void gee_read_only_set_iterator_class_init (GeeReadOnlySetIteratorClass * klass)
 {
 	gee_read_only_set_iterator_parent_class = g_type_class_peek_parent (klass);
+	g_type_class_add_private (klass, sizeof (GeeReadOnlySetIteratorPrivate));
+	G_OBJECT_CLASS (klass)->get_property = gee_read_only_set_iterator_get_property;
+	G_OBJECT_CLASS (klass)->set_property = gee_read_only_set_iterator_set_property;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
@@ -188,10 +223,11 @@ static void gee_read_only_set_iterator_gee_iterator_interface_init (GeeIteratorI
 
 static void gee_read_only_set_iterator_init (GeeReadOnlySetIterator * self)
 {
+	self->priv = GEE_READ_ONLY_SET_ITERATOR_GET_PRIVATE (self);
 }
 
 
-GType gee_read_only_set_iterator_get_type (void)
+static GType gee_read_only_set_iterator_get_type (void)
 {
 	static GType gee_read_only_set_iterator_type_id = 0;
 	if (G_UNLIKELY (gee_read_only_set_iterator_type_id == 0)) {
@@ -212,6 +248,9 @@ static void gee_read_only_set_get_property (GObject * object, guint property_id,
 		case GEE_READ_ONLY_SET_SIZE:
 		g_value_set_int (value, gee_read_only_set_real_get_size (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -227,6 +266,9 @@ static void gee_read_only_set_set_property (GObject * object, guint property_id,
 		case GEE_READ_ONLY_SET_G_DESTROY_FUNC:
 		self->priv->g_destroy_func = g_value_get_pointer (value);
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
