@@ -29,6 +29,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodefragment.h>
+#include <vala/valasymbol.h>
 
 G_BEGIN_DECLS
 
@@ -63,6 +64,7 @@ struct _ValaTypeRegisterFunctionClass {
 	char* (*get_type_flags) (ValaTypeRegisterFunction* self);
 	ValaCCodeFragment* (*get_type_interface_init_declaration) (ValaTypeRegisterFunction* self);
 	ValaCCodeFragment* (*get_type_interface_init_statements) (ValaTypeRegisterFunction* self);
+	ValaSymbolAccessibility (*get_accessibility) (ValaTypeRegisterFunction* self);
 };
 
 void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self, gboolean plugin);
@@ -78,7 +80,8 @@ ValaCCodeFragment* vala_type_register_function_get_type_interface_init_declarati
 ValaCCodeFragment* vala_type_register_function_get_type_interface_init_statements (ValaTypeRegisterFunction* self);
 ValaCCodeFragment* vala_type_register_function_get_declaration (ValaTypeRegisterFunction* self);
 ValaCCodeFragment* vala_type_register_function_get_definition (ValaTypeRegisterFunction* self);
-GType vala_type_register_function_get_type ();
+ValaSymbolAccessibility vala_type_register_function_get_accessibility (ValaTypeRegisterFunction* self);
+GType vala_type_register_function_get_type (void);
 
 G_END_DECLS
 
