@@ -90,61 +90,62 @@
      DIV = 306,
      PERCENT = 307,
      ABSTRACT = 308,
-     BASE = 309,
-     BREAK = 310,
-     CASE = 311,
-     CATCH = 312,
-     CLASS = 313,
-     CONST = 314,
-     CONSTRUCT = 315,
-     CONTINUE = 316,
-     DEFAULT = 317,
-     DELEGATE = 318,
-     DO = 319,
-     ELSE = 320,
-     ENUM = 321,
-     VALA_FALSE = 322,
-     FINALLY = 323,
-     FOR = 324,
-     FOREACH = 325,
-     GET = 326,
-     IF = 327,
-     IN = 328,
-     INTERFACE = 329,
-     IS = 330,
-     LOCK = 331,
-     NAMESPACE = 332,
-     NEW = 333,
-     VALA_NULL = 334,
-     OUT = 335,
-     OVERRIDE = 336,
-     PRIVATE = 337,
-     PROTECTED = 338,
-     PUBLIC = 339,
-     REF = 340,
-     RETURN = 341,
-     SET = 342,
-     SIGNAL = 343,
-     SIZEOF = 344,
-     STATIC = 345,
-     STRUCT = 346,
-     SWITCH = 347,
-     THIS = 348,
-     THROW = 349,
-     THROWS = 350,
-     VALA_TRUE = 351,
-     TRY = 352,
-     TYPEOF = 353,
-     USING = 354,
-     VAR = 355,
-     VIRTUAL = 356,
-     WEAK = 357,
-     WHILE = 358,
-     IDENTIFIER = 359,
-     INTEGER_LITERAL = 360,
-     REAL_LITERAL = 361,
-     CHARACTER_LITERAL = 362,
-     STRING_LITERAL = 363
+     AS = 309,
+     BASE = 310,
+     BREAK = 311,
+     CASE = 312,
+     CATCH = 313,
+     CLASS = 314,
+     CONST = 315,
+     CONSTRUCT = 316,
+     CONTINUE = 317,
+     DEFAULT = 318,
+     DELEGATE = 319,
+     DO = 320,
+     ELSE = 321,
+     ENUM = 322,
+     VALA_FALSE = 323,
+     FINALLY = 324,
+     FOR = 325,
+     FOREACH = 326,
+     GET = 327,
+     IF = 328,
+     IN = 329,
+     INTERFACE = 330,
+     IS = 331,
+     LOCK = 332,
+     NAMESPACE = 333,
+     NEW = 334,
+     VALA_NULL = 335,
+     OUT = 336,
+     OVERRIDE = 337,
+     PRIVATE = 338,
+     PROTECTED = 339,
+     PUBLIC = 340,
+     REF = 341,
+     RETURN = 342,
+     SET = 343,
+     SIGNAL = 344,
+     SIZEOF = 345,
+     STATIC = 346,
+     STRUCT = 347,
+     SWITCH = 348,
+     THIS = 349,
+     THROW = 350,
+     THROWS = 351,
+     VALA_TRUE = 352,
+     TRY = 353,
+     TYPEOF = 354,
+     USING = 355,
+     VAR = 356,
+     VIRTUAL = 357,
+     WEAK = 358,
+     WHILE = 359,
+     IDENTIFIER = 360,
+     INTEGER_LITERAL = 361,
+     REAL_LITERAL = 362,
+     CHARACTER_LITERAL = 363,
+     STRING_LITERAL = 364
    };
 #endif
 /* Tokens.  */
@@ -199,68 +200,69 @@
 #define DIV 306
 #define PERCENT 307
 #define ABSTRACT 308
-#define BASE 309
-#define BREAK 310
-#define CASE 311
-#define CATCH 312
-#define CLASS 313
-#define CONST 314
-#define CONSTRUCT 315
-#define CONTINUE 316
-#define DEFAULT 317
-#define DELEGATE 318
-#define DO 319
-#define ELSE 320
-#define ENUM 321
-#define VALA_FALSE 322
-#define FINALLY 323
-#define FOR 324
-#define FOREACH 325
-#define GET 326
-#define IF 327
-#define IN 328
-#define INTERFACE 329
-#define IS 330
-#define LOCK 331
-#define NAMESPACE 332
-#define NEW 333
-#define VALA_NULL 334
-#define OUT 335
-#define OVERRIDE 336
-#define PRIVATE 337
-#define PROTECTED 338
-#define PUBLIC 339
-#define REF 340
-#define RETURN 341
-#define SET 342
-#define SIGNAL 343
-#define SIZEOF 344
-#define STATIC 345
-#define STRUCT 346
-#define SWITCH 347
-#define THIS 348
-#define THROW 349
-#define THROWS 350
-#define VALA_TRUE 351
-#define TRY 352
-#define TYPEOF 353
-#define USING 354
-#define VAR 355
-#define VIRTUAL 356
-#define WEAK 357
-#define WHILE 358
-#define IDENTIFIER 359
-#define INTEGER_LITERAL 360
-#define REAL_LITERAL 361
-#define CHARACTER_LITERAL 362
-#define STRING_LITERAL 363
+#define AS 309
+#define BASE 310
+#define BREAK 311
+#define CASE 312
+#define CATCH 313
+#define CLASS 314
+#define CONST 315
+#define CONSTRUCT 316
+#define CONTINUE 317
+#define DEFAULT 318
+#define DELEGATE 319
+#define DO 320
+#define ELSE 321
+#define ENUM 322
+#define VALA_FALSE 323
+#define FINALLY 324
+#define FOR 325
+#define FOREACH 326
+#define GET 327
+#define IF 328
+#define IN 329
+#define INTERFACE 330
+#define IS 331
+#define LOCK 332
+#define NAMESPACE 333
+#define NEW 334
+#define VALA_NULL 335
+#define OUT 336
+#define OVERRIDE 337
+#define PRIVATE 338
+#define PROTECTED 339
+#define PUBLIC 340
+#define REF 341
+#define RETURN 342
+#define SET 343
+#define SIGNAL 344
+#define SIZEOF 345
+#define STATIC 346
+#define STRUCT 347
+#define SWITCH 348
+#define THIS 349
+#define THROW 350
+#define THROWS 351
+#define VALA_TRUE 352
+#define TRY 353
+#define TYPEOF 354
+#define USING 355
+#define VAR 356
+#define VIRTUAL 357
+#define WEAK 358
+#define WHILE 359
+#define IDENTIFIER 360
+#define INTEGER_LITERAL 361
+#define REAL_LITERAL 362
+#define CHARACTER_LITERAL 363
+#define STRING_LITERAL 364
 
 
 
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 66 "parser.y"
+#line 67 "parser.y"
 {
 	int num;
 	char *str;
@@ -270,7 +272,6 @@ typedef union YYSTYPE
 	ValaExpression *expression;
 	ValaStatement *statement;
 	ValaBlock *block;
-	ValaStruct *struct_;
 	ValaInterface *interface;
 	ValaEnumValue *enum_value;
 	ValaConstant *constant;
@@ -292,7 +293,7 @@ typedef union YYSTYPE
 	ValaCatchClause *catch_clause;
 }
 /* Line 1489 of yacc.c.  */
-#line 296 "parser.h"
+#line 297 "parser.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
