@@ -97,10 +97,10 @@ ValaExpression* vala_addressof_expression_get_inner (ValaAddressofExpression* se
 
 void vala_addressof_expression_set_inner (ValaAddressofExpression* self, ValaExpression* value)
 {
-	ValaExpression* __temp1;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_ADDRESSOF_EXPRESSION (self));
-	__temp1 = NULL;
-	self->priv->_inner = (__temp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp1);
+	_tmp1 = NULL;
+	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
 }
 
@@ -113,6 +113,9 @@ static void vala_addressof_expression_get_property (GObject * object, guint prop
 		case VALA_ADDRESSOF_EXPRESSION_INNER:
 		g_value_set_object (value, vala_addressof_expression_get_inner (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -125,6 +128,9 @@ static void vala_addressof_expression_set_property (GObject * object, guint prop
 		case VALA_ADDRESSOF_EXPRESSION_INNER:
 		vala_addressof_expression_set_inner (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
