@@ -26,6 +26,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/list.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
 
@@ -53,15 +54,15 @@ struct _ValaArrayCreationExpressionClass {
 };
 
 void vala_array_creation_expression_append_size (ValaArrayCreationExpression* self, ValaExpression* size);
-GList* vala_array_creation_expression_get_sizes (ValaArrayCreationExpression* self);
-ValaArrayCreationExpression* vala_array_creation_expression_new (ValaTypeReference* _element_type, gint _rank, ValaInitializerList* _initializer, ValaSourceReference* source);
+GeeList* vala_array_creation_expression_get_sizes (ValaArrayCreationExpression* self);
+ValaArrayCreationExpression* vala_array_creation_expression_new (ValaTypeReference* element_type, gint rank, ValaInitializerList* initializer_list, ValaSourceReference* source_reference);
 ValaTypeReference* vala_array_creation_expression_get_element_type (ValaArrayCreationExpression* self);
 void vala_array_creation_expression_set_element_type (ValaArrayCreationExpression* self, ValaTypeReference* value);
 gint vala_array_creation_expression_get_rank (ValaArrayCreationExpression* self);
 void vala_array_creation_expression_set_rank (ValaArrayCreationExpression* self, gint value);
 ValaInitializerList* vala_array_creation_expression_get_initializer_list (ValaArrayCreationExpression* self);
 void vala_array_creation_expression_set_initializer_list (ValaArrayCreationExpression* self, ValaInitializerList* value);
-GType vala_array_creation_expression_get_type ();
+GType vala_array_creation_expression_get_type (void);
 
 G_END_DECLS
 
