@@ -1,6 +1,6 @@
 /* valaattribute.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,10 +19,10 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaattribute.h"
+#include <gee/arraylist.h>
+#include <gee/collection.h>
 #include <vala/valasourcereference.h>
 #include <vala/valaattribute.h>
 #include <vala/valanamedargument.h>
@@ -38,7 +38,7 @@ struct _ValaAttributePrivate {
 #define VALA_ATTRIBUTE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ATTRIBUTE, ValaAttributePrivate))
 enum  {
 	VALA_ATTRIBUTE_DUMMY_PROPERTY,
-	VALA_ATTRIBUTE_NAME,
+	VALA_ATTRIBUTE_NAME
 };
 static gpointer vala_attribute_parent_class = NULL;
 static void vala_attribute_dispose (GObject * obj);
@@ -47,19 +47,18 @@ static void vala_attribute_dispose (GObject * obj);
 /**
  * Creates a new attribute.
  *
- * @param name attribute type name
- * @param source reference to source code
- * @return newly created attribute
+ * @param name             attribute type name
+ * @param source_reference reference to source code
+ * @return                 newly created attribute
  */
-ValaAttribute* vala_attribute_new (const char* _name, ValaSourceReference* source)
+ValaAttribute* vala_attribute_new (const char* name, ValaSourceReference* source_reference)
 {
-	g_return_val_if_fail (_name != NULL, NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaAttribute * self = g_object_newv (VALA_TYPE_ATTRIBUTE, __params_it - __params, __params);
+	ValaAttribute * self;
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = g_object_newv (VALA_TYPE_ATTRIBUTE, 0, NULL);
+	vala_attribute_set_name (self, name);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -73,7 +72,7 @@ void vala_attribute_add_argument (ValaAttribute* self, ValaNamedArgument* arg)
 {
 	g_return_if_fail (VALA_IS_ATTRIBUTE (self));
 	g_return_if_fail (VALA_IS_NAMED_ARGUMENT (arg));
-	self->args = g_list_append (self->args, g_object_ref (arg));
+	gee_collection_add (GEE_COLLECTION (self->args), arg);
 }
 
 
@@ -88,18 +87,23 @@ gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name)
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), FALSE);
 	g_return_val_if_fail (name != NULL, FALSE);
 	{
-		GList* __temp1 = NULL;
-		__temp1 = self->args;
-		GList* arg_it;
-		for (arg_it = __temp1; arg_it != NULL; arg_it = arg_it->next) {
-			ValaNamedArgument* arg = arg_it->data;
+		GeeList* arg_collection;
+		GeeIterator* arg_it;
+		arg_collection = self->args;
+		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
+		while (gee_iterator_next (arg_it)) {
+			ValaNamedArgument* arg;
+			arg = gee_iterator_get (arg_it);
 			{
 				/* FIXME: use hash table*/
 				if (g_utf8_collate (vala_named_argument_get_name (arg), name) == 0) {
-					return TRUE;
+					gboolean _tmp0;
+					return (_tmp0 = TRUE, (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp0);
 				}
+				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
 		}
+		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 	}
 	return FALSE;
 }
@@ -116,26 +120,33 @@ char* vala_attribute_get_string (ValaAttribute* self, const char* name)
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	{
-		GList* __temp5 = NULL;
-		__temp5 = self->args;
-		GList* arg_it;
-		for (arg_it = __temp5; arg_it != NULL; arg_it = arg_it->next) {
-			ValaNamedArgument* arg = arg_it->data;
+		GeeList* arg_collection;
+		GeeIterator* arg_it;
+		arg_collection = self->args;
+		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
+		while (gee_iterator_next (arg_it)) {
+			ValaNamedArgument* arg;
+			arg = gee_iterator_get (arg_it);
 			{
 				/* FIXME: use hash table*/
 				if (g_utf8_collate (vala_named_argument_get_name (arg), name) == 0) {
 					if (VALA_IS_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg))) {
-						ValaLiteral* __temp3 = NULL;
-						ValaLiteral* lit = (__temp3 = vala_literal_expression_get_literal ((VALA_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg)))), (__temp3 == NULL ? NULL : g_object_ref (__temp3)));
+						ValaLiteral* _tmp0;
+						ValaLiteral* lit;
+						_tmp0 = NULL;
+						lit = (_tmp0 = vala_literal_expression_get_literal ((VALA_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg)))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 						if (VALA_IS_STRING_LITERAL (lit)) {
-							char* __temp4 = NULL;
-							return (__temp4 = vala_string_literal_eval ((VALA_STRING_LITERAL (lit))), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), __temp4);
+							char* _tmp1;
+							_tmp1 = NULL;
+							return (_tmp1 = vala_string_literal_eval ((VALA_STRING_LITERAL (lit))), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp1);
 						}
 						(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
 					}
 				}
+				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
 		}
+		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 	}
 	return NULL;
 }
@@ -152,26 +163,32 @@ gint vala_attribute_get_integer (ValaAttribute* self, const char* name)
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), 0);
 	g_return_val_if_fail (name != NULL, 0);
 	{
-		GList* __temp9 = NULL;
-		__temp9 = self->args;
-		GList* arg_it;
-		for (arg_it = __temp9; arg_it != NULL; arg_it = arg_it->next) {
-			ValaNamedArgument* arg = arg_it->data;
+		GeeList* arg_collection;
+		GeeIterator* arg_it;
+		arg_collection = self->args;
+		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
+		while (gee_iterator_next (arg_it)) {
+			ValaNamedArgument* arg;
+			arg = gee_iterator_get (arg_it);
 			{
 				/* FIXME: use hash table*/
 				if (g_utf8_collate (vala_named_argument_get_name (arg), name) == 0) {
 					if (VALA_IS_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg))) {
-						ValaLiteral* __temp7 = NULL;
-						ValaLiteral* lit = (__temp7 = vala_literal_expression_get_literal ((VALA_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg)))), (__temp7 == NULL ? NULL : g_object_ref (__temp7)));
+						ValaLiteral* _tmp0;
+						ValaLiteral* lit;
+						_tmp0 = NULL;
+						lit = (_tmp0 = vala_literal_expression_get_literal ((VALA_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg)))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 						if (VALA_IS_INTEGER_LITERAL (lit)) {
-							gint __temp8;
-							return (__temp8 = atoi (vala_integer_literal_get_value ((VALA_INTEGER_LITERAL (lit)))), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), __temp8);
+							gint _tmp1;
+							return (_tmp1 = atoi (vala_integer_literal_get_value ((VALA_INTEGER_LITERAL (lit)))), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp1);
 						}
 						(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
 					}
 				}
+				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
 		}
+		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 	}
 	return 0;
 }
@@ -188,26 +205,32 @@ gboolean vala_attribute_get_bool (ValaAttribute* self, const char* name)
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), FALSE);
 	g_return_val_if_fail (name != NULL, FALSE);
 	{
-		GList* __temp13 = NULL;
-		__temp13 = self->args;
-		GList* arg_it;
-		for (arg_it = __temp13; arg_it != NULL; arg_it = arg_it->next) {
-			ValaNamedArgument* arg = arg_it->data;
+		GeeList* arg_collection;
+		GeeIterator* arg_it;
+		arg_collection = self->args;
+		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
+		while (gee_iterator_next (arg_it)) {
+			ValaNamedArgument* arg;
+			arg = gee_iterator_get (arg_it);
 			{
 				/* FIXME: use hash table*/
 				if (g_utf8_collate (vala_named_argument_get_name (arg), name) == 0) {
 					if (VALA_IS_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg))) {
-						ValaLiteral* __temp11 = NULL;
-						ValaLiteral* lit = (__temp11 = vala_literal_expression_get_literal ((VALA_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg)))), (__temp11 == NULL ? NULL : g_object_ref (__temp11)));
+						ValaLiteral* _tmp0;
+						ValaLiteral* lit;
+						_tmp0 = NULL;
+						lit = (_tmp0 = vala_literal_expression_get_literal ((VALA_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg)))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 						if (VALA_IS_BOOLEAN_LITERAL (lit)) {
-							gboolean __temp12;
-							return (__temp12 = vala_boolean_literal_get_value ((VALA_BOOLEAN_LITERAL (lit))), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), __temp12);
+							gboolean _tmp1;
+							return (_tmp1 = vala_boolean_literal_get_value ((VALA_BOOLEAN_LITERAL (lit))), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp1);
 						}
 						(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
 					}
 				}
+				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
 		}
+		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 	}
 	return FALSE;
 }
@@ -222,30 +245,39 @@ char* vala_attribute_get_name (ValaAttribute* self)
 
 void vala_attribute_set_name (ValaAttribute* self, const char* value)
 {
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_ATTRIBUTE (self));
-	char* __temp16 = NULL;
-	self->priv->_name = (__temp16 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp16);
+	_tmp1 = NULL;
+	self->priv->_name = (_tmp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp1);
 }
 
 
 static void vala_attribute_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaAttribute * self = VALA_ATTRIBUTE (object);
+	ValaAttribute * self;
+	self = VALA_ATTRIBUTE (object);
 	switch (property_id) {
 		case VALA_ATTRIBUTE_NAME:
 		g_value_set_string (value, vala_attribute_get_name (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
 static void vala_attribute_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaAttribute * self = VALA_ATTRIBUTE (object);
+	ValaAttribute * self;
+	self = VALA_ATTRIBUTE (object);
 	switch (property_id) {
 		case VALA_ATTRIBUTE_NAME:
 		vala_attribute_set_name (self, g_value_get_string (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -257,30 +289,32 @@ static void vala_attribute_class_init (ValaAttributeClass * klass)
 	G_OBJECT_CLASS (klass)->get_property = vala_attribute_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_attribute_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_attribute_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ATTRIBUTE_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ATTRIBUTE_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_attribute_init (ValaAttribute * self)
 {
 	self->priv = VALA_ATTRIBUTE_GET_PRIVATE (self);
+	self->args = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
 static void vala_attribute_dispose (GObject * obj)
 {
-	ValaAttribute * self = VALA_ATTRIBUTE (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
-	(self->args == NULL ? NULL : (self->args = (g_list_foreach (self->args, (GFunc) g_object_unref, NULL), g_list_free (self->args), NULL)));
+	ValaAttribute * self;
 	ValaAttributeClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_ATTRIBUTE (obj);
+	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	(self->args == NULL ? NULL : (self->args = (g_object_unref (self->args), NULL)));
 	klass = VALA_ATTRIBUTE_CLASS (g_type_class_peek (VALA_TYPE_ATTRIBUTE));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_attribute_get_type ()
+GType vala_attribute_get_type (void)
 {
 	static GType vala_attribute_type_id = 0;
 	if (G_UNLIKELY (vala_attribute_type_id == 0)) {
