@@ -54,7 +54,7 @@ struct _ValaBaseAccessClass {
 };
 
 ValaBaseAccess* vala_base_access_new (ValaSourceReference* source);
-GType vala_base_access_get_type ();
+GType vala_base_access_get_type (void);
 
 G_END_DECLS
 
