@@ -100,6 +100,9 @@ static void vala_boolean_literal_get_property (GObject * object, guint property_
 		case VALA_BOOLEAN_LITERAL_VALUE:
 		g_value_set_boolean (value, vala_boolean_literal_get_value (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -112,6 +115,9 @@ static void vala_boolean_literal_set_property (GObject * object, guint property_
 		case VALA_BOOLEAN_LITERAL_VALUE:
 		vala_boolean_literal_set_value (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
