@@ -28,8 +28,8 @@
 #include <gee/iterator.h>
 #include <vala/valatypereference.h>
 #include <vala/valasourcereference.h>
-#include <vala/valasymbol.h>
 #include <vala/valacallback.h>
+#include <vala/valasymbol.h>
 #include <vala/valatypeparameter.h>
 #include <vala/valascope.h>
 #include <vala/valaformalparameter.h>
@@ -137,7 +137,7 @@ gboolean vala_callback_matches_method (ValaCallback* self, ValaMethod* m)
 	GeeCollection* method_params;
 	GeeIterator* method_params_it;
 	gboolean first;
-	gboolean __temp4;
+	gboolean _tmp3;
 	g_return_val_if_fail (VALA_IS_CALLBACK (self), FALSE);
 	g_return_val_if_fail (VALA_IS_METHOD (m), FALSE);
 	if (!vala_type_reference_stricter (vala_method_get_return_type (m), vala_callback_get_return_type (self))) {
@@ -172,8 +172,8 @@ gboolean vala_callback_matches_method (ValaCallback* self, ValaMethod* m)
 				}
 				method_param = gee_iterator_get (method_params_it);
 				if (!vala_type_reference_stricter (vala_formal_parameter_get_type_reference (param), vala_formal_parameter_get_type_reference (method_param))) {
-					gboolean __temp2;
-					return (__temp2 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (method_param == NULL ? NULL : (method_param = (g_object_unref (method_param), NULL))), (param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL))), (method_params == NULL ? NULL : (method_params = (g_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), __temp2);
+					gboolean _tmp1;
+					return (_tmp1 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (method_param == NULL ? NULL : (method_param = (g_object_unref (method_param), NULL))), (param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL))), (method_params == NULL ? NULL : (method_params = (g_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp1);
 				}
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 				(method_param == NULL ? NULL : (method_param = (g_object_unref (method_param), NULL)));
@@ -183,10 +183,10 @@ gboolean vala_callback_matches_method (ValaCallback* self, ValaMethod* m)
 	}
 	/* method may not expect more arguments */
 	if (gee_iterator_next (method_params_it)) {
-		gboolean __temp3;
-		return (__temp3 = FALSE, (method_params == NULL ? NULL : (method_params = (g_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), __temp3);
+		gboolean _tmp2;
+		return (_tmp2 = FALSE, (method_params == NULL ? NULL : (method_params = (g_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp2);
 	}
-	return (__temp4 = TRUE, (method_params == NULL ? NULL : (method_params = (g_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), __temp4);
+	return (_tmp3 = TRUE, (method_params == NULL ? NULL : (method_params = (g_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp3);
 	(method_params == NULL ? NULL : (method_params = (g_object_unref (method_params), NULL)));
 	(method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL)));
 }
@@ -243,18 +243,18 @@ static void vala_callback_real_accept_children (ValaCodeNode* base, ValaCodeVisi
 static char* vala_callback_real_get_cname (ValaDataType* base, gboolean const_type)
 {
 	ValaCallback * self;
-	const char* __temp7;
+	const char* _tmp2;
 	self = ((ValaCallback*) base);
 	if (self->priv->cname == NULL) {
-		char* __temp6;
-		char* __temp5;
-		__temp6 = NULL;
-		__temp5 = NULL;
-		self->priv->cname = (__temp6 = g_strdup_printf ("%s%s", (__temp5 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp6);
-		(__temp5 = (g_free (__temp5), NULL));
+		char* _tmp1;
+		char* _tmp0;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		self->priv->cname = (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
+		(_tmp0 = (g_free (_tmp0), NULL));
 	}
-	__temp7 = NULL;
-	return (__temp7 = self->priv->cname, (__temp7 == NULL ? NULL : g_strdup (__temp7)));
+	_tmp2 = NULL;
+	return (_tmp2 = self->priv->cname, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
 }
 
 
@@ -265,12 +265,12 @@ static char* vala_callback_real_get_cname (ValaDataType* base, gboolean const_ty
  */
 void vala_callback_set_cname (ValaCallback* self, const char* cname)
 {
-	char* __temp10;
-	const char* __temp9;
+	char* _tmp1;
+	const char* _tmp0;
 	g_return_if_fail (VALA_IS_CALLBACK (self));
-	__temp10 = NULL;
-	__temp9 = NULL;
-	self->priv->cname = (__temp10 = (__temp9 = cname, (__temp9 == NULL ? NULL : g_strdup (__temp9))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp10);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
 }
 
 
@@ -279,10 +279,10 @@ static void vala_callback_process_ccode_attribute (ValaCallback* self, ValaAttri
 	g_return_if_fail (VALA_IS_CALLBACK (self));
 	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
-		char* __temp11;
-		__temp11 = NULL;
-		vala_callback_set_cname (self, (__temp11 = vala_attribute_get_string (a, "cname")));
-		(__temp11 = (g_free (__temp11), NULL));
+		char* _tmp0;
+		_tmp0 = NULL;
+		vala_callback_set_cname (self, (_tmp0 = vala_attribute_get_string (a, "cname")));
+		(_tmp0 = (g_free (_tmp0), NULL));
 	}
 }
 
@@ -298,10 +298,10 @@ void vala_callback_process_attributes (ValaCallback* self)
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* __temp12;
+			ValaAttribute* _tmp0;
 			ValaAttribute* a;
-			__temp12 = NULL;
-			a = (__temp12 = a_it->data, (__temp12 == NULL ? NULL : g_object_ref (__temp12)));
+			_tmp0 = NULL;
+			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_callback_process_ccode_attribute (self, a);
@@ -362,12 +362,12 @@ ValaTypeReference* vala_callback_get_return_type (ValaCallback* self)
 
 void vala_callback_set_return_type (ValaCallback* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp20;
-	ValaTypeReference* __temp19;
+	ValaTypeReference* _tmp2;
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_CALLBACK (self));
-	__temp20 = NULL;
-	__temp19 = NULL;
-	self->priv->_return_type = (__temp20 = (__temp19 = value, (__temp19 == NULL ? NULL : g_object_ref (__temp19))), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), __temp20);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_return_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), _tmp2);
 }
 
 
@@ -396,6 +396,9 @@ static void vala_callback_get_property (GObject * object, guint property_id, GVa
 		case VALA_CALLBACK_INSTANCE:
 		g_value_set_boolean (value, vala_callback_get_instance (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -411,6 +414,9 @@ static void vala_callback_set_property (GObject * object, guint property_id, con
 		case VALA_CALLBACK_INSTANCE:
 		vala_callback_set_instance (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
