@@ -19,12 +19,14 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valacodecontext.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/readonlycollection.h>
 #include <vala/valamethod.h>
-#include <vala/valasymbol.h>
+#include <vala/valanamespace.h>
+#include <vala/valasourcereference.h>
 #include <vala/valacodecontext.h>
 #include <vala/valasourcefile.h>
 #include <vala/valacodevisitor.h>
@@ -38,14 +40,17 @@ struct _ValaCodeContextPrivate {
 	gboolean _ccode_only;
 	gboolean _compile_only;
 	char* _output;
+	char* _directory;
 	gboolean _debug;
 	gint _optlevel;
 	gboolean _thread;
 	ValaMethod* _module_init_method;
-	GList* source_files;
-	ValaSymbol* root;
-	GList* cycles;
-	GList* packages;
+	gboolean _save_temps;
+	GeeList* source_files;
+	GeeList* c_source_files;
+	ValaNamespace* _root;
+	GeeList* cycles;
+	GeeList* packages;
 };
 #define VALA_CODE_CONTEXT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CODE_CONTEXT, ValaCodeContextPrivate))
 enum  {
@@ -57,40 +62,43 @@ enum  {
 	VALA_CODE_CONTEXT_CCODE_ONLY,
 	VALA_CODE_CONTEXT_COMPILE_ONLY,
 	VALA_CODE_CONTEXT_OUTPUT,
+	VALA_CODE_CONTEXT_DIRECTORY,
 	VALA_CODE_CONTEXT_DEBUG,
 	VALA_CODE_CONTEXT_OPTLEVEL,
 	VALA_CODE_CONTEXT_THREAD,
-	VALA_CODE_CONTEXT_MODULE_INIT_METHOD
+	VALA_CODE_CONTEXT_MODULE_INIT_METHOD,
+	VALA_CODE_CONTEXT_SAVE_TEMPS,
+	VALA_CODE_CONTEXT_SAVE_CSOURCES,
+	VALA_CODE_CONTEXT_SAVE_CHEADERS,
+	VALA_CODE_CONTEXT_ROOT
 };
 static ValaSourceFile* vala_code_context_find_cycle_head (ValaCodeContext* self, ValaSourceFile* file);
-static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file, GList* chain);
+static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file, GeeCollection* chain);
 static gpointer vala_code_context_parent_class = NULL;
 static void vala_code_context_dispose (GObject * obj);
 
 
-/**
- * Returns the root symbol of the code tree.
- *
- * @return root symbol
- */
-ValaSymbol* vala_code_context_get_root (ValaCodeContext* self)
-{
-	ValaSymbol* __temp0;
-	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
-	__temp0 = NULL;
-	return (__temp0 = self->priv->root, (__temp0 == NULL ? NULL : g_object_ref (__temp0)));
-}
-
-
 /**
  * Returns a copy of the list of source files.
  *
  * @return list of source files
  */
-GList* vala_code_context_get_source_files (ValaCodeContext* self)
+GeeCollection* vala_code_context_get_source_files (ValaCodeContext* self)
 {
 	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
-	return g_list_copy (self->priv->source_files);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->source_files)));
+}
+
+
+/**
+ * Returns a copy of the list of C source files.
+ *
+ * @return list of C source files
+ */
+GeeCollection* vala_code_context_get_c_source_files (ValaCodeContext* self)
+{
+	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, GEE_COLLECTION (self->priv->c_source_files)));
 }
 
 
@@ -103,7 +111,20 @@ void vala_code_context_add_source_file (ValaCodeContext* self, ValaSourceFile* f
 {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	g_return_if_fail (VALA_IS_SOURCE_FILE (file));
-	self->priv->source_files = g_list_append (self->priv->source_files, g_object_ref (file));
+	gee_collection_add (GEE_COLLECTION (self->priv->source_files), file);
+}
+
+
+/**
+ * Adds the specified file to the list of C source files.
+ *
+ * @param file a C source file
+ */
+void vala_code_context_add_c_source_file (ValaCodeContext* self, const char* file)
+{
+	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	g_return_if_fail (file != NULL);
+	gee_collection_add (GEE_COLLECTION (self->priv->c_source_files), file);
 }
 
 
@@ -112,10 +133,10 @@ void vala_code_context_add_source_file (ValaCodeContext* self, ValaSourceFile* f
  *
  * @return list of used packages
  */
-GList* vala_code_context_get_packages (ValaCodeContext* self)
+GeeCollection* vala_code_context_get_packages (ValaCodeContext* self)
 {
 	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
-	return g_list_copy (self->priv->packages);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, GEE_COLLECTION (self->priv->packages)));
 }
 
 
@@ -129,7 +150,7 @@ gboolean vala_code_context_has_package (ValaCodeContext* self, const char* pkg)
 {
 	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
 	g_return_val_if_fail (pkg != NULL, FALSE);
-	return g_list_find_custom (self->priv->packages, pkg, ((GCompareFunc) strcmp)) != NULL;
+	return gee_collection_contains (GEE_COLLECTION (self->priv->packages), pkg);
 }
 
 
@@ -142,7 +163,7 @@ void vala_code_context_add_package (ValaCodeContext* self, const char* pkg)
 {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	g_return_if_fail (pkg != NULL);
-	self->priv->packages = g_list_append (self->priv->packages, g_strdup (pkg));
+	gee_collection_add (GEE_COLLECTION (self->priv->packages), pkg);
 }
 
 
@@ -155,18 +176,21 @@ void vala_code_context_accept (ValaCodeContext* self, ValaCodeVisitor* visitor)
 {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_node_accept (VALA_CODE_NODE (vala_code_context_get_root (self)), visitor);
 	{
-		GList* __temp5;
-		GList* file_it;
-		__temp5 = NULL;
-		__temp5 = self->priv->source_files;
-		for (file_it = __temp5; file_it != NULL; file_it = file_it->next) {
+		GeeList* file_collection;
+		GeeIterator* file_it;
+		file_collection = self->priv->source_files;
+		file_it = gee_iterable_iterator (GEE_ITERABLE (file_collection));
+		while (gee_iterator_next (file_it)) {
 			ValaSourceFile* file;
-			file = file_it->data;
+			file = gee_iterator_get (file_it);
 			{
 				vala_source_file_accept (file, visitor);
+				(file == NULL ? NULL : (file = (g_object_unref (file), NULL)));
 			}
 		}
+		(file_it == NULL ? NULL : (file_it = (g_object_unref (file_it), NULL)));
 	}
 }
 
@@ -178,88 +202,104 @@ void vala_code_context_find_header_cycles (ValaCodeContext* self)
 {
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	{
-		GList* __temp6;
-		GList* file_it;
-		__temp6 = NULL;
-		__temp6 = self->priv->source_files;
-		for (file_it = __temp6; file_it != NULL; file_it = file_it->next) {
+		GeeList* file_collection;
+		GeeIterator* file_it;
+		file_collection = self->priv->source_files;
+		file_it = gee_iterable_iterator (GEE_ITERABLE (file_collection));
+		while (gee_iterator_next (file_it)) {
 			ValaSourceFile* file;
-			file = file_it->data;
+			file = gee_iterator_get (file_it);
 			{
 				/* find cycles in dependencies between source files 
 				 we're only interested in internal source files */
 				if (vala_source_file_get_pkg (file)) {
+					(file == NULL ? NULL : (file = (g_object_unref (file), NULL)));
 					continue;
 				}
 				if (vala_source_file_get_mark (file) == 0) {
-					vala_code_context_visit (self, file, NULL);
+					GeeArrayList* _tmp0;
+					_tmp0 = NULL;
+					vala_code_context_visit (self, file, GEE_COLLECTION ((_tmp0 = gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal))));
+					(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 				}
+				(file == NULL ? NULL : (file = (g_object_unref (file), NULL)));
 			}
 		}
+		(file_it == NULL ? NULL : (file_it = (g_object_unref (file_it), NULL)));
 	}
 	{
-		GList* __temp7;
-		GList* cycle_it;
-		__temp7 = NULL;
-		__temp7 = self->priv->cycles;
-		for (cycle_it = __temp7; cycle_it != NULL; cycle_it = cycle_it->next) {
+		GeeList* cycle_collection;
+		GeeIterator* cycle_it;
+		cycle_collection = self->priv->cycles;
+		cycle_it = gee_iterable_iterator (GEE_ITERABLE (cycle_collection));
+		while (gee_iterator_next (cycle_it)) {
 			ValaSourceFileCycle* cycle;
-			cycle = cycle_it->data;
+			cycle = gee_iterator_get (cycle_it);
 			{
 				/* find one head for each cycle, it must not have any
 				 * hard dependencies on other files in the cycle
 				 */
-				cycle->head = vala_code_context_find_cycle_head (self, VALA_SOURCE_FILE (cycle->files->data));
-				(vala_source_file_set_is_cycle_head (cycle->head, TRUE), vala_source_file_get_is_cycle_head (cycle->head));
+				cycle->head = vala_code_context_find_cycle_head (self, gee_list_get (cycle->files, 0));
+				vala_source_file_set_is_cycle_head (cycle->head, TRUE);
+				(cycle == NULL ? NULL : (cycle = (g_object_unref (cycle), NULL)));
 			}
 		}
+		(cycle_it == NULL ? NULL : (cycle_it = (g_object_unref (cycle_it), NULL)));
 	}
 	{
-		GList* __temp11;
-		GList* file2_it;
-		__temp11 = NULL;
-		__temp11 = self->priv->source_files;
-		for (file2_it = __temp11; file2_it != NULL; file2_it = file2_it->next) {
+		GeeList* file2_collection;
+		GeeIterator* file2_it;
+		file2_collection = self->priv->source_files;
+		file2_it = gee_iterable_iterator (GEE_ITERABLE (file2_collection));
+		while (gee_iterator_next (file2_it)) {
 			ValaSourceFile* file2;
-			file2 = file2_it->data;
+			file2 = gee_iterator_get (file2_it);
 			{
 				/* connect the source files in a non-cyclic way
 				 * cycle members connect to the head of their cycle
 				 
 				 we're only interested in internal source files */
 				if (vala_source_file_get_pkg (file2)) {
+					(file2 == NULL ? NULL : (file2 = (g_object_unref (file2), NULL)));
 					continue;
 				}
 				{
-					GList* __temp10;
-					GList* dep_it;
-					__temp10 = NULL;
-					__temp10 = vala_source_file_get_header_internal_dependencies (file2);
-					for (dep_it = __temp10; dep_it != NULL; dep_it = dep_it->next) {
+					GeeCollection* dep_collection;
+					GeeIterator* dep_it;
+					dep_collection = vala_source_file_get_header_internal_dependencies (file2);
+					dep_it = gee_iterable_iterator (GEE_ITERABLE (dep_collection));
+					while (gee_iterator_next (dep_it)) {
+						ValaSourceFile* _tmp3;
 						ValaSourceFile* dep;
-						dep = dep_it->data;
+						_tmp3 = NULL;
+						dep = (_tmp3 = gee_iterator_get (dep_it), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
 						{
 							if (vala_source_file_get_cycle (file2) != NULL && vala_source_file_get_cycle (dep) == vala_source_file_get_cycle (file2)) {
 								/* in the same cycle */
 								if (!vala_source_file_get_is_cycle_head (file2)) {
-									char* __temp8;
+									char* _tmp1;
 									/* include header of cycle head */
-									__temp8 = NULL;
-									vala_source_file_add_header_internal_include (file2, (__temp8 = vala_source_file_get_cinclude_filename (vala_source_file_get_cycle (file2)->head)));
-									(__temp8 = (g_free (__temp8), NULL));
+									_tmp1 = NULL;
+									vala_source_file_add_header_internal_include (file2, (_tmp1 = vala_source_file_get_cinclude_filename (vala_source_file_get_cycle (file2)->head)));
+									(_tmp1 = (g_free (_tmp1), NULL));
 								}
 							} else {
-								char* __temp9;
+								char* _tmp2;
 								/* we can just include the headers if they are not in a cycle or not in the same cycle as the current file */
-								__temp9 = NULL;
-								vala_source_file_add_header_internal_include (file2, (__temp9 = vala_source_file_get_cinclude_filename (dep)));
-								(__temp9 = (g_free (__temp9), NULL));
+								_tmp2 = NULL;
+								vala_source_file_add_header_internal_include (file2, (_tmp2 = vala_source_file_get_cinclude_filename (dep)));
+								(_tmp2 = (g_free (_tmp2), NULL));
 							}
+							(dep == NULL ? NULL : (dep = (g_object_unref (dep), NULL)));
 						}
 					}
+					(dep_collection == NULL ? NULL : (dep_collection = (g_object_unref (dep_collection), NULL)));
+					(dep_it == NULL ? NULL : (dep_it = (g_object_unref (dep_it), NULL)));
 				}
+				(file2 == NULL ? NULL : (file2 = (g_object_unref (file2), NULL)));
 			}
 		}
+		(file2_it == NULL ? NULL : (file2_it = (g_object_unref (file2_it), NULL)));
 	}
 }
 
@@ -269,35 +309,47 @@ static ValaSourceFile* vala_code_context_find_cycle_head (ValaCodeContext* self,
 	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (file), NULL);
 	{
-		GList* __temp14;
-		GList* dep_it;
-		__temp14 = NULL;
-		__temp14 = vala_source_file_get_header_internal_full_dependencies (file);
-		for (dep_it = __temp14; dep_it != NULL; dep_it = dep_it->next) {
+		GeeCollection* dep_collection;
+		GeeIterator* dep_it;
+		dep_collection = vala_source_file_get_header_internal_full_dependencies (file);
+		dep_it = gee_iterable_iterator (GEE_ITERABLE (dep_collection));
+		while (gee_iterator_next (dep_it)) {
+			ValaSourceFile* _tmp2;
 			ValaSourceFile* dep;
-			dep = dep_it->data;
+			_tmp2 = NULL;
+			dep = (_tmp2 = gee_iterator_get (dep_it), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
 			{
 				if (dep == file) {
+					(dep == NULL ? NULL : (dep = (g_object_unref (dep), NULL)));
 					continue;
 				}
 				{
-					GList* __temp13;
-					GList* cycle_file_it;
-					__temp13 = NULL;
-					__temp13 = vala_source_file_get_cycle (file)->files;
-					for (cycle_file_it = __temp13; cycle_file_it != NULL; cycle_file_it = cycle_file_it->next) {
+					GeeList* cycle_file_collection;
+					GeeIterator* cycle_file_it;
+					cycle_file_collection = vala_source_file_get_cycle (file)->files;
+					cycle_file_it = gee_iterable_iterator (GEE_ITERABLE (cycle_file_collection));
+					while (gee_iterator_next (cycle_file_it)) {
+						ValaSourceFile* _tmp1;
 						ValaSourceFile* cycle_file;
-						cycle_file = cycle_file_it->data;
+						_tmp1 = NULL;
+						cycle_file = (_tmp1 = gee_iterator_get (cycle_file_it), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 						{
 							/* ignore file-internal dependencies */
 							if (dep == cycle_file) {
-								return vala_code_context_find_cycle_head (self, dep);
+								ValaSourceFile* _tmp0;
+								_tmp0 = NULL;
+								return (_tmp0 = vala_code_context_find_cycle_head (self, dep), (cycle_file == NULL ? NULL : (cycle_file = (g_object_unref (cycle_file), NULL))), (cycle_file_it == NULL ? NULL : (cycle_file_it = (g_object_unref (cycle_file_it), NULL))), (dep == NULL ? NULL : (dep = (g_object_unref (dep), NULL))), (dep_collection == NULL ? NULL : (dep_collection = (g_object_unref (dep_collection), NULL))), (dep_it == NULL ? NULL : (dep_it = (g_object_unref (dep_it), NULL))), _tmp0);
 							}
+							(cycle_file == NULL ? NULL : (cycle_file = (g_object_unref (cycle_file), NULL)));
 						}
 					}
+					(cycle_file_it == NULL ? NULL : (cycle_file_it = (g_object_unref (cycle_file_it), NULL)));
 				}
+				(dep == NULL ? NULL : (dep = (g_object_unref (dep), NULL)));
 			}
 		}
+		(dep_collection == NULL ? NULL : (dep_collection = (g_object_unref (dep_collection), NULL)));
+		(dep_it == NULL ? NULL : (dep_it = (g_object_unref (dep_it), NULL)));
 	}
 	return file;
 }
@@ -306,160 +358,133 @@ static ValaSourceFile* vala_code_context_find_cycle_head (ValaCodeContext* self,
 /* no hard dependencies on members of the same cycle found
  * source file suitable as cycle head
  */
-static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file, GList* chain)
+static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file, GeeCollection* chain)
 {
-	GList* l;
+	GeeList* l;
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
 	g_return_if_fail (VALA_IS_SOURCE_FILE (file));
-	/* no deep copy available yet
-	 * var l = chain.copy ();
-	 */
-	l = NULL;
+	g_return_if_fail (chain == NULL || GEE_IS_COLLECTION (chain));
+	l = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 	{
-		GList* __temp16;
-		GList* chain_file_it;
-		__temp16 = NULL;
-		__temp16 = chain;
-		for (chain_file_it = __temp16; chain_file_it != NULL; chain_file_it = chain_file_it->next) {
+		GeeCollection* chain_file_collection;
+		GeeIterator* chain_file_it;
+		chain_file_collection = chain;
+		chain_file_it = gee_iterable_iterator (GEE_ITERABLE (chain_file_collection));
+		while (gee_iterator_next (chain_file_it)) {
 			ValaSourceFile* chain_file;
-			chain_file = chain_file_it->data;
+			chain_file = gee_iterator_get (chain_file_it);
 			{
-				l = g_list_append (l, chain_file);
+				gee_collection_add (GEE_COLLECTION (l), chain_file);
+				(chain_file == NULL ? NULL : (chain_file = (g_object_unref (chain_file), NULL)));
 			}
 		}
+		(chain_file_it == NULL ? NULL : (chain_file_it = (g_object_unref (chain_file_it), NULL)));
 	}
-	l = g_list_append (l, file);
-	/* end workaround 
-	 mark file as currently being visited */
-	(vala_source_file_set_mark (file, 1), vala_source_file_get_mark (file));
+	gee_collection_add (GEE_COLLECTION (l), file);
+	/* mark file as currently being visited */
+	vala_source_file_set_mark (file, 1);
 	{
-		GList* __temp26;
-		GList* dep_it;
-		__temp26 = NULL;
-		__temp26 = vala_source_file_get_header_internal_dependencies (file);
-		for (dep_it = __temp26; dep_it != NULL; dep_it = dep_it->next) {
+		GeeCollection* dep_collection;
+		GeeIterator* dep_it;
+		dep_collection = vala_source_file_get_header_internal_dependencies (file);
+		dep_it = gee_iterable_iterator (GEE_ITERABLE (dep_collection));
+		while (gee_iterator_next (dep_it)) {
+			ValaSourceFile* _tmp2;
 			ValaSourceFile* dep;
-			dep = dep_it->data;
+			_tmp2 = NULL;
+			dep = (_tmp2 = gee_iterator_get (dep_it), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
 			{
 				if (file == dep) {
+					(dep == NULL ? NULL : (dep = (g_object_unref (dep), NULL)));
 					continue;
 				}
 				if (vala_source_file_get_mark (dep) == 1) {
 					ValaSourceFileCycle* cycle;
-					ValaSourceFileCycle* __temp17;
 					gboolean cycle_start_found;
 					/* found cycle */
 					cycle = g_object_new (VALA_TYPE_SOURCE_FILE_CYCLE, NULL);
-					__temp17 = NULL;
-					self->priv->cycles = g_list_append (self->priv->cycles, (__temp17 = cycle, (__temp17 == NULL ? NULL : g_object_ref (__temp17))));
+					gee_collection_add (GEE_COLLECTION (self->priv->cycles), cycle);
 					cycle_start_found = FALSE;
 					{
-						GList* __temp25;
-						GList* cycle_file_it;
-						__temp25 = NULL;
-						__temp25 = l;
-						for (cycle_file_it = __temp25; cycle_file_it != NULL; cycle_file_it = cycle_file_it->next) {
+						GeeList* cycle_file_collection;
+						GeeIterator* cycle_file_it;
+						cycle_file_collection = l;
+						cycle_file_it = gee_iterable_iterator (GEE_ITERABLE (cycle_file_collection));
+						while (gee_iterator_next (cycle_file_it)) {
 							ValaSourceFile* cycle_file;
-							cycle_file = cycle_file_it->data;
+							cycle_file = gee_iterator_get (cycle_file_it);
 							{
-								ValaSourceFileCycle* __temp18;
+								ValaSourceFileCycle* _tmp0;
 								ValaSourceFileCycle* ref_cycle_file_cycle;
-								__temp18 = NULL;
-								ref_cycle_file_cycle = (__temp18 = vala_source_file_get_cycle (cycle_file), (__temp18 == NULL ? NULL : g_object_ref (__temp18)));
+								_tmp0 = NULL;
+								ref_cycle_file_cycle = (_tmp0 = vala_source_file_get_cycle (cycle_file), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 								if (!cycle_start_found) {
 									if (cycle_file == dep) {
 										cycle_start_found = TRUE;
 									}
 								}
 								if (!cycle_start_found) {
+									(cycle_file == NULL ? NULL : (cycle_file = (g_object_unref (cycle_file), NULL)));
+									(ref_cycle_file_cycle == NULL ? NULL : (ref_cycle_file_cycle = (g_object_unref (ref_cycle_file_cycle), NULL)));
 									continue;
 								}
 								if (vala_source_file_get_cycle (cycle_file) != NULL) {
-									GList* newlist;
-									GList* __temp20;
-									GList* __temp23;
 									/* file already in a cycle */
 									if (vala_source_file_get_cycle (cycle_file) == cycle) {
+										(cycle_file == NULL ? NULL : (cycle_file = (g_object_unref (cycle_file), NULL)));
+										(ref_cycle_file_cycle == NULL ? NULL : (ref_cycle_file_cycle = (g_object_unref (ref_cycle_file_cycle), NULL)));
 										continue;
 									}
 									/* file is in the same cycle, nothing to do 
-									 file is in an other cycle, merge the two cycles 
-									 broken memory management cycles.remove (cycle_file.cycle); */
-									newlist = NULL;
+									 file is in an other cycle, merge the two cycles */
+									gee_collection_remove (GEE_COLLECTION (self->priv->cycles), vala_source_file_get_cycle (cycle_file));
 									{
-										GList* __temp19;
-										GList* oldcycle_it;
-										__temp19 = NULL;
-										__temp19 = self->priv->cycles;
-										for (oldcycle_it = __temp19; oldcycle_it != NULL; oldcycle_it = oldcycle_it->next) {
-											ValaSourceFileCycle* oldcycle;
-											oldcycle = oldcycle_it->data;
-											{
-												if (oldcycle != vala_source_file_get_cycle (cycle_file)) {
-													newlist = g_list_append (newlist, oldcycle);
-												}
-											}
-										}
-									}
-									__temp20 = NULL;
-									self->priv->cycles = (__temp20 = NULL, (self->priv->cycles == NULL ? NULL : (self->priv->cycles = (g_list_foreach (self->priv->cycles, (GFunc) g_object_unref, NULL), g_list_free (self->priv->cycles), NULL))), __temp20);
-									{
-										GList* __temp22;
-										GList* newcycle_it;
-										__temp22 = NULL;
-										__temp22 = newlist;
-										for (newcycle_it = __temp22; newcycle_it != NULL; newcycle_it = newcycle_it->next) {
-											ValaSourceFileCycle* newcycle;
-											newcycle = newcycle_it->data;
-											{
-												ValaSourceFileCycle* __temp21;
-												__temp21 = NULL;
-												self->priv->cycles = g_list_append (self->priv->cycles, (__temp21 = newcycle, (__temp21 == NULL ? NULL : g_object_ref (__temp21))));
-											}
-										}
-									}
-									__temp23 = NULL;
-									newlist = (__temp23 = NULL, (newlist == NULL ? NULL : (newlist = (g_list_free (newlist), NULL))), __temp23);
-									{
-										GList* __temp24;
-										GList* inner_cycle_file_it;
-										__temp24 = NULL;
-										__temp24 = vala_source_file_get_cycle (cycle_file)->files;
-										for (inner_cycle_file_it = __temp24; inner_cycle_file_it != NULL; inner_cycle_file_it = inner_cycle_file_it->next) {
+										GeeList* inner_cycle_file_collection;
+										GeeIterator* inner_cycle_file_it;
+										inner_cycle_file_collection = vala_source_file_get_cycle (cycle_file)->files;
+										inner_cycle_file_it = gee_iterable_iterator (GEE_ITERABLE (inner_cycle_file_collection));
+										while (gee_iterator_next (inner_cycle_file_it)) {
+											ValaSourceFile* _tmp1;
 											ValaSourceFile* inner_cycle_file;
-											inner_cycle_file = inner_cycle_file_it->data;
+											_tmp1 = NULL;
+											inner_cycle_file = (_tmp1 = gee_iterator_get (inner_cycle_file_it), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 											{
-												/* end workaround for broken memory management */
 												if (vala_source_file_get_cycle (inner_cycle_file) != cycle) {
 													/* file in inner cycle not yet added to outer cycle */
-													cycle->files = g_list_append (cycle->files, inner_cycle_file);
-													(vala_source_file_set_cycle (inner_cycle_file, cycle), vala_source_file_get_cycle (inner_cycle_file));
+													gee_collection_add (GEE_COLLECTION (cycle->files), inner_cycle_file);
+													vala_source_file_set_cycle (inner_cycle_file, cycle);
 												}
+												(inner_cycle_file == NULL ? NULL : (inner_cycle_file = (g_object_unref (inner_cycle_file), NULL)));
 											}
 										}
+										(inner_cycle_file_it == NULL ? NULL : (inner_cycle_file_it = (g_object_unref (inner_cycle_file_it), NULL)));
 									}
-									(newlist == NULL ? NULL : (newlist = (g_list_free (newlist), NULL)));
 								} else {
-									cycle->files = g_list_append (cycle->files, cycle_file);
-									(vala_source_file_set_cycle (cycle_file, cycle), vala_source_file_get_cycle (cycle_file));
+									gee_collection_add (GEE_COLLECTION (cycle->files), cycle_file);
+									vala_source_file_set_cycle (cycle_file, cycle);
 								}
+								(cycle_file == NULL ? NULL : (cycle_file = (g_object_unref (cycle_file), NULL)));
 								(ref_cycle_file_cycle == NULL ? NULL : (ref_cycle_file_cycle = (g_object_unref (ref_cycle_file_cycle), NULL)));
 							}
 						}
+						(cycle_file_it == NULL ? NULL : (cycle_file_it = (g_object_unref (cycle_file_it), NULL)));
 					}
 					(cycle == NULL ? NULL : (cycle = (g_object_unref (cycle), NULL)));
 				} else {
 					if (vala_source_file_get_mark (dep) == 0) {
 						/* found not yet visited file */
-						vala_code_context_visit (self, dep, l);
+						vala_code_context_visit (self, dep, GEE_COLLECTION (l));
 					}
 				}
+				(dep == NULL ? NULL : (dep = (g_object_unref (dep), NULL)));
 			}
 		}
+		(dep_collection == NULL ? NULL : (dep_collection = (g_object_unref (dep_collection), NULL)));
+		(dep_it == NULL ? NULL : (dep_it = (g_object_unref (dep_it), NULL)));
 	}
 	/* mark file as successfully visited */
-	(vala_source_file_set_mark (file, 2), vala_source_file_get_mark (file));
-	(l == NULL ? NULL : (l = (g_list_free (l), NULL)));
+	vala_source_file_set_mark (file, 2);
+	(l == NULL ? NULL : (l = (g_object_unref (l), NULL)));
 }
 
 
@@ -472,12 +497,12 @@ char* vala_code_context_get_library (ValaCodeContext* self)
 
 void vala_code_context_set_library (ValaCodeContext* self, const char* value)
 {
-	char* __temp29;
-	const char* __temp28;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
-	__temp29 = NULL;
-	__temp28 = NULL;
-	self->priv->_library = (__temp29 = (__temp28 = value, (__temp28 == NULL ? NULL : g_strdup (__temp28))), (self->priv->_library = (g_free (self->priv->_library), NULL)), __temp29);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_library = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_library = (g_free (self->priv->_library), NULL)), _tmp2);
 }
 
 
@@ -560,12 +585,30 @@ char* vala_code_context_get_output (ValaCodeContext* self)
 
 void vala_code_context_set_output (ValaCodeContext* self, const char* value)
 {
-	char* __temp37;
-	const char* __temp36;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
-	__temp37 = NULL;
-	__temp36 = NULL;
-	self->priv->_output = (__temp37 = (__temp36 = value, (__temp36 == NULL ? NULL : g_strdup (__temp36))), (self->priv->_output = (g_free (self->priv->_output), NULL)), __temp37);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_output = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_output = (g_free (self->priv->_output), NULL)), _tmp2);
+}
+
+
+char* vala_code_context_get_directory (ValaCodeContext* self)
+{
+	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
+	return self->priv->_directory;
+}
+
+
+void vala_code_context_set_directory (ValaCodeContext* self, const char* value)
+{
+	char* _tmp2;
+	const char* _tmp1;
+	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_directory = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_directory = (g_free (self->priv->_directory), NULL)), _tmp2);
 }
 
 
@@ -620,12 +663,47 @@ ValaMethod* vala_code_context_get_module_init_method (ValaCodeContext* self)
 
 void vala_code_context_set_module_init_method (ValaCodeContext* self, ValaMethod* value)
 {
-	ValaMethod* __temp43;
-	ValaMethod* __temp42;
+	ValaMethod* _tmp2;
+	ValaMethod* _tmp1;
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
-	__temp43 = NULL;
-	__temp42 = NULL;
-	self->priv->_module_init_method = (__temp43 = (__temp42 = value, (__temp42 == NULL ? NULL : g_object_ref (__temp42))), (self->priv->_module_init_method == NULL ? NULL : (self->priv->_module_init_method = (g_object_unref (self->priv->_module_init_method), NULL))), __temp43);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_module_init_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_module_init_method == NULL ? NULL : (self->priv->_module_init_method = (g_object_unref (self->priv->_module_init_method), NULL))), _tmp2);
+}
+
+
+gboolean vala_code_context_get_save_temps (ValaCodeContext* self)
+{
+	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	return self->priv->_save_temps;
+}
+
+
+void vala_code_context_set_save_temps (ValaCodeContext* self, gboolean value)
+{
+	g_return_if_fail (VALA_IS_CODE_CONTEXT (self));
+	self->priv->_save_temps = value;
+}
+
+
+gboolean vala_code_context_get_save_csources (ValaCodeContext* self)
+{
+	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	return vala_code_context_get_save_temps (self);
+}
+
+
+gboolean vala_code_context_get_save_cheaders (ValaCodeContext* self)
+{
+	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), FALSE);
+	return vala_code_context_get_save_csources (self) || NULL != vala_code_context_get_library (self);
+}
+
+
+ValaNamespace* vala_code_context_get_root (ValaCodeContext* self)
+{
+	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (self), NULL);
+	return self->priv->_root;
 }
 
 
@@ -655,6 +733,9 @@ static void vala_code_context_get_property (GObject * object, guint property_id,
 		case VALA_CODE_CONTEXT_OUTPUT:
 		g_value_set_string (value, vala_code_context_get_output (self));
 		break;
+		case VALA_CODE_CONTEXT_DIRECTORY:
+		g_value_set_string (value, vala_code_context_get_directory (self));
+		break;
 		case VALA_CODE_CONTEXT_DEBUG:
 		g_value_set_boolean (value, vala_code_context_get_debug (self));
 		break;
@@ -667,6 +748,21 @@ static void vala_code_context_get_property (GObject * object, guint property_id,
 		case VALA_CODE_CONTEXT_MODULE_INIT_METHOD:
 		g_value_set_object (value, vala_code_context_get_module_init_method (self));
 		break;
+		case VALA_CODE_CONTEXT_SAVE_TEMPS:
+		g_value_set_boolean (value, vala_code_context_get_save_temps (self));
+		break;
+		case VALA_CODE_CONTEXT_SAVE_CSOURCES:
+		g_value_set_boolean (value, vala_code_context_get_save_csources (self));
+		break;
+		case VALA_CODE_CONTEXT_SAVE_CHEADERS:
+		g_value_set_boolean (value, vala_code_context_get_save_cheaders (self));
+		break;
+		case VALA_CODE_CONTEXT_ROOT:
+		g_value_set_object (value, vala_code_context_get_root (self));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -697,6 +793,9 @@ static void vala_code_context_set_property (GObject * object, guint property_id,
 		case VALA_CODE_CONTEXT_OUTPUT:
 		vala_code_context_set_output (self, g_value_get_string (value));
 		break;
+		case VALA_CODE_CONTEXT_DIRECTORY:
+		vala_code_context_set_directory (self, g_value_get_string (value));
+		break;
 		case VALA_CODE_CONTEXT_DEBUG:
 		vala_code_context_set_debug (self, g_value_get_boolean (value));
 		break;
@@ -709,6 +808,12 @@ static void vala_code_context_set_property (GObject * object, guint property_id,
 		case VALA_CODE_CONTEXT_MODULE_INIT_METHOD:
 		vala_code_context_set_module_init_method (self, g_value_get_object (value));
 		break;
+		case VALA_CODE_CONTEXT_SAVE_TEMPS:
+		vala_code_context_set_save_temps (self, g_value_get_boolean (value));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -727,17 +832,26 @@ static void vala_code_context_class_init (ValaCodeContextClass * klass)
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_CCODE_ONLY, g_param_spec_boolean ("ccode-only", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_COMPILE_ONLY, g_param_spec_boolean ("compile-only", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_OUTPUT, g_param_spec_string ("output", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_DIRECTORY, g_param_spec_string ("directory", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_DEBUG, g_param_spec_boolean ("debug", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_OPTLEVEL, g_param_spec_int ("optlevel", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_THREAD, g_param_spec_boolean ("thread", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_MODULE_INIT_METHOD, g_param_spec_object ("module-init-method", "foo", "bar", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_SAVE_TEMPS, g_param_spec_boolean ("save-temps", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_SAVE_CSOURCES, g_param_spec_boolean ("save-csources", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_SAVE_CHEADERS, g_param_spec_boolean ("save-cheaders", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_CONTEXT_ROOT, g_param_spec_object ("root", "foo", "bar", VALA_TYPE_NAMESPACE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
 
 static void vala_code_context_init (ValaCodeContext * self)
 {
 	self->priv = VALA_CODE_CONTEXT_GET_PRIVATE (self);
-	self->priv->root = vala_symbol_new (NULL);
+	self->priv->source_files = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->c_source_files = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_direct_equal));
+	self->priv->_root = vala_namespace_new (NULL, NULL);
+	self->priv->cycles = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->packages = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_str_equal));
 }
 
 
@@ -749,18 +863,20 @@ static void vala_code_context_dispose (GObject * obj)
 	self = VALA_CODE_CONTEXT (obj);
 	(self->priv->_library = (g_free (self->priv->_library), NULL));
 	(self->priv->_output = (g_free (self->priv->_output), NULL));
+	(self->priv->_directory = (g_free (self->priv->_directory), NULL));
 	(self->priv->_module_init_method == NULL ? NULL : (self->priv->_module_init_method = (g_object_unref (self->priv->_module_init_method), NULL)));
-	(self->priv->source_files == NULL ? NULL : (self->priv->source_files = (g_list_foreach (self->priv->source_files, (GFunc) g_object_unref, NULL), g_list_free (self->priv->source_files), NULL)));
-	(self->priv->root == NULL ? NULL : (self->priv->root = (g_object_unref (self->priv->root), NULL)));
-	(self->priv->cycles == NULL ? NULL : (self->priv->cycles = (g_list_foreach (self->priv->cycles, (GFunc) g_object_unref, NULL), g_list_free (self->priv->cycles), NULL)));
-	(self->priv->packages == NULL ? NULL : (self->priv->packages = (g_list_foreach (self->priv->packages, (GFunc) g_free, NULL), g_list_free (self->priv->packages), NULL)));
+	(self->priv->source_files == NULL ? NULL : (self->priv->source_files = (g_object_unref (self->priv->source_files), NULL)));
+	(self->priv->c_source_files == NULL ? NULL : (self->priv->c_source_files = (g_object_unref (self->priv->c_source_files), NULL)));
+	(self->priv->_root == NULL ? NULL : (self->priv->_root = (g_object_unref (self->priv->_root), NULL)));
+	(self->priv->cycles == NULL ? NULL : (self->priv->cycles = (g_object_unref (self->priv->cycles), NULL)));
+	(self->priv->packages == NULL ? NULL : (self->priv->packages = (g_object_unref (self->priv->packages), NULL)));
 	klass = VALA_CODE_CONTEXT_CLASS (g_type_class_peek (VALA_TYPE_CODE_CONTEXT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_code_context_get_type ()
+GType vala_code_context_get_type (void)
 {
 	static GType vala_code_context_type_id = 0;
 	if (G_UNLIKELY (vala_code_context_type_id == 0)) {
