@@ -117,10 +117,10 @@ ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* nam
 		GList* a_it;
 		a_collection = self->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* __temp1;
+			ValaAttribute* _tmp1;
 			ValaAttribute* a;
-			__temp1 = NULL;
-			a = (__temp1 = a_it->data, (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
+			_tmp1 = NULL;
+			a = (_tmp1 = a_it->data, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 			{
 				/* FIXME: use hash table*/
 				if (g_utf8_collate (vala_attribute_get_name (a), name) == 0) {
@@ -141,11 +141,22 @@ ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* nam
  */
 static char* vala_code_node_real_to_string (ValaCodeNode* self)
 {
+	GString* str;
+	const char* _tmp1;
+	char* _tmp2;
 	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	str = g_string_new ("");
+	g_string_append (g_string_append (str, "/* "), g_type_name (G_TYPE_FROM_INSTANCE (G_OBJECT (self))));
 	if (vala_code_node_get_source_reference (self) != NULL) {
-		return vala_source_reference_to_string (vala_code_node_get_source_reference (self));
+		char* _tmp0;
+		_tmp0 = NULL;
+		g_string_append (g_string_append (str, "@"), (_tmp0 = vala_source_reference_to_string (vala_code_node_get_source_reference (self))));
+		(_tmp0 = (g_free (_tmp0), NULL));
 	}
-	return g_strdup ("(unknown)");
+	_tmp1 = NULL;
+	_tmp2 = NULL;
+	return (_tmp2 = (_tmp1 = g_string_append (str, " */")->str, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), _tmp2);
+	(str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL)));
 }
 
 
@@ -178,12 +189,12 @@ ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self)
 
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value)
 {
-	ValaSourceReference* __temp8;
-	ValaSourceReference* __temp7;
+	ValaSourceReference* _tmp2;
+	ValaSourceReference* _tmp1;
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	__temp8 = NULL;
-	__temp7 = NULL;
-	self->priv->_source_reference = (__temp8 = (__temp7 = value, (__temp7 == NULL ? NULL : g_object_ref (__temp7))), (self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (g_object_unref (self->priv->_source_reference), NULL))), __temp8);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_source_reference = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (g_object_unref (self->priv->_source_reference), NULL))), _tmp2);
 }
 
 
@@ -196,18 +207,18 @@ ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self)
 
 void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value)
 {
-	ValaCCodeNode* __temp12;
-	ValaCCodeNode* __temp11;
+	ValaCCodeNode* _tmp3;
+	ValaCCodeNode* _tmp2;
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
 	if (vala_code_node_get_source_reference (self) != NULL) {
-		ValaCCodeLineDirective* __temp10;
-		__temp10 = NULL;
-		vala_ccode_node_set_line (value, (__temp10 = vala_ccode_line_directive_new (vala_source_file_get_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (self))), vala_source_reference_get_first_line (vala_code_node_get_source_reference (self)))));
-		(__temp10 == NULL ? NULL : (__temp10 = (g_object_unref (__temp10), NULL)));
+		ValaCCodeLineDirective* _tmp1;
+		_tmp1 = NULL;
+		vala_ccode_node_set_line (value, (_tmp1 = vala_ccode_line_directive_new (vala_source_file_get_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (self))), vala_source_reference_get_first_line (vala_code_node_get_source_reference (self)))));
+		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 	}
-	__temp12 = NULL;
-	__temp11 = NULL;
-	self->priv->_ccodenode = (__temp12 = (__temp11 = value, (__temp11 == NULL ? NULL : g_object_ref (__temp11))), (self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (g_object_unref (self->priv->_ccodenode), NULL))), __temp12);
+	_tmp3 = NULL;
+	_tmp2 = NULL;
+	self->priv->_ccodenode = (_tmp3 = (_tmp2 = value, (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (g_object_unref (self->priv->_ccodenode), NULL))), _tmp3);
 }
 
 
@@ -259,6 +270,9 @@ static void vala_code_node_get_property (GObject * object, guint property_id, GV
 		case VALA_CODE_NODE_TREE_CAN_FAIL:
 		g_value_set_boolean (value, vala_code_node_get_tree_can_fail (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -283,6 +297,9 @@ static void vala_code_node_set_property (GObject * object, guint property_id, co
 		case VALA_CODE_NODE_TREE_CAN_FAIL:
 		vala_code_node_set_tree_can_fail (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -319,7 +336,7 @@ static void vala_code_node_dispose (GObject * obj)
 	GObjectClass * parent_class;
 	self = VALA_CODE_NODE (obj);
 	(self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (g_object_unref (self->priv->_source_reference), NULL)));
-	(self->attributes == NULL ? NULL : (self->attributes = (g_list_foreach (self->attributes, (GFunc) g_object_unref, NULL), g_list_free (self->attributes), NULL)));
+	(self->attributes == NULL ? NULL : (self->attributes = (g_list_foreach (self->attributes, ((GFunc) g_object_unref), NULL), g_list_free (self->attributes), NULL)));
 	(self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (g_object_unref (self->priv->_ccodenode), NULL)));
 	klass = VALA_CODE_NODE_CLASS (g_type_class_peek (VALA_TYPE_CODE_NODE));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
