@@ -20,8 +20,6 @@
  * 	Jürg Billeter <j@bitron.ch>
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valacodevisitor.h"
 #include <vala/valasourcefile.h>
@@ -31,8 +29,6 @@
 #include <vala/valainterface.h>
 #include <vala/valaenum.h>
 #include <vala/valaenumvalue.h>
-#include <vala/valaflags.h>
-#include <vala/valaflagsvalue.h>
 #include <vala/valacallback.h>
 #include <vala/valamember.h>
 #include <vala/valaconstant.h>
@@ -110,8 +106,6 @@ static void vala_code_visitor_real_visit_struct (ValaCodeVisitor* self, ValaStru
 static void vala_code_visitor_real_visit_interface (ValaCodeVisitor* self, ValaInterface* iface);
 static void vala_code_visitor_real_visit_enum (ValaCodeVisitor* self, ValaEnum* en);
 static void vala_code_visitor_real_visit_enum_value (ValaCodeVisitor* self, ValaEnumValue* ev);
-static void vala_code_visitor_real_visit_flags (ValaCodeVisitor* self, ValaFlags* fl);
-static void vala_code_visitor_real_visit_flags_value (ValaCodeVisitor* self, ValaFlagsValue* fv);
 static void vala_code_visitor_real_visit_callback (ValaCodeVisitor* self, ValaCallback* cb);
 static void vala_code_visitor_real_visit_member (ValaCodeVisitor* self, ValaMember* m);
 static void vala_code_visitor_real_visit_constant (ValaCodeVisitor* self, ValaConstant* c);
@@ -134,8 +128,7 @@ static void vala_code_visitor_real_visit_empty_statement (ValaCodeVisitor* self,
 static void vala_code_visitor_real_visit_declaration_statement (ValaCodeVisitor* self, ValaDeclarationStatement* stmt);
 static void vala_code_visitor_real_visit_local_variable_declaration (ValaCodeVisitor* self, ValaLocalVariableDeclaration* decl);
 static void vala_code_visitor_real_visit_variable_declarator (ValaCodeVisitor* self, ValaVariableDeclarator* decl);
-static void vala_code_visitor_real_visit_begin_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list);
-static void vala_code_visitor_real_visit_end_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list);
+static void vala_code_visitor_real_visit_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list);
 static void vala_code_visitor_real_visit_expression_statement (ValaCodeVisitor* self, ValaExpressionStatement* stmt);
 static void vala_code_visitor_real_visit_if_statement (ValaCodeVisitor* self, ValaIfStatement* stmt);
 static void vala_code_visitor_real_visit_switch_statement (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
@@ -150,15 +143,11 @@ static void vala_code_visitor_real_visit_break_statement (ValaCodeVisitor* self,
 static void vala_code_visitor_real_visit_continue_statement (ValaCodeVisitor* self, ValaContinueStatement* stmt);
 static void vala_code_visitor_real_visit_begin_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt);
 static void vala_code_visitor_real_visit_end_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt);
-static void vala_code_visitor_real_visit_begin_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt);
-static void vala_code_visitor_real_visit_end_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt);
-static void vala_code_visitor_real_visit_begin_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt);
-static void vala_code_visitor_real_visit_end_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt);
-static void vala_code_visitor_real_visit_begin_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
-static void vala_code_visitor_real_visit_end_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
+static void vala_code_visitor_real_visit_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt);
+static void vala_code_visitor_real_visit_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt);
+static void vala_code_visitor_real_visit_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
 static void vala_code_visitor_real_visit_lock_statement (ValaCodeVisitor* self, ValaLockStatement* stmt);
-static void vala_code_visitor_real_visit_begin_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
-static void vala_code_visitor_real_visit_end_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
+static void vala_code_visitor_real_visit_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
 static void vala_code_visitor_real_visit_boolean_literal (ValaCodeVisitor* self, ValaBooleanLiteral* lit);
 static void vala_code_visitor_real_visit_character_literal (ValaCodeVisitor* self, ValaCharacterLiteral* lit);
 static void vala_code_visitor_real_visit_integer_literal (ValaCodeVisitor* self, ValaIntegerLiteral* lit);
@@ -319,42 +308,6 @@ void vala_code_visitor_visit_enum_value (ValaCodeVisitor* self, ValaEnumValue* e
 }
 
 
-/**
- * Visit operation called for flags.
- *
- * @param fl a flags
- */
-static void vala_code_visitor_real_visit_flags (ValaCodeVisitor* self, ValaFlags* fl)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_FLAGS (fl));
-}
-
-
-void vala_code_visitor_visit_flags (ValaCodeVisitor* self, ValaFlags* fl)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_flags (self, fl);
-}
-
-
-/**
- * Visit operation called for flags values.
- *
- * @param fv an flags value
- */
-static void vala_code_visitor_real_visit_flags_value (ValaCodeVisitor* self, ValaFlagsValue* fv)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_FLAGS_VALUE (fv));
-}
-
-
-void vala_code_visitor_visit_flags_value (ValaCodeVisitor* self, ValaFlagsValue* fv)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_flags_value (self, fv);
-}
-
-
 /**
  * Visit operation called for callbacks.
  *
@@ -756,34 +709,16 @@ void vala_code_visitor_visit_variable_declarator (ValaCodeVisitor* self, ValaVar
  *
  * @param list an initializer list
  */
-static void vala_code_visitor_real_visit_begin_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list)
+static void vala_code_visitor_real_visit_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_INITIALIZER_LIST (list));
 }
 
 
-void vala_code_visitor_visit_begin_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list)
+void vala_code_visitor_visit_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_initializer_list (self, list);
-}
-
-
-/**
- * Visit operation called for initializer lists
- *
- * @param list an initializer list
- */
-static void vala_code_visitor_real_visit_end_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_INITIALIZER_LIST (list));
-}
-
-
-void vala_code_visitor_visit_end_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_initializer_list (self, list);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_initializer_list (self, list);
 }
 
 
@@ -1040,110 +975,56 @@ void vala_code_visitor_visit_end_return_statement (ValaCodeVisitor* self, ValaRe
 
 
 /**
- * Visit operation called at beginning of throw statements.
+ * Visit operation called for throw statements.
  *
  * @param stmt a throw statement
  */
-static void vala_code_visitor_real_visit_begin_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt)
+static void vala_code_visitor_real_visit_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_THROW_STATEMENT (stmt));
 }
 
 
-void vala_code_visitor_visit_begin_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt)
+void vala_code_visitor_visit_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_throw_statement (self, stmt);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_throw_statement (self, stmt);
 }
 
 
 /**
- * Visit operation called at end of throw statements.
- *
- * @param stmt a throw statement
- */
-static void vala_code_visitor_real_visit_end_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_THROW_STATEMENT (stmt));
-}
-
-
-void vala_code_visitor_visit_end_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_throw_statement (self, stmt);
-}
-
-
-/**
- * Visit operation called at beginning of try statements.
+ * Visit operation called for try statements.
  *
  * @param stmt a try statement
  */
-static void vala_code_visitor_real_visit_begin_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt)
+static void vala_code_visitor_real_visit_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_TRY_STATEMENT (stmt));
 }
 
 
-void vala_code_visitor_visit_begin_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt)
+void vala_code_visitor_visit_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_try_statement (self, stmt);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_try_statement (self, stmt);
 }
 
 
 /**
- * Visit operation called at end of try statements.
- *
- * @param stmt a try statement
- */
-static void vala_code_visitor_real_visit_end_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_TRY_STATEMENT (stmt));
-}
-
-
-void vala_code_visitor_visit_end_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_try_statement (self, stmt);
-}
-
-
-/**
- * Visit operation called at beginning of catch clauses.
+ * Visit operation called for catch clauses.
  *
  * @param clause a catch cluase
  */
-static void vala_code_visitor_real_visit_begin_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause)
+static void vala_code_visitor_real_visit_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_CATCH_CLAUSE (clause));
 }
 
 
-void vala_code_visitor_visit_begin_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause)
+void vala_code_visitor_visit_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_catch_clause (self, clause);
-}
-
-
-/**
- * Visit operation called at end of catch clauses.
- *
- * @param clause a catch clause
- */
-static void vala_code_visitor_real_visit_end_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_CATCH_CLAUSE (clause));
-}
-
-
-void vala_code_visitor_visit_end_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_catch_clause (self, clause);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_catch_clause (self, clause);
 }
 
 
@@ -1170,34 +1051,16 @@ void vala_code_visitor_visit_lock_statement (ValaCodeVisitor* self, ValaLockStat
  *
  * @param expr an array creation expression
  */
-static void vala_code_visitor_real_visit_begin_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr)
+static void vala_code_visitor_real_visit_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (expr));
 }
 
 
-void vala_code_visitor_visit_begin_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr)
+void vala_code_visitor_visit_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_array_creation_expression (self, expr);
-}
-
-
-/**
- * Visit operations called for array creation expresions.
- *
- * @param expr an array creation expression
- */
-static void vala_code_visitor_real_visit_end_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (expr));
-}
-
-
-void vala_code_visitor_visit_end_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_array_creation_expression (self, expr);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_array_creation_expression (self, expr);
 }
 
 
@@ -1770,8 +1633,6 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass)
 	VALA_CODE_VISITOR_CLASS (klass)->visit_interface = vala_code_visitor_real_visit_interface;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum = vala_code_visitor_real_visit_enum;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum_value = vala_code_visitor_real_visit_enum_value;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_flags = vala_code_visitor_real_visit_flags;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_flags_value = vala_code_visitor_real_visit_flags_value;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_callback = vala_code_visitor_real_visit_callback;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_member = vala_code_visitor_real_visit_member;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_constant = vala_code_visitor_real_visit_constant;
@@ -1794,8 +1655,7 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass)
 	VALA_CODE_VISITOR_CLASS (klass)->visit_declaration_statement = vala_code_visitor_real_visit_declaration_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_local_variable_declaration = vala_code_visitor_real_visit_local_variable_declaration;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_variable_declarator = vala_code_visitor_real_visit_variable_declarator;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_initializer_list = vala_code_visitor_real_visit_begin_initializer_list;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_initializer_list = vala_code_visitor_real_visit_end_initializer_list;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_initializer_list = vala_code_visitor_real_visit_initializer_list;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_expression_statement = vala_code_visitor_real_visit_expression_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_if_statement = vala_code_visitor_real_visit_if_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_switch_statement = vala_code_visitor_real_visit_switch_statement;
@@ -1810,15 +1670,11 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass)
 	VALA_CODE_VISITOR_CLASS (klass)->visit_continue_statement = vala_code_visitor_real_visit_continue_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_return_statement = vala_code_visitor_real_visit_begin_return_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_end_return_statement = vala_code_visitor_real_visit_end_return_statement;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_throw_statement = vala_code_visitor_real_visit_begin_throw_statement;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_throw_statement = vala_code_visitor_real_visit_end_throw_statement;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_try_statement = vala_code_visitor_real_visit_begin_try_statement;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_try_statement = vala_code_visitor_real_visit_end_try_statement;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_catch_clause = vala_code_visitor_real_visit_begin_catch_clause;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_catch_clause = vala_code_visitor_real_visit_end_catch_clause;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_throw_statement = vala_code_visitor_real_visit_throw_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_try_statement = vala_code_visitor_real_visit_try_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_catch_clause = vala_code_visitor_real_visit_catch_clause;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_lock_statement = vala_code_visitor_real_visit_lock_statement;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_array_creation_expression = vala_code_visitor_real_visit_begin_array_creation_expression;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_array_creation_expression = vala_code_visitor_real_visit_end_array_creation_expression;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_array_creation_expression = vala_code_visitor_real_visit_array_creation_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_boolean_literal = vala_code_visitor_real_visit_boolean_literal;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_character_literal = vala_code_visitor_real_visit_character_literal;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_integer_literal = vala_code_visitor_real_visit_integer_literal;
@@ -1858,7 +1714,7 @@ static void vala_code_visitor_init (ValaCodeVisitor * self)
 }
 
 
-GType vala_code_visitor_get_type ()
+GType vala_code_visitor_get_type (void)
 {
 	static GType vala_code_visitor_type_id = 0;
 	if (G_UNLIKELY (vala_code_visitor_type_id == 0)) {
