@@ -78,8 +78,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_declaration_statement) (ValaCodeVisitor* self, ValaDeclarationStatement* stmt);
 	void (*visit_local_variable_declaration) (ValaCodeVisitor* self, ValaLocalVariableDeclaration* decl);
 	void (*visit_variable_declarator) (ValaCodeVisitor* self, ValaVariableDeclarator* decl);
-	void (*visit_begin_initializer_list) (ValaCodeVisitor* self, ValaInitializerList* list);
-	void (*visit_end_initializer_list) (ValaCodeVisitor* self, ValaInitializerList* list);
+	void (*visit_initializer_list) (ValaCodeVisitor* self, ValaInitializerList* list);
 	void (*visit_expression_statement) (ValaCodeVisitor* self, ValaExpressionStatement* stmt);
 	void (*visit_if_statement) (ValaCodeVisitor* self, ValaIfStatement* stmt);
 	void (*visit_switch_statement) (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
@@ -98,8 +97,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_try_statement) (ValaCodeVisitor* self, ValaTryStatement* stmt);
 	void (*visit_catch_clause) (ValaCodeVisitor* self, ValaCatchClause* clause);
 	void (*visit_lock_statement) (ValaCodeVisitor* self, ValaLockStatement* stmt);
-	void (*visit_begin_array_creation_expression) (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
-	void (*visit_end_array_creation_expression) (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
+	void (*visit_array_creation_expression) (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
 	void (*visit_boolean_literal) (ValaCodeVisitor* self, ValaBooleanLiteral* lit);
 	void (*visit_character_literal) (ValaCodeVisitor* self, ValaCharacterLiteral* lit);
 	void (*visit_integer_literal) (ValaCodeVisitor* self, ValaIntegerLiteral* lit);
@@ -162,8 +160,7 @@ void vala_code_visitor_visit_empty_statement (ValaCodeVisitor* self, ValaEmptySt
 void vala_code_visitor_visit_declaration_statement (ValaCodeVisitor* self, ValaDeclarationStatement* stmt);
 void vala_code_visitor_visit_local_variable_declaration (ValaCodeVisitor* self, ValaLocalVariableDeclaration* decl);
 void vala_code_visitor_visit_variable_declarator (ValaCodeVisitor* self, ValaVariableDeclarator* decl);
-void vala_code_visitor_visit_begin_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list);
-void vala_code_visitor_visit_end_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list);
+void vala_code_visitor_visit_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list);
 void vala_code_visitor_visit_expression_statement (ValaCodeVisitor* self, ValaExpressionStatement* stmt);
 void vala_code_visitor_visit_if_statement (ValaCodeVisitor* self, ValaIfStatement* stmt);
 void vala_code_visitor_visit_switch_statement (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
@@ -182,8 +179,7 @@ void vala_code_visitor_visit_throw_statement (ValaCodeVisitor* self, ValaThrowSt
 void vala_code_visitor_visit_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt);
 void vala_code_visitor_visit_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
 void vala_code_visitor_visit_lock_statement (ValaCodeVisitor* self, ValaLockStatement* stmt);
-void vala_code_visitor_visit_begin_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
-void vala_code_visitor_visit_end_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
+void vala_code_visitor_visit_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
 void vala_code_visitor_visit_boolean_literal (ValaCodeVisitor* self, ValaBooleanLiteral* lit);
 void vala_code_visitor_visit_character_literal (ValaCodeVisitor* self, ValaCharacterLiteral* lit);
 void vala_code_visitor_visit_integer_literal (ValaCodeVisitor* self, ValaIntegerLiteral* lit);
