@@ -87,10 +87,10 @@ ValaLocalVariableDeclaration* vala_declaration_statement_get_declaration (ValaDe
 
 void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self, ValaLocalVariableDeclaration* value)
 {
-	ValaLocalVariableDeclaration* __temp1;
+	ValaLocalVariableDeclaration* _tmp1;
 	g_return_if_fail (VALA_IS_DECLARATION_STATEMENT (self));
-	__temp1 = NULL;
-	self->priv->_declaration = (__temp1 = g_object_ref (value), (self->priv->_declaration == NULL ? NULL : (self->priv->_declaration = (g_object_unref (self->priv->_declaration), NULL))), __temp1);
+	_tmp1 = NULL;
+	self->priv->_declaration = (_tmp1 = g_object_ref (value), (self->priv->_declaration == NULL ? NULL : (self->priv->_declaration = (g_object_unref (self->priv->_declaration), NULL))), _tmp1);
 }
 
 
@@ -102,6 +102,9 @@ static void vala_declaration_statement_get_property (GObject * object, guint pro
 		case VALA_DECLARATION_STATEMENT_DECLARATION:
 		g_value_set_object (value, vala_declaration_statement_get_declaration (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -114,6 +117,9 @@ static void vala_declaration_statement_set_property (GObject * object, guint pro
 		case VALA_DECLARATION_STATEMENT_DECLARATION:
 		vala_declaration_statement_set_declaration (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
