@@ -104,10 +104,10 @@ ValaExpression* vala_element_access_get_container (ValaElementAccess* self)
 
 void vala_element_access_set_container (ValaElementAccess* self, ValaExpression* value)
 {
-	ValaExpression* __temp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_ELEMENT_ACCESS (self));
-	__temp2 = NULL;
-	self->priv->_container = (__temp2 = g_object_ref (value), (self->priv->_container == NULL ? NULL : (self->priv->_container = (g_object_unref (self->priv->_container), NULL))), __temp2);
+	_tmp1 = NULL;
+	self->priv->_container = (_tmp1 = g_object_ref (value), (self->priv->_container == NULL ? NULL : (self->priv->_container = (g_object_unref (self->priv->_container), NULL))), _tmp1);
 }
 
 
@@ -119,6 +119,9 @@ static void vala_element_access_get_property (GObject * object, guint property_i
 		case VALA_ELEMENT_ACCESS_CONTAINER:
 		g_value_set_object (value, vala_element_access_get_container (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -131,6 +134,9 @@ static void vala_element_access_set_property (GObject * object, guint property_i
 		case VALA_ELEMENT_ACCESS_CONTAINER:
 		vala_element_access_set_container (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
