@@ -19,25 +19,20 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaenumvalue.h"
 #include <vala/valaexpression.h>
 #include <vala/valaenumvalue.h>
 #include <vala/valacodevisitor.h>
-#include <vala/valasymbol.h>
 #include <vala/valaenum.h>
 
 struct _ValaEnumValuePrivate {
-	char* _name;
 	ValaExpression* _value;
 	char* cname;
 };
 #define VALA_ENUM_VALUE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ENUM_VALUE, ValaEnumValuePrivate))
 enum  {
 	VALA_ENUM_VALUE_DUMMY_PROPERTY,
-	VALA_ENUM_VALUE_NAME,
 	VALA_ENUM_VALUE_VALUE
 };
 static void vala_enum_value_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -51,16 +46,12 @@ static void vala_enum_value_dispose (GObject * obj);
  * @param name enum value name
  * @return     newly created enum value
  */
-ValaEnumValue* vala_enum_value_new (const char* _name)
+ValaEnumValue* vala_enum_value_new (const char* name)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaEnumValue * self;
-	g_return_val_if_fail (_name != NULL, NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
-	self = g_object_newv (VALA_TYPE_ENUM_VALUE, __params_it - __params, __params);
+	g_return_val_if_fail (name != NULL, NULL);
+	self = g_object_newv (VALA_TYPE_ENUM_VALUE, 0, NULL);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
@@ -72,18 +63,14 @@ ValaEnumValue* vala_enum_value_new (const char* _name)
  * @param value numerical representation
  * @return      newly created enum value
  */
-ValaEnumValue* vala_enum_value_new_with_value (const char* _name, ValaExpression* _value)
+ValaEnumValue* vala_enum_value_new_with_value (const char* name, ValaExpression* value)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaEnumValue * self;
-	g_return_val_if_fail (_name != NULL, NULL);
-	g_return_val_if_fail (_value == NULL || VALA_IS_EXPRESSION (_value), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
-	(__params_it->name = "value", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, _value), __params_it++);
-	self = g_object_newv (VALA_TYPE_ENUM_VALUE, __params_it - __params, __params);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (value == NULL || VALA_IS_EXPRESSION (value), NULL);
+	self = g_object_newv (VALA_TYPE_ENUM_VALUE, 0, NULL);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	vala_enum_value_set_value (self, value);
 	return self;
 }
 
@@ -91,7 +78,7 @@ ValaEnumValue* vala_enum_value_new_with_value (const char* _name, ValaExpression
 static void vala_enum_value_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaEnumValue * self;
-	self = VALA_ENUM_VALUE (base);
+	self = ((ValaEnumValue*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_enum_value (visitor, self);
 }
@@ -104,39 +91,23 @@ static void vala_enum_value_real_accept (ValaCodeNode* base, ValaCodeVisitor* vi
  */
 char* vala_enum_value_get_cname (ValaEnumValue* self)
 {
-	const char* __temp3;
+	const char* _tmp3;
 	g_return_val_if_fail (VALA_IS_ENUM_VALUE (self), NULL);
 	if (self->priv->cname == NULL) {
-		ValaEnum* __temp0;
+		ValaEnum* _tmp0;
 		ValaEnum* en;
-		char* __temp2;
-		char* __temp1;
-		__temp0 = NULL;
-		en = (__temp0 = VALA_ENUM (vala_symbol_get_node (vala_symbol_get_parent_symbol (vala_code_node_get_symbol (VALA_CODE_NODE (self))))), (__temp0 == NULL ? NULL : g_object_ref (__temp0)));
-		__temp2 = NULL;
-		__temp1 = NULL;
-		self->priv->cname = (__temp2 = g_strdup_printf ("%s%s", (__temp1 = vala_enum_get_cprefix (en)), vala_enum_value_get_name (self)), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp2);
-		(__temp1 = (g_free (__temp1), NULL));
+		char* _tmp2;
+		char* _tmp1;
+		_tmp0 = NULL;
+		en = (_tmp0 = VALA_ENUM (vala_symbol_get_parent_symbol (((ValaSymbol*) self))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+		_tmp2 = NULL;
+		_tmp1 = NULL;
+		self->priv->cname = (_tmp2 = g_strdup_printf ("%s%s", (_tmp1 = vala_enum_get_cprefix (en)), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp2);
+		(_tmp1 = (g_free (_tmp1), NULL));
 		(en == NULL ? NULL : (en = (g_object_unref (en), NULL)));
 	}
-	__temp3 = NULL;
-	return (__temp3 = self->priv->cname, (__temp3 == NULL ? NULL : g_strdup (__temp3)));
-}
-
-
-char* vala_enum_value_get_name (ValaEnumValue* self)
-{
-	g_return_val_if_fail (VALA_IS_ENUM_VALUE (self), NULL);
-	return self->priv->_name;
-}
-
-
-void vala_enum_value_set_name (ValaEnumValue* self, const char* value)
-{
-	char* __temp6;
-	g_return_if_fail (VALA_IS_ENUM_VALUE (self));
-	__temp6 = NULL;
-	self->priv->_name = (__temp6 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp6);
+	_tmp3 = NULL;
+	return (_tmp3 = self->priv->cname, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
 }
 
 
@@ -149,12 +120,12 @@ ValaExpression* vala_enum_value_get_value (ValaEnumValue* self)
 
 void vala_enum_value_set_value (ValaEnumValue* self, ValaExpression* value)
 {
-	ValaExpression* __temp9;
-	ValaExpression* __temp8;
+	ValaExpression* _tmp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_ENUM_VALUE (self));
-	__temp9 = NULL;
-	__temp8 = NULL;
-	self->priv->_value = (__temp9 = (__temp8 = value, (__temp8 == NULL ? NULL : g_object_ref (__temp8))), (self->priv->_value == NULL ? NULL : (self->priv->_value = (g_object_unref (self->priv->_value), NULL))), __temp9);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_value == NULL ? NULL : (self->priv->_value = (g_object_unref (self->priv->_value), NULL))), _tmp2);
 }
 
 
@@ -163,12 +134,12 @@ static void vala_enum_value_get_property (GObject * object, guint property_id, G
 	ValaEnumValue * self;
 	self = VALA_ENUM_VALUE (object);
 	switch (property_id) {
-		case VALA_ENUM_VALUE_NAME:
-		g_value_set_string (value, vala_enum_value_get_name (self));
-		break;
 		case VALA_ENUM_VALUE_VALUE:
 		g_value_set_object (value, vala_enum_value_get_value (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -178,12 +149,12 @@ static void vala_enum_value_set_property (GObject * object, guint property_id, c
 	ValaEnumValue * self;
 	self = VALA_ENUM_VALUE (object);
 	switch (property_id) {
-		case VALA_ENUM_VALUE_NAME:
-		vala_enum_value_set_name (self, g_value_get_string (value));
-		break;
 		case VALA_ENUM_VALUE_VALUE:
 		vala_enum_value_set_value (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -196,7 +167,6 @@ static void vala_enum_value_class_init (ValaEnumValueClass * klass)
 	G_OBJECT_CLASS (klass)->set_property = vala_enum_value_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_enum_value_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_enum_value_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ENUM_VALUE_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ENUM_VALUE_VALUE, g_param_spec_object ("value", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -213,7 +183,6 @@ static void vala_enum_value_dispose (GObject * obj)
 	ValaEnumValueClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_ENUM_VALUE (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->priv->_value == NULL ? NULL : (self->priv->_value = (g_object_unref (self->priv->_value), NULL)));
 	(self->priv->cname = (g_free (self->priv->cname), NULL));
 	klass = VALA_ENUM_VALUE_CLASS (g_type_class_peek (VALA_TYPE_ENUM_VALUE));
@@ -222,12 +191,12 @@ static void vala_enum_value_dispose (GObject * obj)
 }
 
 
-GType vala_enum_value_get_type ()
+GType vala_enum_value_get_type (void)
 {
 	static GType vala_enum_value_type_id = 0;
 	if (G_UNLIKELY (vala_enum_value_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaEnumValueClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_enum_value_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaEnumValue), 0, (GInstanceInitFunc) vala_enum_value_init };
-		vala_enum_value_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaEnumValue", &g_define_type_info, 0);
+		vala_enum_value_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaEnumValue", &g_define_type_info, 0);
 	}
 	return vala_enum_value_type_id;
 }
