@@ -58,12 +58,12 @@ ValaTypeReference* vala_expression_get_static_type (ValaExpression* self)
 
 void vala_expression_set_static_type (ValaExpression* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp2;
-	ValaTypeReference* __temp1;
+	ValaTypeReference* _tmp2;
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_EXPRESSION (self));
-	__temp2 = NULL;
-	__temp1 = NULL;
-	self->priv->_static_type = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_static_type == NULL ? NULL : (self->priv->_static_type = (g_object_unref (self->priv->_static_type), NULL))), __temp2);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_static_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_static_type == NULL ? NULL : (self->priv->_static_type = (g_object_unref (self->priv->_static_type), NULL))), _tmp2);
 }
 
 
@@ -76,12 +76,12 @@ ValaTypeReference* vala_expression_get_expected_type (ValaExpression* self)
 
 void vala_expression_set_expected_type (ValaExpression* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp5;
-	ValaTypeReference* __temp4;
+	ValaTypeReference* _tmp2;
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_EXPRESSION (self));
-	__temp5 = NULL;
-	__temp4 = NULL;
-	self->priv->_expected_type = (__temp5 = (__temp4 = value, (__temp4 == NULL ? NULL : g_object_ref (__temp4))), (self->priv->_expected_type == NULL ? NULL : (self->priv->_expected_type = (g_object_unref (self->priv->_expected_type), NULL))), __temp5);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_expected_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_expected_type == NULL ? NULL : (self->priv->_expected_type = (g_object_unref (self->priv->_expected_type), NULL))), _tmp2);
 }
 
 
@@ -181,6 +181,9 @@ static void vala_expression_get_property (GObject * object, guint property_id, G
 		case VALA_EXPRESSION_CAN_FAIL:
 		g_value_set_boolean (value, vala_expression_get_can_fail (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -211,6 +214,9 @@ static void vala_expression_set_property (GObject * object, guint property_id, c
 		case VALA_EXPRESSION_CAN_FAIL:
 		vala_expression_set_can_fail (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
