@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaforeachstatement.h"
 #include <vala/valatypereference.h>
@@ -33,9 +31,11 @@
 struct _ValaForeachStatementPrivate {
 	ValaTypeReference* _type_reference;
 	char* _variable_name;
-	ValaStatement* _body;
 	ValaVariableDeclarator* _variable_declarator;
+	ValaVariableDeclarator* _collection_variable_declarator;
+	ValaVariableDeclarator* _iterator_variable_declarator;
 	ValaExpression* _collection;
+	ValaBlock* _body;
 };
 #define VALA_FOREACH_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FOREACH_STATEMENT, ValaForeachStatementPrivate))
 enum  {
@@ -44,7 +44,9 @@ enum  {
 	VALA_FOREACH_STATEMENT_VARIABLE_NAME,
 	VALA_FOREACH_STATEMENT_COLLECTION,
 	VALA_FOREACH_STATEMENT_BODY,
-	VALA_FOREACH_STATEMENT_VARIABLE_DECLARATOR
+	VALA_FOREACH_STATEMENT_VARIABLE_DECLARATOR,
+	VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE_DECLARATOR,
+	VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE_DECLARATOR
 };
 static void vala_foreach_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_foreach_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
@@ -61,24 +63,29 @@ static void vala_foreach_statement_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created foreach statement
  */
-ValaForeachStatement* vala_foreach_statement_new (ValaTypeReference* type, const char* id, ValaExpression* col, ValaStatement* _body, ValaSourceReference* source)
+ValaForeachStatement* vala_foreach_statement_new (ValaTypeReference* type_reference, const char* variable_name, ValaExpression* collection, ValaBlock* body, ValaSourceReference* source_reference)
 {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaForeachStatement * self;
-	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type), NULL);
-	g_return_val_if_fail (id != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_EXPRESSION (col), NULL);
-	g_return_val_if_fail (_body == NULL || VALA_IS_STATEMENT (_body), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 5);
+	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type_reference), NULL);
+	g_return_val_if_fail (variable_name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (collection), NULL);
+	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
-	(__params_it->name = "type-reference", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, type), __params_it++);
-	(__params_it->name = "variable-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, id), __params_it++);
-	(__params_it->name = "collection", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, col), __params_it++);
-	(__params_it->name = "body", g_value_init (&__params_it->value, VALA_TYPE_STATEMENT), g_value_set_object (&__params_it->value, _body), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
+	(__params_it->name = "type-reference", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, type_reference), __params_it++);
+	(__params_it->name = "variable-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, variable_name), __params_it++);
+	(__params_it->name = "collection", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, collection), __params_it++);
 	self = g_object_newv (VALA_TYPE_FOREACH_STATEMENT, __params_it - __params, __params);
+	vala_foreach_statement_set_body (self, body);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -86,13 +93,15 @@ ValaForeachStatement* vala_foreach_statement_new (ValaTypeReference* type, const
 static void vala_foreach_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaForeachStatement * self;
-	self = VALA_FOREACH_STATEMENT (base);
+	self = ((ValaForeachStatement*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_begin_foreach_statement (visitor, self);
+	vala_code_visitor_visit_begin_block (visitor, VALA_BLOCK (self));
 	vala_code_node_accept (VALA_CODE_NODE (vala_foreach_statement_get_type_reference (self)), visitor);
 	vala_code_node_accept (VALA_CODE_NODE (vala_foreach_statement_get_collection (self)), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_foreach_statement_get_collection (self));
 	vala_code_node_accept (VALA_CODE_NODE (vala_foreach_statement_get_body (self)), visitor);
+	vala_code_visitor_visit_end_block (visitor, VALA_BLOCK (self));
 	vala_code_visitor_visit_end_foreach_statement (visitor, self);
 }
 
@@ -100,11 +109,11 @@ static void vala_foreach_statement_real_accept (ValaCodeNode* base, ValaCodeVisi
 static void vala_foreach_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
 	ValaForeachStatement * self;
-	self = VALA_FOREACH_STATEMENT (base);
+	self = ((ValaForeachStatement*) base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_foreach_statement_get_collection (self)) == old_node) {
-		(vala_foreach_statement_set_collection (self, VALA_EXPRESSION (new_node)), vala_foreach_statement_get_collection (self));
+		vala_foreach_statement_set_collection (self, VALA_EXPRESSION (new_node));
 	}
 }
 
@@ -118,10 +127,10 @@ ValaTypeReference* vala_foreach_statement_get_type_reference (ValaForeachStateme
 
 void vala_foreach_statement_set_type_reference (ValaForeachStatement* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp1;
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
-	__temp1 = NULL;
-	self->priv->_type_reference = (__temp1 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp1);
+	_tmp1 = NULL;
+	self->priv->_type_reference = (_tmp1 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp1);
 }
 
 
@@ -134,10 +143,10 @@ char* vala_foreach_statement_get_variable_name (ValaForeachStatement* self)
 
 void vala_foreach_statement_set_variable_name (ValaForeachStatement* self, const char* value)
 {
-	char* __temp3;
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
-	__temp3 = NULL;
-	self->priv->_variable_name = (__temp3 = g_strdup (value), (self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL)), __temp3);
+	_tmp1 = NULL;
+	self->priv->_variable_name = (_tmp1 = g_strdup (value), (self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL)), _tmp1);
 }
 
 
@@ -150,29 +159,30 @@ ValaExpression* vala_foreach_statement_get_collection (ValaForeachStatement* sel
 
 void vala_foreach_statement_set_collection (ValaForeachStatement* self, ValaExpression* value)
 {
-	ValaExpression* __temp5;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
-	__temp5 = NULL;
-	self->priv->_collection = (__temp5 = g_object_ref (value), (self->priv->_collection == NULL ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL))), __temp5);
-	(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_collection), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_collection)));
+	_tmp1 = NULL;
+	self->priv->_collection = (_tmp1 = g_object_ref (value), (self->priv->_collection == NULL ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL))), _tmp1);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_collection), VALA_CODE_NODE (self));
 }
 
 
-ValaStatement* vala_foreach_statement_get_body (ValaForeachStatement* self)
+ValaBlock* vala_foreach_statement_get_body (ValaForeachStatement* self)
 {
 	g_return_val_if_fail (VALA_IS_FOREACH_STATEMENT (self), NULL);
 	return self->priv->_body;
 }
 
 
-void vala_foreach_statement_set_body (ValaForeachStatement* self, ValaStatement* value)
+void vala_foreach_statement_set_body (ValaForeachStatement* self, ValaBlock* value)
 {
-	ValaStatement* __temp8;
-	ValaStatement* __temp7;
+	ValaBlock* _tmp2;
+	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
-	__temp8 = NULL;
-	__temp7 = NULL;
-	self->priv->_body = (__temp8 = (__temp7 = value, (__temp7 == NULL ? NULL : g_object_ref (__temp7))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp8);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_body), VALA_CODE_NODE (self));
 }
 
 
@@ -185,12 +195,48 @@ ValaVariableDeclarator* vala_foreach_statement_get_variable_declarator (ValaFore
 
 void vala_foreach_statement_set_variable_declarator (ValaForeachStatement* self, ValaVariableDeclarator* value)
 {
-	ValaVariableDeclarator* __temp11;
-	ValaVariableDeclarator* __temp10;
+	ValaVariableDeclarator* _tmp2;
+	ValaVariableDeclarator* _tmp1;
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
-	__temp11 = NULL;
-	__temp10 = NULL;
-	self->priv->_variable_declarator = (__temp11 = (__temp10 = value, (__temp10 == NULL ? NULL : g_object_ref (__temp10))), (self->priv->_variable_declarator == NULL ? NULL : (self->priv->_variable_declarator = (g_object_unref (self->priv->_variable_declarator), NULL))), __temp11);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_variable_declarator = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_variable_declarator == NULL ? NULL : (self->priv->_variable_declarator = (g_object_unref (self->priv->_variable_declarator), NULL))), _tmp2);
+}
+
+
+ValaVariableDeclarator* vala_foreach_statement_get_collection_variable_declarator (ValaForeachStatement* self)
+{
+	g_return_val_if_fail (VALA_IS_FOREACH_STATEMENT (self), NULL);
+	return self->priv->_collection_variable_declarator;
+}
+
+
+void vala_foreach_statement_set_collection_variable_declarator (ValaForeachStatement* self, ValaVariableDeclarator* value)
+{
+	ValaVariableDeclarator* _tmp2;
+	ValaVariableDeclarator* _tmp1;
+	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_collection_variable_declarator = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_collection_variable_declarator == NULL ? NULL : (self->priv->_collection_variable_declarator = (g_object_unref (self->priv->_collection_variable_declarator), NULL))), _tmp2);
+}
+
+
+ValaVariableDeclarator* vala_foreach_statement_get_iterator_variable_declarator (ValaForeachStatement* self)
+{
+	g_return_val_if_fail (VALA_IS_FOREACH_STATEMENT (self), NULL);
+	return self->priv->_iterator_variable_declarator;
+}
+
+
+void vala_foreach_statement_set_iterator_variable_declarator (ValaForeachStatement* self, ValaVariableDeclarator* value)
+{
+	ValaVariableDeclarator* _tmp2;
+	ValaVariableDeclarator* _tmp1;
+	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_iterator_variable_declarator = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_iterator_variable_declarator == NULL ? NULL : (self->priv->_iterator_variable_declarator = (g_object_unref (self->priv->_iterator_variable_declarator), NULL))), _tmp2);
 }
 
 
@@ -214,6 +260,15 @@ static void vala_foreach_statement_get_property (GObject * object, guint propert
 		case VALA_FOREACH_STATEMENT_VARIABLE_DECLARATOR:
 		g_value_set_object (value, vala_foreach_statement_get_variable_declarator (self));
 		break;
+		case VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE_DECLARATOR:
+		g_value_set_object (value, vala_foreach_statement_get_collection_variable_declarator (self));
+		break;
+		case VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE_DECLARATOR:
+		g_value_set_object (value, vala_foreach_statement_get_iterator_variable_declarator (self));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -238,6 +293,15 @@ static void vala_foreach_statement_set_property (GObject * object, guint propert
 		case VALA_FOREACH_STATEMENT_VARIABLE_DECLARATOR:
 		vala_foreach_statement_set_variable_declarator (self, g_value_get_object (value));
 		break;
+		case VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE_DECLARATOR:
+		vala_foreach_statement_set_collection_variable_declarator (self, g_value_get_object (value));
+		break;
+		case VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE_DECLARATOR:
+		vala_foreach_statement_set_iterator_variable_declarator (self, g_value_get_object (value));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -254,8 +318,10 @@ static void vala_foreach_statement_class_init (ValaForeachStatementClass * klass
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_TYPE_REFERENCE, g_param_spec_object ("type-reference", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_VARIABLE_NAME, g_param_spec_string ("variable-name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_COLLECTION, g_param_spec_object ("collection", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_VARIABLE_DECLARATOR, g_param_spec_object ("variable-declarator", "foo", "bar", VALA_TYPE_VARIABLE_DECLARATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE_DECLARATOR, g_param_spec_object ("collection-variable-declarator", "foo", "bar", VALA_TYPE_VARIABLE_DECLARATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE_DECLARATOR, g_param_spec_object ("iterator-variable-declarator", "foo", "bar", VALA_TYPE_VARIABLE_DECLARATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -273,21 +339,23 @@ static void vala_foreach_statement_dispose (GObject * obj)
 	self = VALA_FOREACH_STATEMENT (obj);
 	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
 	(self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL));
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	(self->priv->_variable_declarator == NULL ? NULL : (self->priv->_variable_declarator = (g_object_unref (self->priv->_variable_declarator), NULL)));
+	(self->priv->_collection_variable_declarator == NULL ? NULL : (self->priv->_collection_variable_declarator = (g_object_unref (self->priv->_collection_variable_declarator), NULL)));
+	(self->priv->_iterator_variable_declarator == NULL ? NULL : (self->priv->_iterator_variable_declarator = (g_object_unref (self->priv->_iterator_variable_declarator), NULL)));
 	(self->priv->_collection == NULL ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL)));
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	klass = VALA_FOREACH_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_FOREACH_STATEMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_foreach_statement_get_type ()
+GType vala_foreach_statement_get_type (void)
 {
 	static GType vala_foreach_statement_type_id = 0;
 	if (G_UNLIKELY (vala_foreach_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaForeachStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_foreach_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaForeachStatement), 0, (GInstanceInitFunc) vala_foreach_statement_init };
-		vala_foreach_statement_type_id = g_type_register_static (VALA_TYPE_STATEMENT, "ValaForeachStatement", &g_define_type_info, 0);
+		vala_foreach_statement_type_id = g_type_register_static (VALA_TYPE_BLOCK, "ValaForeachStatement", &g_define_type_info, 0);
 	}
 	return vala_foreach_statement_type_id;
 }
