@@ -50,6 +50,7 @@ static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, Vala
 static GeeCollection* vala_formal_parameter_real_get_parameters (ValaInvokable* base);
 static ValaTypeReference* vala_formal_parameter_real_get_return_type (ValaInvokable* base);
 static gboolean vala_formal_parameter_real_is_invokable (ValaInvokable* base);
+static GObject * vala_formal_parameter_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_formal_parameter_parent_class = NULL;
 static ValaInvokableIface* vala_formal_parameter_vala_invokable_parent_iface = NULL;
 static void vala_formal_parameter_dispose (GObject * obj);
@@ -118,17 +119,17 @@ static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, Vala
 static GeeCollection* vala_formal_parameter_real_get_parameters (ValaInvokable* base)
 {
 	ValaFormalParameter * self;
-	ValaCallback* __temp1;
+	ValaCallback* _tmp1;
 	ValaCallback* cb;
-	GeeCollection* __temp2;
+	GeeCollection* _tmp2;
 	self = ((ValaFormalParameter*) base);
 	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
 		return GEE_COLLECTION (NULL);
 	}
-	__temp1 = NULL;
-	cb = (__temp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
-	__temp2 = NULL;
-	return (__temp2 = vala_callback_get_parameters (cb), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), __temp2);
+	_tmp1 = NULL;
+	cb = (_tmp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	_tmp2 = NULL;
+	return (_tmp2 = vala_callback_get_parameters (cb), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), _tmp2);
 	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
 }
 
@@ -136,19 +137,19 @@ static GeeCollection* vala_formal_parameter_real_get_parameters (ValaInvokable*
 static ValaTypeReference* vala_formal_parameter_real_get_return_type (ValaInvokable* base)
 {
 	ValaFormalParameter * self;
-	ValaCallback* __temp4;
+	ValaCallback* _tmp1;
 	ValaCallback* cb;
-	ValaTypeReference* __temp5;
-	ValaTypeReference* __temp6;
+	ValaTypeReference* _tmp2;
+	ValaTypeReference* _tmp3;
 	self = ((ValaFormalParameter*) base);
 	if (!vala_invokable_is_invokable (VALA_INVOKABLE (self))) {
 		return VALA_TYPE_REFERENCE (NULL);
 	}
-	__temp4 = NULL;
-	cb = (__temp4 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (__temp4 == NULL ? NULL : g_object_ref (__temp4)));
-	__temp5 = NULL;
-	__temp6 = NULL;
-	return (__temp6 = (__temp5 = vala_callback_get_return_type (cb), (__temp5 == NULL ? NULL : g_object_ref (__temp5))), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), __temp6);
+	_tmp1 = NULL;
+	cb = (_tmp1 = VALA_CALLBACK (vala_type_reference_get_data_type (vala_formal_parameter_get_type_reference (self))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	_tmp2 = NULL;
+	_tmp3 = NULL;
+	return (_tmp3 = (_tmp2 = vala_callback_get_return_type (cb), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL))), _tmp3);
 	(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
 }
 
@@ -170,12 +171,12 @@ ValaTypeReference* vala_formal_parameter_get_type_reference (ValaFormalParameter
 
 void vala_formal_parameter_set_type_reference (ValaFormalParameter* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp10;
-	ValaTypeReference* __temp9;
+	ValaTypeReference* _tmp2;
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
-	__temp10 = NULL;
-	__temp9 = NULL;
-	self->priv->_type_reference = (__temp10 = (__temp9 = value, (__temp9 == NULL ? NULL : g_object_ref (__temp9))), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp10);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_type_reference = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp2);
 }
 
 
@@ -202,12 +203,12 @@ ValaExpression* vala_formal_parameter_get_default_expression (ValaFormalParamete
 
 void vala_formal_parameter_set_default_expression (ValaFormalParameter* self, ValaExpression* value)
 {
-	ValaExpression* __temp14;
-	ValaExpression* __temp13;
+	ValaExpression* _tmp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
-	__temp14 = NULL;
-	__temp13 = NULL;
-	self->priv->_default_expression = (__temp14 = (__temp13 = value, (__temp13 == NULL ? NULL : g_object_ref (__temp13))), (self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL))), __temp14);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_default_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL))), _tmp2);
 }
 
 
@@ -239,6 +240,23 @@ void vala_formal_parameter_set_construct_parameter (ValaFormalParameter* self, g
 }
 
 
+static GObject * vala_formal_parameter_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties)
+{
+	GObject * obj;
+	ValaFormalParameterClass * klass;
+	GObjectClass * parent_class;
+	ValaFormalParameter * self;
+	klass = VALA_FORMAL_PARAMETER_CLASS (g_type_class_peek (VALA_TYPE_FORMAL_PARAMETER));
+	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
+	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
+	self = VALA_FORMAL_PARAMETER (obj);
+	{
+		vala_symbol_set_access (VALA_SYMBOL (self), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+	}
+	return obj;
+}
+
+
 static void vala_formal_parameter_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
 	ValaFormalParameter * self;
@@ -259,6 +277,9 @@ static void vala_formal_parameter_get_property (GObject * object, guint property
 		case VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER:
 		g_value_set_boolean (value, vala_formal_parameter_get_construct_parameter (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -283,6 +304,9 @@ static void vala_formal_parameter_set_property (GObject * object, guint property
 		case VALA_FORMAL_PARAMETER_CONSTRUCT_PARAMETER:
 		vala_formal_parameter_set_construct_parameter (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -293,6 +317,7 @@ static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass)
 	g_type_class_add_private (klass, sizeof (ValaFormalParameterPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_formal_parameter_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_formal_parameter_set_property;
+	G_OBJECT_CLASS (klass)->constructor = vala_formal_parameter_constructor;
 	G_OBJECT_CLASS (klass)->dispose = vala_formal_parameter_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_formal_parameter_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_formal_parameter_real_accept_children;
