@@ -1,6 +1,6 @@
 /* valainitializerlist.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,6 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
+ * 	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #include "valainitializerlist.h"
@@ -33,8 +34,10 @@ struct _ValaInitializerListPrivate {
 };
 #define VALA_INITIALIZER_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INITIALIZER_LIST, ValaInitializerListPrivate))
 enum  {
-	VALA_INITIALIZER_LIST_DUMMY_PROPERTY
+	VALA_INITIALIZER_LIST_DUMMY_PROPERTY,
+	VALA_INITIALIZER_LIST_SIZE
 };
+static void vala_initializer_list_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_initializer_list_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_initializer_list_parent_class = NULL;
 static void vala_initializer_list_dispose (GObject * obj);
@@ -81,12 +84,11 @@ ValaInitializerList* vala_initializer_list_new (ValaSourceReference* source_refe
 }
 
 
-static void vala_initializer_list_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
+static void vala_initializer_list_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaInitializerList * self;
 	self = ((ValaInitializerList*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	vala_code_visitor_visit_begin_initializer_list (visitor, self);
 	{
 		GeeList* expr_collection;
 		GeeIterator* expr_it;
@@ -102,7 +104,37 @@ static void vala_initializer_list_real_accept (ValaCodeNode* base, ValaCodeVisit
 		}
 		(expr_it == NULL ? NULL : (expr_it = (g_object_unref (expr_it), NULL)));
 	}
-	vala_code_visitor_visit_end_initializer_list (visitor, self);
+}
+
+
+static void vala_initializer_list_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
+{
+	ValaInitializerList * self;
+	self = ((ValaInitializerList*) base);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_visitor_visit_initializer_list (visitor, self);
+}
+
+
+gint vala_initializer_list_get_size (ValaInitializerList* self)
+{
+	g_return_val_if_fail (VALA_IS_INITIALIZER_LIST (self), 0);
+	return gee_collection_get_size (((GeeCollection*) self->priv->initializers));
+}
+
+
+static void vala_initializer_list_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
+{
+	ValaInitializerList * self;
+	self = VALA_INITIALIZER_LIST (object);
+	switch (property_id) {
+		case VALA_INITIALIZER_LIST_SIZE:
+		g_value_set_int (value, vala_initializer_list_get_size (self));
+		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
 }
 
 
@@ -110,8 +142,11 @@ static void vala_initializer_list_class_init (ValaInitializerListClass * klass)
 {
 	vala_initializer_list_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaInitializerListPrivate));
+	G_OBJECT_CLASS (klass)->get_property = vala_initializer_list_get_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_initializer_list_dispose;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_initializer_list_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_initializer_list_real_accept;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INITIALIZER_LIST_SIZE, g_param_spec_int ("size", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
 
