@@ -1,6 +1,6 @@
 /* valainitializerlist.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,6 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
+ * 	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #ifndef __VALAINITIALIZERLIST_H__
@@ -55,6 +56,7 @@ struct _ValaInitializerListClass {
 void vala_initializer_list_append (ValaInitializerList* self, ValaExpression* expr);
 GeeCollection* vala_initializer_list_get_initializers (ValaInitializerList* self);
 ValaInitializerList* vala_initializer_list_new (ValaSourceReference* source_reference);
+gint vala_initializer_list_get_size (ValaInitializerList* self);
 GType vala_initializer_list_get_type (void);
 
 G_END_DECLS
