@@ -19,17 +19,18 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valainvocationexpression.h"
+#include <gee/arraylist.h>
+#include <gee/readonlycollection.h>
+#include <gee/readonlylist.h>
 #include <vala/valasourcereference.h>
 #include <vala/valainvocationexpression.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaInvocationExpressionPrivate {
-	GList* argument_list;
-	GList* array_sizes;
+	GeeList* argument_list;
+	GeeList* array_sizes;
 };
 #define VALA_INVOCATION_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INVOCATION_EXPRESSION, ValaInvocationExpressionPrivate))
 enum  {
@@ -45,22 +46,27 @@ static void vala_invocation_expression_dispose (GObject * obj);
 /**
  * Creates a new invocation expression.
  *
- * @param call   method to call
- * @param source reference to source code
- * @return       newly created invocation expression
+ * @param call             method to call
+ * @param source_reference reference to source code
+ * @return                 newly created invocation expression
  */
-ValaInvocationExpression* vala_invocation_expression_new (ValaExpression* _call, ValaSourceReference* source)
+ValaInvocationExpression* vala_invocation_expression_new (ValaExpression* call, ValaSourceReference* source_reference)
 {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaInvocationExpression * self;
-	g_return_val_if_fail (VALA_IS_EXPRESSION (_call), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 2);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (call), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "call", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, _call), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
+	(__params_it->name = "call", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, call), __params_it++);
 	self = g_object_newv (VALA_TYPE_INVOCATION_EXPRESSION, __params_it - __params, __params);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -74,8 +80,8 @@ void vala_invocation_expression_add_argument (ValaInvocationExpression* self, Va
 {
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
 	g_return_if_fail (VALA_IS_EXPRESSION (arg));
-	self->priv->argument_list = g_list_append (self->priv->argument_list, g_object_ref (arg));
-	(vala_code_node_set_parent_node (VALA_CODE_NODE (arg), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (arg)));
+	gee_collection_add (GEE_COLLECTION (self->priv->argument_list), arg);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (arg), VALA_CODE_NODE (self));
 }
 
 
@@ -84,10 +90,10 @@ void vala_invocation_expression_add_argument (ValaInvocationExpression* self, Va
  *
  * @return argument list
  */
-GList* vala_invocation_expression_get_argument_list (ValaInvocationExpression* self)
+GeeCollection* vala_invocation_expression_get_argument_list (ValaInvocationExpression* self)
 {
 	g_return_val_if_fail (VALA_IS_INVOCATION_EXPRESSION (self), NULL);
-	return g_list_copy (self->priv->argument_list);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->argument_list)));
 }
 
 
@@ -98,7 +104,7 @@ void vala_invocation_expression_append_array_size (ValaInvocationExpression* sel
 {
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
 	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (size));
-	self->priv->array_sizes = g_list_append (self->priv->array_sizes, g_object_ref (size));
+	gee_collection_add (GEE_COLLECTION (self->priv->array_sizes), size);
 }
 
 
@@ -106,34 +112,34 @@ void vala_invocation_expression_append_array_size (ValaInvocationExpression* sel
  * Get the C code expression for array sizes for all dimensions
  * ascending from left to right.
  */
-GList* vala_invocation_expression_get_array_sizes (ValaInvocationExpression* self)
+GeeList* vala_invocation_expression_get_array_sizes (ValaInvocationExpression* self)
 {
 	g_return_val_if_fail (VALA_IS_INVOCATION_EXPRESSION (self), NULL);
-	return g_list_copy (self->priv->array_sizes);
+	return GEE_LIST (gee_read_only_list_new (g_object_ref, g_object_unref, self->priv->array_sizes));
 }
 
 
 static void vala_invocation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaInvocationExpression * self;
-	self = VALA_INVOCATION_EXPRESSION (base);
+	self = ((ValaInvocationExpression*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_invocation_expression_get_call (self)), visitor);
 	vala_code_visitor_visit_begin_invocation_expression (visitor, self);
 	{
-		GList* __temp2;
-		GList* expr_it;
-		__temp2 = NULL;
-		__temp2 = g_list_copy (self->priv->argument_list);
-		for (expr_it = __temp2; expr_it != NULL; expr_it = expr_it->next) {
+		GeeList* expr_collection;
+		GeeIterator* expr_it;
+		expr_collection = self->priv->argument_list;
+		expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
+		while (gee_iterator_next (expr_it)) {
 			ValaExpression* expr;
-			expr = expr_it->data;
+			expr = gee_iterator_get (expr_it);
 			{
-				/* iterate over list copy as list may change in loop body*/
 				vala_code_node_accept (VALA_CODE_NODE (expr), visitor);
+				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
 			}
 		}
-		(__temp2 == NULL ? NULL : (__temp2 = (g_list_free (__temp2), NULL)));
+		(expr_it == NULL ? NULL : (expr_it = (g_object_unref (expr_it), NULL)));
 	}
 	vala_code_visitor_visit_end_invocation_expression (visitor, self);
 }
@@ -142,21 +148,17 @@ static void vala_invocation_expression_real_accept (ValaCodeNode* base, ValaCode
 static void vala_invocation_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
 	ValaInvocationExpression * self;
-	GList* l;
-	self = VALA_INVOCATION_EXPRESSION (base);
+	gint index;
+	self = ((ValaInvocationExpression*) base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_invocation_expression_get_call (self)) == old_node) {
-		(vala_invocation_expression_set_call (self, VALA_EXPRESSION (new_node)), vala_invocation_expression_get_call (self));
+		vala_invocation_expression_set_call (self, VALA_EXPRESSION (new_node));
 	}
-	l = g_list_find (self->priv->argument_list, old_node);
-	if (l != NULL) {
-		if (vala_code_node_get_parent_node (new_node) != NULL) {
-			return;
-		}
-		self->priv->argument_list = g_list_insert_before (self->priv->argument_list, l, g_object_ref (new_node));
-		self->priv->argument_list = g_list_remove_link (self->priv->argument_list, l);
-		(vala_code_node_set_parent_node (new_node, VALA_CODE_NODE (self)), vala_code_node_get_parent_node (new_node));
+	index = gee_list_index_of (self->priv->argument_list, old_node);
+	if (index >= 0 && vala_code_node_get_parent_node (new_node) == NULL) {
+		gee_list_set (((GeeList*) self->priv->argument_list), index, VALA_EXPRESSION (new_node));
+		vala_code_node_set_parent_node (new_node, VALA_CODE_NODE (self));
 	}
 }
 
@@ -170,11 +172,11 @@ ValaExpression* vala_invocation_expression_get_call (ValaInvocationExpression* s
 
 void vala_invocation_expression_set_call (ValaInvocationExpression* self, ValaExpression* value)
 {
-	ValaExpression* __temp4;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (self));
-	__temp4 = NULL;
-	self->_call = (__temp4 = g_object_ref (value), (self->_call == NULL ? NULL : (self->_call = (g_object_unref (self->_call), NULL))), __temp4);
-	(vala_code_node_set_parent_node (VALA_CODE_NODE (self->_call), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->_call)));
+	_tmp1 = NULL;
+	self->_call = (_tmp1 = g_object_ref (value), (self->_call == NULL ? NULL : (self->_call = (g_object_unref (self->_call), NULL))), _tmp1);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->_call), VALA_CODE_NODE (self));
 }
 
 
@@ -186,6 +188,9 @@ static void vala_invocation_expression_get_property (GObject * object, guint pro
 		case VALA_INVOCATION_EXPRESSION_CALL:
 		g_value_set_object (value, vala_invocation_expression_get_call (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -198,6 +203,9 @@ static void vala_invocation_expression_set_property (GObject * object, guint pro
 		case VALA_INVOCATION_EXPRESSION_CALL:
 		vala_invocation_expression_set_call (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -218,6 +226,8 @@ static void vala_invocation_expression_class_init (ValaInvocationExpressionClass
 static void vala_invocation_expression_init (ValaInvocationExpression * self)
 {
 	self->priv = VALA_INVOCATION_EXPRESSION_GET_PRIVATE (self);
+	self->priv->argument_list = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->array_sizes = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
@@ -228,15 +238,15 @@ static void vala_invocation_expression_dispose (GObject * obj)
 	GObjectClass * parent_class;
 	self = VALA_INVOCATION_EXPRESSION (obj);
 	(self->_call == NULL ? NULL : (self->_call = (g_object_unref (self->_call), NULL)));
-	(self->priv->argument_list == NULL ? NULL : (self->priv->argument_list = (g_list_foreach (self->priv->argument_list, (GFunc) g_object_unref, NULL), g_list_free (self->priv->argument_list), NULL)));
-	(self->priv->array_sizes == NULL ? NULL : (self->priv->array_sizes = (g_list_foreach (self->priv->array_sizes, (GFunc) g_object_unref, NULL), g_list_free (self->priv->array_sizes), NULL)));
+	(self->priv->argument_list == NULL ? NULL : (self->priv->argument_list = (g_object_unref (self->priv->argument_list), NULL)));
+	(self->priv->array_sizes == NULL ? NULL : (self->priv->array_sizes = (g_object_unref (self->priv->array_sizes), NULL)));
 	klass = VALA_INVOCATION_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_INVOCATION_EXPRESSION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_invocation_expression_get_type ()
+GType vala_invocation_expression_get_type (void)
 {
 	static GType vala_invocation_expression_type_id = 0;
 	if (G_UNLIKELY (vala_invocation_expression_type_id == 0)) {
