@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaliteral.h"
 #include <vala/valatypereference.h>
@@ -32,7 +30,7 @@ struct _ValaLiteralPrivate {
 #define VALA_LITERAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_LITERAL, ValaLiteralPrivate))
 enum  {
 	VALA_LITERAL_DUMMY_PROPERTY,
-	VALA_LITERAL_STATIC_TYPE,
+	VALA_LITERAL_STATIC_TYPE
 };
 static gpointer vala_literal_parent_class = NULL;
 static void vala_literal_dispose (GObject * obj);
@@ -47,31 +45,41 @@ ValaTypeReference* vala_literal_get_static_type (ValaLiteral* self)
 
 void vala_literal_set_static_type (ValaLiteral* self, ValaTypeReference* value)
 {
+	ValaTypeReference* _tmp2;
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_LITERAL (self));
-	ValaTypeReference* __temp2 = NULL;
-	ValaTypeReference* __temp1 = NULL;
-	self->priv->_static_type = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_static_type == NULL ? NULL : (self->priv->_static_type = (g_object_unref (self->priv->_static_type), NULL))), __temp2);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_static_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_static_type == NULL ? NULL : (self->priv->_static_type = (g_object_unref (self->priv->_static_type), NULL))), _tmp2);
 }
 
 
 static void vala_literal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaLiteral * self = VALA_LITERAL (object);
+	ValaLiteral * self;
+	self = VALA_LITERAL (object);
 	switch (property_id) {
 		case VALA_LITERAL_STATIC_TYPE:
 		g_value_set_object (value, vala_literal_get_static_type (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
 static void vala_literal_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaLiteral * self = VALA_LITERAL (object);
+	ValaLiteral * self;
+	self = VALA_LITERAL (object);
 	switch (property_id) {
 		case VALA_LITERAL_STATIC_TYPE:
 		vala_literal_set_static_type (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -95,17 +103,18 @@ static void vala_literal_init (ValaLiteral * self)
 
 static void vala_literal_dispose (GObject * obj)
 {
-	ValaLiteral * self = VALA_LITERAL (obj);
-	(self->priv->_static_type == NULL ? NULL : (self->priv->_static_type = (g_object_unref (self->priv->_static_type), NULL)));
+	ValaLiteral * self;
 	ValaLiteralClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_LITERAL (obj);
+	(self->priv->_static_type == NULL ? NULL : (self->priv->_static_type = (g_object_unref (self->priv->_static_type), NULL)));
 	klass = VALA_LITERAL_CLASS (g_type_class_peek (VALA_TYPE_LITERAL));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_literal_get_type ()
+GType vala_literal_get_type (void)
 {
 	static GType vala_literal_type_id = 0;
 	if (G_UNLIKELY (vala_literal_type_id == 0)) {
