@@ -56,7 +56,7 @@ struct _ValaLiteralExpressionClass {
 ValaLiteralExpression* vala_literal_expression_new (ValaLiteral* _literal, ValaSourceReference* source);
 ValaLiteral* vala_literal_expression_get_literal (ValaLiteralExpression* self);
 void vala_literal_expression_set_literal (ValaLiteralExpression* self, ValaLiteral* value);
-GType vala_literal_expression_get_type ();
+GType vala_literal_expression_get_type (void);
 
 G_END_DECLS
 
