@@ -22,10 +22,10 @@
 
 #ifndef __VALALOCALVARIABLEDECLARATION_H__
 #define __VALALOCALVARIABLEDECLARATION_H__
-typedef struct _ValaLocalVariableDeclarationPrivate ValaLocalVariableDeclarationPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/collection.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -38,6 +38,7 @@ G_BEGIN_DECLS
 #define VALA_IS_LOCAL_VARIABLE_DECLARATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOCAL_VARIABLE_DECLARATION))
 #define VALA_LOCAL_VARIABLE_DECLARATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOCAL_VARIABLE_DECLARATION, ValaLocalVariableDeclarationClass))
 
+typedef struct _ValaLocalVariableDeclarationPrivate ValaLocalVariableDeclarationPrivate;
 
 /**
  * Represents a local variable declaration in the source code.
@@ -50,13 +51,13 @@ struct _ValaLocalVariableDeclarationClass {
 	ValaCodeNodeClass parent;
 };
 
-ValaLocalVariableDeclaration* vala_local_variable_declaration_new (ValaTypeReference* type, ValaSourceReference* source);
-ValaLocalVariableDeclaration* vala_local_variable_declaration_new_var_type (ValaSourceReference* source);
+ValaLocalVariableDeclaration* vala_local_variable_declaration_new (ValaTypeReference* type_reference, ValaSourceReference* source_reference);
+ValaLocalVariableDeclaration* vala_local_variable_declaration_new_var_type (ValaSourceReference* source_reference);
 void vala_local_variable_declaration_add_declarator (ValaLocalVariableDeclaration* self, ValaVariableDeclarator* declarator);
-GList* vala_local_variable_declaration_get_variable_declarators (ValaLocalVariableDeclaration* self);
+GeeCollection* vala_local_variable_declaration_get_variable_declarators (ValaLocalVariableDeclaration* self);
 ValaTypeReference* vala_local_variable_declaration_get_type_reference (ValaLocalVariableDeclaration* self);
 void vala_local_variable_declaration_set_type_reference (ValaLocalVariableDeclaration* self, ValaTypeReference* value);
-GType vala_local_variable_declaration_get_type ();
+GType vala_local_variable_declaration_get_type (void);
 
 G_END_DECLS
 
