@@ -62,6 +62,8 @@ ValaExpression* vala_member_access_get_inner (ValaMemberAccess* self);
 void vala_member_access_set_inner (ValaMemberAccess* self, ValaExpression* value);
 char* vala_member_access_get_member_name (ValaMemberAccess* self);
 void vala_member_access_set_member_name (ValaMemberAccess* self, const char* value);
+gboolean vala_member_access_get_prototype_access (ValaMemberAccess* self);
+void vala_member_access_set_prototype_access (ValaMemberAccess* self, gboolean value);
 GType vala_member_access_get_type (void);
 
 G_END_DECLS
