@@ -31,7 +31,6 @@
 #include <gee/collection.h>
 #include <vala/valamember.h>
 #include <vala/valainvokable.h>
-#include <vala/valamemberaccessibility.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -52,13 +51,13 @@ typedef struct _ValaMethodPrivate ValaMethodPrivate;
 struct _ValaMethod {
 	ValaMember parent;
 	ValaMethodPrivate * priv;
-	ValaMemberAccessibility access;
 };
 struct _ValaMethodClass {
 	ValaMemberClass parent;
 	char* (*get_default_cname) (ValaMethod* self);
 };
 
+static const char* VALA_METHOD_DEFAULT_SENTINEL = "NULL";
 ValaMethod* vala_method_new (const char* name, ValaTypeReference* return_type, ValaSourceReference* source_reference);
 void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param);
 char* vala_method_get_cname (ValaMethod* self);
@@ -75,6 +74,10 @@ ValaBlock* vala_method_get_body (ValaMethod* self);
 void vala_method_set_body (ValaMethod* self, ValaBlock* value);
 gboolean vala_method_get_instance (ValaMethod* self);
 void vala_method_set_instance (ValaMethod* self, gboolean value);
+char* vala_method_get_vfunc_name (ValaMethod* self);
+void vala_method_set_vfunc_name (ValaMethod* self, const char* value);
+char* vala_method_get_sentinel (ValaMethod* self);
+void vala_method_set_sentinel (ValaMethod* self, const char* value);
 gboolean vala_method_get_is_abstract (ValaMethod* self);
 void vala_method_set_is_abstract (ValaMethod* self, gboolean value);
 gboolean vala_method_get_is_virtual (ValaMethod* self);
