@@ -68,6 +68,7 @@ static GeeCollection* vala_namespace_real_get_cheader_filenames (ValaSymbol* bas
 static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAttribute* a);
 static gpointer vala_namespace_parent_class = NULL;
 static void vala_namespace_dispose (GObject * obj);
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
 /**
@@ -82,6 +83,7 @@ ValaNamespace* vala_namespace_new (const char* name, ValaSourceReference* source
 	ValaNamespace * self;
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_NAMESPACE, 0, NULL);
+	vala_symbol_set_access (VALA_SYMBOL (self), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
@@ -428,23 +430,23 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 static char* vala_namespace_real_get_cprefix (ValaSymbol* base)
 {
 	ValaNamespace * self;
-	const char* __temp7;
+	const char* _tmp3;
 	self = ((ValaNamespace*) base);
 	if (self->priv->cprefix == NULL) {
 		if (vala_symbol_get_name (((ValaSymbol*) self)) == NULL) {
-			char* __temp4;
-			__temp4 = NULL;
-			self->priv->cprefix = (__temp4 = g_strdup (""), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), __temp4);
+			char* _tmp0;
+			_tmp0 = NULL;
+			self->priv->cprefix = (_tmp0 = g_strdup (""), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp0);
 		} else {
-			char* __temp6;
-			const char* __temp5;
-			__temp6 = NULL;
-			__temp5 = NULL;
-			self->priv->cprefix = (__temp6 = (__temp5 = vala_symbol_get_name (((ValaSymbol*) self)), (__temp5 == NULL ? NULL : g_strdup (__temp5))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), __temp6);
+			char* _tmp2;
+			const char* _tmp1;
+			_tmp2 = NULL;
+			_tmp1 = NULL;
+			self->priv->cprefix = (_tmp2 = (_tmp1 = vala_symbol_get_name (((ValaSymbol*) self)), (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp2);
 		}
 	}
-	__temp7 = NULL;
-	return (__temp7 = self->priv->cprefix, (__temp7 == NULL ? NULL : g_strdup (__temp7)));
+	_tmp3 = NULL;
+	return (_tmp3 = self->priv->cprefix, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
 }
 
 
@@ -456,12 +458,12 @@ static char* vala_namespace_real_get_cprefix (ValaSymbol* base)
  */
 void vala_namespace_set_cprefix (ValaNamespace* self, const char* cprefix)
 {
-	char* __temp10;
-	const char* __temp9;
+	char* _tmp1;
+	const char* _tmp0;
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
-	__temp10 = NULL;
-	__temp9 = NULL;
-	self->priv->cprefix = (__temp10 = (__temp9 = cprefix, (__temp9 == NULL ? NULL : g_strdup (__temp9))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), __temp10);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->cprefix = (_tmp1 = (_tmp0 = cprefix, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp1);
 }
 
 
@@ -474,24 +476,24 @@ void vala_namespace_set_cprefix (ValaNamespace* self, const char* cprefix)
 static char* vala_namespace_real_get_lower_case_cprefix (ValaSymbol* base)
 {
 	ValaNamespace * self;
-	const char* __temp14;
+	const char* _tmp3;
 	self = ((ValaNamespace*) base);
 	if (self->priv->lower_case_cprefix == NULL) {
 		if (vala_symbol_get_name (((ValaSymbol*) self)) == NULL) {
-			char* __temp11;
-			__temp11 = NULL;
-			self->priv->lower_case_cprefix = (__temp11 = g_strdup (""), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), __temp11);
+			char* _tmp0;
+			_tmp0 = NULL;
+			self->priv->lower_case_cprefix = (_tmp0 = g_strdup (""), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp0);
 		} else {
-			char* __temp13;
-			char* __temp12;
-			__temp13 = NULL;
-			__temp12 = NULL;
-			self->priv->lower_case_cprefix = (__temp13 = g_strdup_printf ("%s_", (__temp12 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self))))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), __temp13);
-			(__temp12 = (g_free (__temp12), NULL));
+			char* _tmp2;
+			char* _tmp1;
+			_tmp2 = NULL;
+			_tmp1 = NULL;
+			self->priv->lower_case_cprefix = (_tmp2 = g_strdup_printf ("%s_", (_tmp1 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self))))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp2);
+			(_tmp1 = (g_free (_tmp1), NULL));
 		}
 	}
-	__temp14 = NULL;
-	return (__temp14 = self->priv->lower_case_cprefix, (__temp14 == NULL ? NULL : g_strdup (__temp14)));
+	_tmp3 = NULL;
+	return (_tmp3 = self->priv->lower_case_cprefix, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
 }
 
 
@@ -503,12 +505,12 @@ static char* vala_namespace_real_get_lower_case_cprefix (ValaSymbol* base)
  */
 void vala_namespace_set_lower_case_cprefix (ValaNamespace* self, const char* cprefix)
 {
-	char* __temp17;
-	const char* __temp16;
+	char* _tmp1;
+	const char* _tmp0;
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
-	__temp17 = NULL;
-	__temp16 = NULL;
-	self->priv->lower_case_cprefix = (__temp17 = (__temp16 = cprefix, (__temp16 == NULL ? NULL : g_strdup (__temp16))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), __temp17);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->lower_case_cprefix = (_tmp1 = (_tmp0 = cprefix, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp1);
 }
 
 
@@ -529,8 +531,8 @@ char* vala_namespace_get_cheader_filename (ValaNamespace* self)
 {
 	GString* s;
 	gboolean first;
-	const char* __temp19;
-	char* __temp20;
+	const char* _tmp0;
+	char* _tmp1;
 	g_return_val_if_fail (VALA_IS_NAMESPACE (self), NULL);
 	s = g_string_new ("");
 	first = TRUE;
@@ -555,9 +557,9 @@ char* vala_namespace_get_cheader_filename (ValaNamespace* self)
 		(cheader_filename_collection == NULL ? NULL : (cheader_filename_collection = (g_object_unref (cheader_filename_collection), NULL)));
 		(cheader_filename_it == NULL ? NULL : (cheader_filename_it = (g_object_unref (cheader_filename_it), NULL)));
 	}
-	__temp19 = NULL;
-	__temp20 = NULL;
-	return (__temp20 = (__temp19 = s->str, (__temp19 == NULL ? NULL : g_strdup (__temp19))), (s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL))), __temp20);
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = (_tmp0 = s->str, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL))), _tmp1);
 	(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 }
 
@@ -570,11 +572,11 @@ char* vala_namespace_get_cheader_filename (ValaNamespace* self)
  */
 void vala_namespace_set_cheader_filename (ValaNamespace* self, const char* cheader_filename)
 {
-	GeeList* __temp21;
+	GeeList* _tmp0;
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (cheader_filename != NULL);
-	__temp21 = NULL;
-	self->priv->cheader_filenames = (__temp21 = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_direct_equal)), (self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (g_object_unref (self->priv->cheader_filenames), NULL))), __temp21);
+	_tmp0 = NULL;
+	self->priv->cheader_filenames = (_tmp0 = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_direct_equal)), (self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (g_object_unref (self->priv->cheader_filenames), NULL))), _tmp0);
 	gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), cheader_filename);
 }
 
@@ -584,16 +586,16 @@ static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAtt
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cprefix")) {
-		char* __temp22;
-		__temp22 = NULL;
-		vala_namespace_set_cprefix (self, (__temp22 = vala_attribute_get_string (a, "cprefix")));
-		(__temp22 = (g_free (__temp22), NULL));
+		char* _tmp0;
+		_tmp0 = NULL;
+		vala_namespace_set_cprefix (self, (_tmp0 = vala_attribute_get_string (a, "cprefix")));
+		(_tmp0 = (g_free (_tmp0), NULL));
 	}
 	if (vala_attribute_has_argument (a, "lower_case_cprefix")) {
-		char* __temp23;
-		__temp23 = NULL;
-		vala_namespace_set_lower_case_cprefix (self, (__temp23 = vala_attribute_get_string (a, "lower_case_cprefix")));
-		(__temp23 = (g_free (__temp23), NULL));
+		char* _tmp1;
+		_tmp1 = NULL;
+		vala_namespace_set_lower_case_cprefix (self, (_tmp1 = vala_attribute_get_string (a, "lower_case_cprefix")));
+		(_tmp1 = (g_free (_tmp1), NULL));
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
 		char* val;
@@ -601,18 +603,20 @@ static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAtt
 		{
 			char** filename_collection;
 			char** filename_it;
+			int filename_collection_length1;
 			filename_collection = g_strsplit (val, ",", 0);
+			filename_collection_length1 = -1;
 			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
-				const char* __temp24;
+				const char* _tmp2;
 				char* filename;
-				__temp24 = NULL;
-				filename = (__temp24 = *filename_it, (__temp24 == NULL ? NULL : g_strdup (__temp24)));
+				_tmp2 = NULL;
+				filename = (_tmp2 = *filename_it, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
 				{
 					gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), filename);
 					(filename = (g_free (filename), NULL));
 				}
 			}
-			(filename_collection = (g_strfreev (filename_collection), NULL));
+			(filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL));
 		}
 		(val = (g_free (val), NULL));
 	}
@@ -630,10 +634,10 @@ void vala_namespace_process_attributes (ValaNamespace* self)
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* __temp25;
+			ValaAttribute* _tmp0;
 			ValaAttribute* a;
-			__temp25 = NULL;
-			a = (__temp25 = a_it->data, (__temp25 == NULL ? NULL : g_object_ref (__temp25)));
+			_tmp0 = NULL;
+			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_namespace_process_ccode_attribute (self, a);
@@ -667,6 +671,9 @@ static void vala_namespace_get_property (GObject * object, guint property_id, GV
 		case VALA_NAMESPACE_PKG:
 		g_value_set_boolean (value, vala_namespace_get_pkg (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -679,6 +686,9 @@ static void vala_namespace_set_property (GObject * object, guint property_id, co
 		case VALA_NAMESPACE_PKG:
 		vala_namespace_set_pkg (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -750,5 +760,23 @@ GType vala_namespace_get_type (void)
 }
 
 
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func)
+{
+	if (array != NULL && destroy_func != NULL) {
+		int i;
+		if (array_length >= 0)
+		for (i = 0; i < array_length; i = i + 1) {
+			if (((gpointer*) array)[i] != NULL)
+			destroy_func (((gpointer*) array)[i]);
+		}
+		else
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
+		}
+	}
+	g_free (array);
+}
+
+
 
 
