@@ -1,6 +1,6 @@
 /* valanamespacereference.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valanamespacereference.h"
 #include <vala/valasymbol.h>
@@ -36,7 +34,7 @@ struct _ValaNamespaceReferencePrivate {
 enum  {
 	VALA_NAMESPACE_REFERENCE_DUMMY_PROPERTY,
 	VALA_NAMESPACE_REFERENCE_NAME,
-	VALA_NAMESPACE_REFERENCE_NAMESPACE_SYMBOL,
+	VALA_NAMESPACE_REFERENCE_NAMESPACE_SYMBOL
 };
 static void vala_namespace_reference_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_namespace_reference_parent_class = NULL;
@@ -46,26 +44,26 @@ static void vala_namespace_reference_dispose (GObject * obj);
 /**
  * Creates a new namespace reference.
  *
- * @param name   namespace name
- * @param source reference to source code
- * @return       newly created namespace reference
+ * @param name             namespace name
+ * @param source_reference reference to source code
+ * @return                 newly created namespace reference
  */
-ValaNamespaceReference* vala_namespace_reference_new (const char* _name, ValaSourceReference* source)
+ValaNamespaceReference* vala_namespace_reference_new (const char* name, ValaSourceReference* source_reference)
 {
-	g_return_val_if_fail (_name != NULL, NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaNamespaceReference * self = g_object_newv (VALA_TYPE_NAMESPACE_REFERENCE, __params_it - __params, __params);
+	ValaNamespaceReference * self;
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = g_object_newv (VALA_TYPE_NAMESPACE_REFERENCE, 0, NULL);
+	vala_namespace_reference_set_name (self, name);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
 
 static void vala_namespace_reference_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaNamespaceReference * self = VALA_NAMESPACE_REFERENCE (base);
+	ValaNamespaceReference * self;
+	self = ((ValaNamespaceReference*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_namespace_reference (visitor, self);
 }
@@ -80,9 +78,10 @@ char* vala_namespace_reference_get_name (ValaNamespaceReference* self)
 
 void vala_namespace_reference_set_name (ValaNamespaceReference* self, const char* value)
 {
+	char* _tmp1;
 	g_return_if_fail (VALA_IS_NAMESPACE_REFERENCE (self));
-	char* __temp1 = NULL;
-	self->priv->_name = (__temp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp1);
+	_tmp1 = NULL;
+	self->priv->_name = (_tmp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp1);
 }
 
 
@@ -102,7 +101,8 @@ void vala_namespace_reference_set_namespace_symbol (ValaNamespaceReference* self
 
 static void vala_namespace_reference_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaNamespaceReference * self = VALA_NAMESPACE_REFERENCE (object);
+	ValaNamespaceReference * self;
+	self = VALA_NAMESPACE_REFERENCE (object);
 	switch (property_id) {
 		case VALA_NAMESPACE_REFERENCE_NAME:
 		g_value_set_string (value, vala_namespace_reference_get_name (self));
@@ -110,13 +110,17 @@ static void vala_namespace_reference_get_property (GObject * object, guint prope
 		case VALA_NAMESPACE_REFERENCE_NAMESPACE_SYMBOL:
 		g_value_set_object (value, vala_namespace_reference_get_namespace_symbol (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
 static void vala_namespace_reference_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaNamespaceReference * self = VALA_NAMESPACE_REFERENCE (object);
+	ValaNamespaceReference * self;
+	self = VALA_NAMESPACE_REFERENCE (object);
 	switch (property_id) {
 		case VALA_NAMESPACE_REFERENCE_NAME:
 		vala_namespace_reference_set_name (self, g_value_get_string (value));
@@ -124,6 +128,9 @@ static void vala_namespace_reference_set_property (GObject * object, guint prope
 		case VALA_NAMESPACE_REFERENCE_NAMESPACE_SYMBOL:
 		vala_namespace_reference_set_namespace_symbol (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -136,7 +143,7 @@ static void vala_namespace_reference_class_init (ValaNamespaceReferenceClass * k
 	G_OBJECT_CLASS (klass)->set_property = vala_namespace_reference_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_namespace_reference_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_namespace_reference_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_NAMESPACE_REFERENCE_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_NAMESPACE_REFERENCE_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_NAMESPACE_REFERENCE_NAMESPACE_SYMBOL, g_param_spec_object ("namespace-symbol", "foo", "bar", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -149,17 +156,18 @@ static void vala_namespace_reference_init (ValaNamespaceReference * self)
 
 static void vala_namespace_reference_dispose (GObject * obj)
 {
-	ValaNamespaceReference * self = VALA_NAMESPACE_REFERENCE (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	ValaNamespaceReference * self;
 	ValaNamespaceReferenceClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_NAMESPACE_REFERENCE (obj);
+	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	klass = VALA_NAMESPACE_REFERENCE_CLASS (g_type_class_peek (VALA_TYPE_NAMESPACE_REFERENCE));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_namespace_reference_get_type ()
+GType vala_namespace_reference_get_type (void)
 {
 	static GType vala_namespace_reference_type_id = 0;
 	if (G_UNLIKELY (vala_namespace_reference_type_id == 0)) {
