@@ -150,12 +150,12 @@ ValaTypeReference* vala_object_creation_expression_get_type_reference (ValaObjec
 
 void vala_object_creation_expression_set_type_reference (ValaObjectCreationExpression* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp3;
-	ValaTypeReference* __temp2;
+	ValaTypeReference* _tmp2;
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self));
-	__temp3 = NULL;
-	__temp2 = NULL;
-	self->priv->_type_reference = (__temp3 = (__temp2 = value, (__temp2 == NULL ? NULL : g_object_ref (__temp2))), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp3);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_type_reference = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp2);
 }
 
 
@@ -168,12 +168,12 @@ ValaMethod* vala_object_creation_expression_get_constructor (ValaObjectCreationE
 
 void vala_object_creation_expression_set_constructor (ValaObjectCreationExpression* self, ValaMethod* value)
 {
-	ValaMethod* __temp6;
-	ValaMethod* __temp5;
+	ValaMethod* _tmp2;
+	ValaMethod* _tmp1;
 	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self));
-	__temp6 = NULL;
-	__temp5 = NULL;
-	self->priv->_constructor = (__temp6 = (__temp5 = value, (__temp5 == NULL ? NULL : g_object_ref (__temp5))), (self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (g_object_unref (self->priv->_constructor), NULL))), __temp6);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_constructor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (g_object_unref (self->priv->_constructor), NULL))), _tmp2);
 }
 
 
@@ -186,12 +186,12 @@ ValaMemberAccess* vala_object_creation_expression_get_member_name (ValaObjectCre
 
 void vala_object_creation_expression_set_member_name (ValaObjectCreationExpression* self, ValaMemberAccess* value)
 {
-	ValaMemberAccess* __temp9;
-	ValaMemberAccess* __temp8;
+	ValaMemberAccess* _tmp2;
+	ValaMemberAccess* _tmp1;
 	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self));
-	__temp9 = NULL;
-	__temp8 = NULL;
-	self->priv->_member_name = (__temp9 = (__temp8 = value, (__temp8 == NULL ? NULL : g_object_ref (__temp8))), (self->priv->_member_name == NULL ? NULL : (self->priv->_member_name = (g_object_unref (self->priv->_member_name), NULL))), __temp9);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_member_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_member_name == NULL ? NULL : (self->priv->_member_name = (g_object_unref (self->priv->_member_name), NULL))), _tmp2);
 }
 
 
@@ -209,6 +209,9 @@ static void vala_object_creation_expression_get_property (GObject * object, guin
 		case VALA_OBJECT_CREATION_EXPRESSION_MEMBER_NAME:
 		g_value_set_object (value, vala_object_creation_expression_get_member_name (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -227,6 +230,9 @@ static void vala_object_creation_expression_set_property (GObject * object, guin
 		case VALA_OBJECT_CREATION_EXPRESSION_MEMBER_NAME:
 		vala_object_creation_expression_set_member_name (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
