@@ -89,10 +89,10 @@ ValaExpression* vala_postfix_expression_get_inner (ValaPostfixExpression* self)
 
 void vala_postfix_expression_set_inner (ValaPostfixExpression* self, ValaExpression* value)
 {
-	ValaExpression* __temp1;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_POSTFIX_EXPRESSION (self));
-	__temp1 = NULL;
-	self->priv->_inner = (__temp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp1);
+	_tmp1 = NULL;
+	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
 }
 
 
@@ -121,6 +121,9 @@ static void vala_postfix_expression_get_property (GObject * object, guint proper
 		case VALA_POSTFIX_EXPRESSION_INCREMENT:
 		g_value_set_boolean (value, vala_postfix_expression_get_increment (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -136,6 +139,9 @@ static void vala_postfix_expression_set_property (GObject * object, guint proper
 		case VALA_POSTFIX_EXPRESSION_INCREMENT:
 		vala_postfix_expression_set_increment (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
