@@ -30,7 +30,6 @@
 #include <ccode/valaccodeconstant.h>
 #include <vala/valamember.h>
 #include <vala/valalockable.h>
-#include <vala/valamemberaccessibility.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -61,16 +60,12 @@ char* vala_property_get_upper_case_cname (ValaProperty* self);
 ValaCCodeConstant* vala_property_get_canonical_cconstant (ValaProperty* self);
 void vala_property_process_attributes (ValaProperty* self);
 gboolean vala_property_equals (ValaProperty* self, ValaProperty* prop2);
-char* vala_property_get_name (ValaProperty* self);
-void vala_property_set_name (ValaProperty* self, const char* value);
 ValaTypeReference* vala_property_get_type_reference (ValaProperty* self);
 void vala_property_set_type_reference (ValaProperty* self, ValaTypeReference* value);
 ValaPropertyAccessor* vala_property_get_get_accessor (ValaProperty* self);
 void vala_property_set_get_accessor (ValaProperty* self, ValaPropertyAccessor* value);
 ValaPropertyAccessor* vala_property_get_set_accessor (ValaProperty* self);
 void vala_property_set_set_accessor (ValaProperty* self, ValaPropertyAccessor* value);
-ValaMemberAccessibility vala_property_get_access (ValaProperty* self);
-void vala_property_set_access (ValaProperty* self, ValaMemberAccessibility value);
 ValaFormalParameter* vala_property_get_this_parameter (ValaProperty* self);
 void vala_property_set_this_parameter (ValaProperty* self, ValaFormalParameter* value);
 gboolean vala_property_get_no_accessor_method (ValaProperty* self);
@@ -87,7 +82,7 @@ ValaProperty* vala_property_get_base_property (ValaProperty* self);
 void vala_property_set_base_property (ValaProperty* self, ValaProperty* value);
 ValaProperty* vala_property_get_base_interface_property (ValaProperty* self);
 void vala_property_set_base_interface_property (ValaProperty* self, ValaProperty* value);
-GType vala_property_get_type ();
+GType vala_property_get_type (void);
 
 G_END_DECLS
 
