@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valareferencetransferexpression.h"
 #include <vala/valasourcereference.h>
@@ -33,7 +31,7 @@ struct _ValaReferenceTransferExpressionPrivate {
 #define VALA_REFERENCE_TRANSFER_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION, ValaReferenceTransferExpressionPrivate))
 enum  {
 	VALA_REFERENCE_TRANSFER_EXPRESSION_DUMMY_PROPERTY,
-	VALA_REFERENCE_TRANSFER_EXPRESSION_INNER,
+	VALA_REFERENCE_TRANSFER_EXPRESSION_INNER
 };
 static void vala_reference_transfer_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_reference_transfer_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
@@ -49,20 +47,29 @@ static void vala_reference_transfer_expression_dispose (GObject * obj);
  */
 ValaReferenceTransferExpression* vala_reference_transfer_expression_new (ValaExpression* inner, ValaSourceReference* source_reference)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaReferenceTransferExpression * self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (inner), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 1);
+	__params_it = __params;
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, inner), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source_reference), __params_it++);
-	ValaReferenceTransferExpression * self = g_object_newv (VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION, __params_it - __params, __params);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
 
 static void vala_reference_transfer_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaReferenceTransferExpression * self = VALA_REFERENCE_TRANSFER_EXPRESSION (base);
+	ValaReferenceTransferExpression * self;
+	self = ((ValaReferenceTransferExpression*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_reference_transfer_expression_get_inner (self)), visitor);
 	vala_code_visitor_visit_reference_transfer_expression (visitor, self);
@@ -71,11 +78,12 @@ static void vala_reference_transfer_expression_real_accept (ValaCodeNode* base,
 
 static void vala_reference_transfer_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
-	ValaReferenceTransferExpression * self = VALA_REFERENCE_TRANSFER_EXPRESSION (base);
+	ValaReferenceTransferExpression * self;
+	self = ((ValaReferenceTransferExpression*) base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_reference_transfer_expression_get_inner (self)) == old_node) {
-		(vala_reference_transfer_expression_set_inner (self, VALA_EXPRESSION (new_node)), vala_reference_transfer_expression_get_inner (self));
+		vala_reference_transfer_expression_set_inner (self, VALA_EXPRESSION (new_node));
 	}
 }
 
@@ -89,31 +97,40 @@ ValaExpression* vala_reference_transfer_expression_get_inner (ValaReferenceTrans
 
 void vala_reference_transfer_expression_set_inner (ValaReferenceTransferExpression* self, ValaExpression* value)
 {
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_REFERENCE_TRANSFER_EXPRESSION (self));
-	ValaExpression* __temp1 = NULL;
-	self->priv->_inner = (__temp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp1);
-	(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_inner)));
+	_tmp1 = NULL;
+	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
 }
 
 
 static void vala_reference_transfer_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaReferenceTransferExpression * self = VALA_REFERENCE_TRANSFER_EXPRESSION (object);
+	ValaReferenceTransferExpression * self;
+	self = VALA_REFERENCE_TRANSFER_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_REFERENCE_TRANSFER_EXPRESSION_INNER:
 		g_value_set_object (value, vala_reference_transfer_expression_get_inner (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
 static void vala_reference_transfer_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaReferenceTransferExpression * self = VALA_REFERENCE_TRANSFER_EXPRESSION (object);
+	ValaReferenceTransferExpression * self;
+	self = VALA_REFERENCE_TRANSFER_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_REFERENCE_TRANSFER_EXPRESSION_INNER:
 		vala_reference_transfer_expression_set_inner (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -139,17 +156,18 @@ static void vala_reference_transfer_expression_init (ValaReferenceTransferExpres
 
 static void vala_reference_transfer_expression_dispose (GObject * obj)
 {
-	ValaReferenceTransferExpression * self = VALA_REFERENCE_TRANSFER_EXPRESSION (obj);
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
+	ValaReferenceTransferExpression * self;
 	ValaReferenceTransferExpressionClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_REFERENCE_TRANSFER_EXPRESSION (obj);
+	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
 	klass = VALA_REFERENCE_TRANSFER_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_reference_transfer_expression_get_type ()
+GType vala_reference_transfer_expression_get_type (void)
 {
 	static GType vala_reference_transfer_expression_type_id = 0;
 	if (G_UNLIKELY (vala_reference_transfer_expression_type_id == 0)) {
