@@ -31,34 +31,18 @@
 
 G_BEGIN_DECLS
 
-
-#define VALA_TYPE_REPORT (vala_report_get_type ())
-#define VALA_REPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_REPORT, ValaReport))
-#define VALA_REPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_REPORT, ValaReportClass))
-#define VALA_IS_REPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_REPORT))
-#define VALA_IS_REPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_REPORT))
-#define VALA_REPORT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_REPORT, ValaReportClass))
-
 typedef struct _ValaReport ValaReport;
-typedef struct _ValaReportClass ValaReportClass;
-typedef struct _ValaReportPrivate ValaReportPrivate;
 
 /**
  * Static class to centralize reporting warnings and errors.
  */
 struct _ValaReport {
-	GObject parent;
-	ValaReportPrivate * priv;
-};
-struct _ValaReportClass {
-	GObjectClass parent;
 };
 
-gint vala_report_get_warnings ();
-gint vala_report_get_errors ();
+gint vala_report_get_warnings (void);
+gint vala_report_get_errors (void);
 void vala_report_warning (ValaSourceReference* source, const char* message);
 void vala_report_error (ValaSourceReference* source, const char* message);
-GType vala_report_get_type ();
 
 G_END_DECLS
 
