@@ -27,8 +27,8 @@
 #include <vala/valatypereference.h>
 #include <vala/valacallback.h>
 #include <vala/valasourcereference.h>
-#include <vala/valasymbol.h>
 #include <vala/valasignal.h>
+#include <vala/valasymbol.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valascope.h>
 #include <vala/valadatatype.h>
@@ -37,7 +37,6 @@
 
 struct _ValaSignalPrivate {
 	ValaTypeReference* _return_type;
-	ValaMemberAccessibility _access;
 	gboolean _has_emitter;
 	GeeList* parameters;
 	ValaCallback* generated_callback;
@@ -48,7 +47,6 @@ struct _ValaSignalPrivate {
 enum  {
 	VALA_SIGNAL_DUMMY_PROPERTY,
 	VALA_SIGNAL_RETURN_TYPE,
-	VALA_SIGNAL_ACCESS,
 	VALA_SIGNAL_HAS_EMITTER
 };
 static GeeCollection* vala_signal_real_get_parameters (ValaInvokable* base);
@@ -131,14 +129,14 @@ static gboolean vala_signal_real_is_invokable (ValaInvokable* base)
  */
 ValaCallback* vala_signal_get_callback (ValaSignal* self)
 {
-	ValaCallback* __temp4;
+	ValaCallback* _tmp1;
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
 	if (self->priv->generated_callback == NULL) {
-		ValaCallback* __temp3;
+		ValaCallback* _tmp0;
 		ValaTypeReference* sender_type;
 		ValaFormalParameter* sender_param;
-		__temp3 = NULL;
-		self->priv->generated_callback = (__temp3 = vala_callback_new (NULL, vala_signal_get_return_type (self), NULL), (self->priv->generated_callback == NULL ? NULL : (self->priv->generated_callback = (g_object_unref (self->priv->generated_callback), NULL))), __temp3);
+		_tmp0 = NULL;
+		self->priv->generated_callback = (_tmp0 = vala_callback_new (NULL, vala_signal_get_return_type (self), NULL), (self->priv->generated_callback == NULL ? NULL : (self->priv->generated_callback = (g_object_unref (self->priv->generated_callback), NULL))), _tmp0);
 		vala_callback_set_instance (self->priv->generated_callback, TRUE);
 		sender_type = vala_type_reference_new ();
 		vala_type_reference_set_data_type (sender_type, VALA_DATA_TYPE (vala_symbol_get_parent_symbol (((ValaSymbol*) self))));
@@ -162,8 +160,8 @@ ValaCallback* vala_signal_get_callback (ValaSignal* self)
 		(sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL)));
 		(sender_param == NULL ? NULL : (sender_param = (g_object_unref (sender_param), NULL)));
 	}
-	__temp4 = NULL;
-	return (__temp4 = self->priv->generated_callback, (__temp4 == NULL ? NULL : g_object_ref (__temp4)));
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->generated_callback, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 }
 
 
@@ -174,28 +172,28 @@ ValaCallback* vala_signal_get_callback (ValaSignal* self)
  */
 char* vala_signal_get_cname (ValaSignal* self)
 {
-	const char* __temp8;
+	const char* _tmp2;
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
 	if (self->priv->cname == NULL) {
-		char* __temp7;
-		const char* __temp6;
-		__temp7 = NULL;
-		__temp6 = NULL;
-		self->priv->cname = (__temp7 = (__temp6 = vala_symbol_get_name (((ValaSymbol*) self)), (__temp6 == NULL ? NULL : g_strdup (__temp6))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp7);
+		char* _tmp1;
+		const char* _tmp0;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		self->priv->cname = (_tmp1 = (_tmp0 = vala_symbol_get_name (((ValaSymbol*) self)), (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
 	}
-	__temp8 = NULL;
-	return (__temp8 = self->priv->cname, (__temp8 == NULL ? NULL : g_strdup (__temp8)));
+	_tmp2 = NULL;
+	return (_tmp2 = self->priv->cname, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
 }
 
 
 void vala_signal_set_cname (ValaSignal* self, const char* cname)
 {
-	char* __temp11;
-	const char* __temp10;
+	char* _tmp1;
+	const char* _tmp0;
 	g_return_if_fail (VALA_IS_SIGNAL (self));
-	__temp11 = NULL;
-	__temp10 = NULL;
-	self->priv->cname = (__temp11 = (__temp10 = cname, (__temp10 == NULL ? NULL : g_strdup (__temp10))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp11);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
 }
 
 
@@ -207,30 +205,30 @@ void vala_signal_set_cname (ValaSignal* self, const char* cname)
 ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self)
 {
 	GString* str;
-	const char* __temp12;
+	const char* _tmp0;
 	char* i;
-	ValaCCodeConstant* __temp15;
+	ValaCCodeConstant* _tmp3;
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
 	str = g_string_new ("\"");
-	__temp12 = NULL;
-	i = (__temp12 = vala_symbol_get_name (((ValaSymbol*) self)), (__temp12 == NULL ? NULL : g_strdup (__temp12)));
+	_tmp0 = NULL;
+	i = (_tmp0 = vala_symbol_get_name (((ValaSymbol*) self)), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	while (g_utf8_strlen (i, -1) > 0) {
 		gunichar c;
-		char* __temp14;
-		const char* __temp13;
+		char* _tmp2;
+		const char* _tmp1;
 		c = g_utf8_get_char (i);
 		if (c == '_') {
 			g_string_append_c (str, '-');
 		} else {
 			g_string_append_unichar (str, c);
 		}
-		__temp14 = NULL;
-		__temp13 = NULL;
-		i = (__temp14 = (__temp13 = g_utf8_next_char (i), (__temp13 == NULL ? NULL : g_strdup (__temp13))), (i = (g_free (i), NULL)), __temp14);
+		_tmp2 = NULL;
+		_tmp1 = NULL;
+		i = (_tmp2 = (_tmp1 = g_utf8_next_char (i), (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (i = (g_free (i), NULL)), _tmp2);
 	}
 	g_string_append_c (str, '"');
-	__temp15 = NULL;
-	return (__temp15 = vala_ccode_constant_new (str->str), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), __temp15);
+	_tmp3 = NULL;
+	return (_tmp3 = vala_ccode_constant_new (str->str), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), _tmp3);
 	(str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL)));
 	(i = (g_free (i), NULL));
 }
@@ -281,10 +279,10 @@ void vala_signal_process_attributes (ValaSignal* self)
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* __temp16;
+			ValaAttribute* _tmp0;
 			ValaAttribute* a;
-			__temp16 = NULL;
-			a = (__temp16 = a_it->data, (__temp16 == NULL ? NULL : g_object_ref (__temp16)));
+			_tmp0 = NULL;
+			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "HasEmitter") == 0) {
 					vala_signal_set_has_emitter (self, TRUE);
@@ -321,24 +319,10 @@ ValaTypeReference* vala_signal_get_return_type (ValaSignal* self)
 
 void vala_signal_set_return_type (ValaSignal* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp19;
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_SIGNAL (self));
-	__temp19 = NULL;
-	self->priv->_return_type = (__temp19 = g_object_ref (value), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), __temp19);
-}
-
-
-ValaMemberAccessibility vala_signal_get_access (ValaSignal* self)
-{
-	g_return_val_if_fail (VALA_IS_SIGNAL (self), 0);
-	return self->priv->_access;
-}
-
-
-void vala_signal_set_access (ValaSignal* self, ValaMemberAccessibility value)
-{
-	g_return_if_fail (VALA_IS_SIGNAL (self));
-	self->priv->_access = value;
+	_tmp1 = NULL;
+	self->priv->_return_type = (_tmp1 = g_object_ref (value), (self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL))), _tmp1);
 }
 
 
@@ -364,12 +348,12 @@ static void vala_signal_get_property (GObject * object, guint property_id, GValu
 		case VALA_SIGNAL_RETURN_TYPE:
 		g_value_set_object (value, vala_signal_get_return_type (self));
 		break;
-		case VALA_SIGNAL_ACCESS:
-		g_value_set_int (value, vala_signal_get_access (self));
-		break;
 		case VALA_SIGNAL_HAS_EMITTER:
 		g_value_set_boolean (value, vala_signal_get_has_emitter (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -382,12 +366,12 @@ static void vala_signal_set_property (GObject * object, guint property_id, const
 		case VALA_SIGNAL_RETURN_TYPE:
 		vala_signal_set_return_type (self, g_value_get_object (value));
 		break;
-		case VALA_SIGNAL_ACCESS:
-		vala_signal_set_access (self, g_value_get_int (value));
-		break;
 		case VALA_SIGNAL_HAS_EMITTER:
 		vala_signal_set_has_emitter (self, g_value_get_boolean (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -402,7 +386,6 @@ static void vala_signal_class_init (ValaSignalClass * klass)
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_signal_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_signal_real_accept_children;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_RETURN_TYPE, g_param_spec_object ("return-type", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_ACCESS, g_param_spec_int ("access", "foo", "bar", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_HAS_EMITTER, g_param_spec_boolean ("has-emitter", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
