@@ -1,6 +1,6 @@
 /* valasignal.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,11 +27,11 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/collection.h>
 #include <ccode/valaccodeconstant.h>
 #include <vala/valamember.h>
 #include <vala/valainvokable.h>
 #include <vala/valalockable.h>
-#include <vala/valamemberaccessibility.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -57,22 +57,18 @@ struct _ValaSignalClass {
 	ValaMemberClass parent;
 };
 
-ValaSignal* vala_signal_new (const char* _name, ValaTypeReference* _return_type, ValaSourceReference* source);
+ValaSignal* vala_signal_new (const char* name, ValaTypeReference* return_type, ValaSourceReference* source_reference);
 void vala_signal_add_parameter (ValaSignal* self, ValaFormalParameter* param);
 ValaCallback* vala_signal_get_callback (ValaSignal* self);
 char* vala_signal_get_cname (ValaSignal* self);
 void vala_signal_set_cname (ValaSignal* self, const char* cname);
 ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self);
 void vala_signal_process_attributes (ValaSignal* self);
-char* vala_signal_get_name (ValaSignal* self);
-void vala_signal_set_name (ValaSignal* self, const char* value);
 ValaTypeReference* vala_signal_get_return_type (ValaSignal* self);
 void vala_signal_set_return_type (ValaSignal* self, ValaTypeReference* value);
-ValaMemberAccessibility vala_signal_get_access (ValaSignal* self);
-void vala_signal_set_access (ValaSignal* self, ValaMemberAccessibility value);
 gboolean vala_signal_get_has_emitter (ValaSignal* self);
 void vala_signal_set_has_emitter (ValaSignal* self, gboolean value);
-GType vala_signal_get_type ();
+GType vala_signal_get_type (void);
 
 G_END_DECLS
 
