@@ -86,10 +86,10 @@ ValaTypeReference* vala_sizeof_expression_get_type_reference (ValaSizeofExpressi
 
 void vala_sizeof_expression_set_type_reference (ValaSizeofExpression* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp1;
+	ValaTypeReference* _tmp1;
 	g_return_if_fail (VALA_IS_SIZEOF_EXPRESSION (self));
-	__temp1 = NULL;
-	self->priv->_type_reference = (__temp1 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp1);
+	_tmp1 = NULL;
+	self->priv->_type_reference = (_tmp1 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp1);
 }
 
 
@@ -101,6 +101,9 @@ static void vala_sizeof_expression_get_property (GObject * object, guint propert
 		case VALA_SIZEOF_EXPRESSION_TYPE_REFERENCE:
 		g_value_set_object (value, vala_sizeof_expression_get_type_reference (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -113,6 +116,9 @@ static void vala_sizeof_expression_set_property (GObject * object, guint propert
 		case VALA_SIZEOF_EXPRESSION_TYPE_REFERENCE:
 		vala_sizeof_expression_set_type_reference (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
