@@ -64,15 +64,15 @@ ValaStringLiteral* vala_string_literal_new (const char* s, ValaSourceReference*
 char* vala_string_literal_eval (ValaStringLiteral* self)
 {
 	char* noquotes;
-	char* __temp1;
+	char* _tmp1;
 	g_return_val_if_fail (VALA_IS_STRING_LITERAL (self), NULL);
 	if (vala_string_literal_get_value (self) == NULL) {
 		return NULL;
 	}
 	/* remove quotes */
 	noquotes = g_strndup (g_utf8_offset_to_pointer (vala_string_literal_get_value (self), 1), ((guint) (g_utf8_strlen (vala_string_literal_get_value (self), -1) - 2)));
-	__temp1 = NULL;
-	return (__temp1 = g_strcompress (noquotes), (noquotes = (g_free (noquotes), NULL)), __temp1);
+	_tmp1 = NULL;
+	return (_tmp1 = g_strcompress (noquotes), (noquotes = (g_free (noquotes), NULL)), _tmp1);
 	(noquotes = (g_free (noquotes), NULL));
 }
 
@@ -96,12 +96,12 @@ char* vala_string_literal_get_value (ValaStringLiteral* self)
 
 void vala_string_literal_set_value (ValaStringLiteral* self, const char* value)
 {
-	char* __temp4;
-	const char* __temp3;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_STRING_LITERAL (self));
-	__temp4 = NULL;
-	__temp3 = NULL;
-	self->priv->_value = (__temp4 = (__temp3 = value, (__temp3 == NULL ? NULL : g_strdup (__temp3))), (self->priv->_value = (g_free (self->priv->_value), NULL)), __temp4);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_value = (g_free (self->priv->_value), NULL)), _tmp2);
 }
 
 
@@ -113,6 +113,9 @@ static void vala_string_literal_get_property (GObject * object, guint property_i
 		case VALA_STRING_LITERAL_VALUE:
 		g_value_set_string (value, vala_string_literal_get_value (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -125,6 +128,9 @@ static void vala_string_literal_set_property (GObject * object, guint property_i
 		case VALA_STRING_LITERAL_VALUE:
 		vala_string_literal_set_value (self, g_value_get_string (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
