@@ -64,9 +64,7 @@ GeeCollection* vala_struct_get_methods (ValaStruct* self);
 gboolean vala_struct_is_integer_type (ValaStruct* self);
 gboolean vala_struct_is_floating_type (ValaStruct* self);
 gint vala_struct_get_rank (ValaStruct* self);
-void vala_struct_set_is_reference_type (ValaStruct* self, gboolean ref_type);
 void vala_struct_process_attributes (ValaStruct* self);
-void vala_struct_set_dup_function (ValaStruct* self, const char* name);
 void vala_struct_set_type_id (ValaStruct* self, const char* name);
 void vala_struct_add_base_type (ValaStruct* self, ValaTypeReference* type);
 GeeCollection* vala_struct_get_base_types (ValaStruct* self);
