@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaswitchlabel.h"
 #include <vala/valaexpression.h>
@@ -34,7 +32,7 @@ struct _ValaSwitchLabelPrivate {
 #define VALA_SWITCH_LABEL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SWITCH_LABEL, ValaSwitchLabelPrivate))
 enum  {
 	VALA_SWITCH_LABEL_DUMMY_PROPERTY,
-	VALA_SWITCH_LABEL_EXPRESSION,
+	VALA_SWITCH_LABEL_EXPRESSION
 };
 static void vala_switch_label_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_switch_label_parent_class = NULL;
@@ -50,13 +48,12 @@ static void vala_switch_label_dispose (GObject * obj);
  */
 ValaSwitchLabel* vala_switch_label_new (ValaExpression* expr, ValaSourceReference* source)
 {
+	ValaSwitchLabel * self;
 	g_return_val_if_fail (expr == NULL || VALA_IS_EXPRESSION (expr), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
-	(__params_it->name = "expression", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaSwitchLabel * self = g_object_newv (VALA_TYPE_SWITCH_LABEL, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_SWITCH_LABEL, 0, NULL);
+	vala_switch_label_set_expression (self, expr);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
@@ -69,18 +66,18 @@ ValaSwitchLabel* vala_switch_label_new (ValaExpression* expr, ValaSourceReferenc
  */
 ValaSwitchLabel* vala_switch_label_new_with_default (ValaSourceReference* source)
 {
+	ValaSwitchLabel * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 1);
-	GParameter * __params_it = __params;
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaSwitchLabel * self = g_object_newv (VALA_TYPE_SWITCH_LABEL, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_SWITCH_LABEL, 0, NULL);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
 
 static void vala_switch_label_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaSwitchLabel * self = VALA_SWITCH_LABEL (base);
+	ValaSwitchLabel * self;
+	self = ((ValaSwitchLabel*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_switch_label_get_expression (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_switch_label_get_expression (self)), visitor);
@@ -99,31 +96,41 @@ ValaExpression* vala_switch_label_get_expression (ValaSwitchLabel* self)
 
 void vala_switch_label_set_expression (ValaSwitchLabel* self, ValaExpression* value)
 {
+	ValaExpression* _tmp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_SWITCH_LABEL (self));
-	ValaExpression* __temp2 = NULL;
-	ValaExpression* __temp1 = NULL;
-	self->priv->_expression = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), __temp2);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp2);
 }
 
 
 static void vala_switch_label_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaSwitchLabel * self = VALA_SWITCH_LABEL (object);
+	ValaSwitchLabel * self;
+	self = VALA_SWITCH_LABEL (object);
 	switch (property_id) {
 		case VALA_SWITCH_LABEL_EXPRESSION:
 		g_value_set_object (value, vala_switch_label_get_expression (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
 static void vala_switch_label_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaSwitchLabel * self = VALA_SWITCH_LABEL (object);
+	ValaSwitchLabel * self;
+	self = VALA_SWITCH_LABEL (object);
 	switch (property_id) {
 		case VALA_SWITCH_LABEL_EXPRESSION:
 		vala_switch_label_set_expression (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -148,17 +155,18 @@ static void vala_switch_label_init (ValaSwitchLabel * self)
 
 static void vala_switch_label_dispose (GObject * obj)
 {
-	ValaSwitchLabel * self = VALA_SWITCH_LABEL (obj);
-	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
+	ValaSwitchLabel * self;
 	ValaSwitchLabelClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_SWITCH_LABEL (obj);
+	(self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL)));
 	klass = VALA_SWITCH_LABEL_CLASS (g_type_class_peek (VALA_TYPE_SWITCH_LABEL));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_switch_label_get_type ()
+GType vala_switch_label_get_type (void)
 {
 	static GType vala_switch_label_type_id = 0;
 	if (G_UNLIKELY (vala_switch_label_type_id == 0)) {
