@@ -22,7 +22,6 @@
 
 #ifndef __VALASWITCHLABEL_H__
 #define __VALASWITCHLABEL_H__
-typedef struct _ValaSwitchLabelPrivate ValaSwitchLabelPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -38,6 +37,7 @@ G_BEGIN_DECLS
 #define VALA_IS_SWITCH_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SWITCH_LABEL))
 #define VALA_SWITCH_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SWITCH_LABEL, ValaSwitchLabelClass))
 
+typedef struct _ValaSwitchLabelPrivate ValaSwitchLabelPrivate;
 
 /**
  * Represents a switch label in the source code.
@@ -54,7 +54,7 @@ ValaSwitchLabel* vala_switch_label_new (ValaExpression* expr, ValaSourceReferenc
 ValaSwitchLabel* vala_switch_label_new_with_default (ValaSourceReference* source);
 ValaExpression* vala_switch_label_get_expression (ValaSwitchLabel* self);
 void vala_switch_label_set_expression (ValaSwitchLabel* self, ValaExpression* value);
-GType vala_switch_label_get_type ();
+GType vala_switch_label_get_type (void);
 
 G_END_DECLS
 
