@@ -19,19 +19,20 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaswitchsection.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/readonlycollection.h>
 #include <vala/valasourcereference.h>
-#include <vala/valaswitchlabel.h>
 #include <vala/valaswitchsection.h>
+#include <vala/valaswitchlabel.h>
 #include <vala/valastatement.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaSwitchSectionPrivate {
-	GList* labels;
-	GList* statement_list;
+	GeeList* labels;
+	GeeList* statement_list;
 };
 #define VALA_SWITCH_SECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SWITCH_SECTION, ValaSwitchSectionPrivate))
 enum  {
@@ -45,19 +46,15 @@ static void vala_switch_section_dispose (GObject * obj);
 /**
  * Creates a new switch section.
  *
- * @param source reference to source code
- * @return       newly created switch section
+ * @param source_reference reference to source code
+ * @return                 newly created switch section
  */
-ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source)
+ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_reference)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaSwitchSection * self;
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_SWITCH_SECTION, __params_it - __params, __params);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = g_object_newv (VALA_TYPE_SWITCH_SECTION, 0, NULL);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -71,7 +68,7 @@ void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* la
 {
 	g_return_if_fail (VALA_IS_SWITCH_SECTION (self));
 	g_return_if_fail (VALA_IS_SWITCH_LABEL (label));
-	self->priv->labels = g_list_append (self->priv->labels, g_object_ref (label));
+	gee_collection_add (GEE_COLLECTION (self->priv->labels), label);
 }
 
 
@@ -80,10 +77,10 @@ void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* la
  *
  * @return switch label list
  */
-GList* vala_switch_section_get_labels (ValaSwitchSection* self)
+GeeCollection* vala_switch_section_get_labels (ValaSwitchSection* self)
 {
 	g_return_val_if_fail (VALA_IS_SWITCH_SECTION (self), NULL);
-	return g_list_copy (self->priv->labels);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->labels)));
 }
 
 
@@ -91,19 +88,22 @@ gboolean vala_switch_section_has_default_label (ValaSwitchSection* self)
 {
 	g_return_val_if_fail (VALA_IS_SWITCH_SECTION (self), FALSE);
 	{
-		GList* __temp2;
-		GList* label_it;
-		__temp2 = NULL;
-		__temp2 = self->priv->labels;
-		for (label_it = __temp2; label_it != NULL; label_it = label_it->next) {
+		GeeList* label_collection;
+		GeeIterator* label_it;
+		label_collection = self->priv->labels;
+		label_it = gee_iterable_iterator (GEE_ITERABLE (label_collection));
+		while (gee_iterator_next (label_it)) {
 			ValaSwitchLabel* label;
-			label = label_it->data;
+			label = gee_iterator_get (label_it);
 			{
 				if (vala_switch_label_get_expression (label) == NULL) {
-					return TRUE;
+					gboolean _tmp0;
+					return (_tmp0 = TRUE, (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), (label_it == NULL ? NULL : (label_it = (g_object_unref (label_it), NULL))), _tmp0);
 				}
+				(label == NULL ? NULL : (label = (g_object_unref (label), NULL)));
 			}
 		}
+		(label_it == NULL ? NULL : (label_it = (g_object_unref (label_it), NULL)));
 	}
 	return FALSE;
 }
@@ -118,7 +118,7 @@ void vala_switch_section_add_statement (ValaSwitchSection* self, ValaStatement*
 {
 	g_return_if_fail (VALA_IS_SWITCH_SECTION (self));
 	g_return_if_fail (VALA_IS_STATEMENT (stmt));
-	self->priv->statement_list = g_list_append (self->priv->statement_list, g_object_ref (stmt));
+	gee_collection_add (GEE_COLLECTION (self->priv->statement_list), stmt);
 }
 
 
@@ -127,45 +127,51 @@ void vala_switch_section_add_statement (ValaSwitchSection* self, ValaStatement*
  *
  * @return statement list
  */
-GList* vala_switch_section_get_statements (ValaSwitchSection* self)
+GeeCollection* vala_switch_section_get_statements (ValaSwitchSection* self)
 {
 	g_return_val_if_fail (VALA_IS_SWITCH_SECTION (self), NULL);
-	return g_list_copy (self->priv->statement_list);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->statement_list)));
 }
 
 
 static void vala_switch_section_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaSwitchSection * self;
-	self = VALA_SWITCH_SECTION (base);
+	self = ((ValaSwitchSection*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
-		GList* __temp5;
-		GList* label_it;
-		__temp5 = NULL;
-		__temp5 = self->priv->labels;
-		for (label_it = __temp5; label_it != NULL; label_it = label_it->next) {
+		GeeList* label_collection;
+		GeeIterator* label_it;
+		label_collection = self->priv->labels;
+		label_it = gee_iterable_iterator (GEE_ITERABLE (label_collection));
+		while (gee_iterator_next (label_it)) {
 			ValaSwitchLabel* label;
-			label = label_it->data;
+			label = gee_iterator_get (label_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (label), visitor);
+				(label == NULL ? NULL : (label = (g_object_unref (label), NULL)));
 			}
 		}
+		(label_it == NULL ? NULL : (label_it = (g_object_unref (label_it), NULL)));
 	}
+	vala_code_visitor_visit_begin_block (visitor, VALA_BLOCK (self));
 	{
-		GList* __temp6;
-		GList* st_it;
-		__temp6 = NULL;
-		__temp6 = self->priv->statement_list;
-		for (st_it = __temp6; st_it != NULL; st_it = st_it->next) {
+		GeeList* st_collection;
+		GeeIterator* st_it;
+		st_collection = self->priv->statement_list;
+		st_it = gee_iterable_iterator (GEE_ITERABLE (st_collection));
+		while (gee_iterator_next (st_it)) {
 			ValaStatement* st;
-			st = st_it->data;
+			st = gee_iterator_get (st_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (st), visitor);
+				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
 			}
 		}
+		(st_it == NULL ? NULL : (st_it = (g_object_unref (st_it), NULL)));
 	}
 	vala_code_visitor_visit_switch_section (visitor, self);
+	vala_code_visitor_visit_end_block (visitor, VALA_BLOCK (self));
 }
 
 
@@ -181,6 +187,8 @@ static void vala_switch_section_class_init (ValaSwitchSectionClass * klass)
 static void vala_switch_section_init (ValaSwitchSection * self)
 {
 	self->priv = VALA_SWITCH_SECTION_GET_PRIVATE (self);
+	self->priv->labels = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->statement_list = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
@@ -190,20 +198,20 @@ static void vala_switch_section_dispose (GObject * obj)
 	ValaSwitchSectionClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_SWITCH_SECTION (obj);
-	(self->priv->labels == NULL ? NULL : (self->priv->labels = (g_list_foreach (self->priv->labels, (GFunc) g_object_unref, NULL), g_list_free (self->priv->labels), NULL)));
-	(self->priv->statement_list == NULL ? NULL : (self->priv->statement_list = (g_list_foreach (self->priv->statement_list, (GFunc) g_object_unref, NULL), g_list_free (self->priv->statement_list), NULL)));
+	(self->priv->labels == NULL ? NULL : (self->priv->labels = (g_object_unref (self->priv->labels), NULL)));
+	(self->priv->statement_list == NULL ? NULL : (self->priv->statement_list = (g_object_unref (self->priv->statement_list), NULL)));
 	klass = VALA_SWITCH_SECTION_CLASS (g_type_class_peek (VALA_TYPE_SWITCH_SECTION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_switch_section_get_type ()
+GType vala_switch_section_get_type (void)
 {
 	static GType vala_switch_section_type_id = 0;
 	if (G_UNLIKELY (vala_switch_section_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaSwitchSectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_switch_section_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSwitchSection), 0, (GInstanceInitFunc) vala_switch_section_init };
-		vala_switch_section_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaSwitchSection", &g_define_type_info, 0);
+		vala_switch_section_type_id = g_type_register_static (VALA_TYPE_BLOCK, "ValaSwitchSection", &g_define_type_info, 0);
 	}
 	return vala_switch_section_type_id;
 }
