@@ -83,6 +83,7 @@ void vala_switch_statement_add_section (ValaSwitchStatement* self, ValaSwitchSec
 {
 	g_return_if_fail (VALA_IS_SWITCH_STATEMENT (self));
 	g_return_if_fail (VALA_IS_SWITCH_SECTION (section));
+	vala_code_node_set_parent_node (VALA_CODE_NODE (section), VALA_CODE_NODE (self));
 	gee_collection_add (GEE_COLLECTION (self->priv->sections), section);
 }
 
@@ -146,10 +147,10 @@ ValaExpression* vala_switch_statement_get_expression (ValaSwitchStatement* self)
 
 void vala_switch_statement_set_expression (ValaSwitchStatement* self, ValaExpression* value)
 {
-	ValaExpression* __temp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_SWITCH_STATEMENT (self));
-	__temp2 = NULL;
-	self->priv->_expression = (__temp2 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), __temp2);
+	_tmp1 = NULL;
+	self->priv->_expression = (_tmp1 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp1);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_expression), VALA_CODE_NODE (self));
 }
 
@@ -162,6 +163,9 @@ static void vala_switch_statement_get_property (GObject * object, guint property
 		case VALA_SWITCH_STATEMENT_EXPRESSION:
 		g_value_set_object (value, vala_switch_statement_get_expression (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -174,6 +178,9 @@ static void vala_switch_statement_set_property (GObject * object, guint property
 		case VALA_SWITCH_STATEMENT_EXPRESSION:
 		vala_switch_statement_set_expression (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
