@@ -1,6 +1,6 @@
 /* valasymbolresolver.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,6 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
+ * 	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #ifndef __VALASYMBOLRESOLVER_H__
@@ -45,9 +46,12 @@
 #include <vala/valadestructor.h>
 #include <vala/valanamespacereference.h>
 #include <vala/valatypereference.h>
+#include <vala/valavariabledeclarator.h>
+#include <vala/valainitializerlist.h>
 #include <vala/valathrowstatement.h>
 #include <vala/valatrystatement.h>
 #include <vala/valacatchclause.h>
+#include <vala/valaarraycreationexpression.h>
 
 G_BEGIN_DECLS
 
