@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valathrowstatement.h"
 #include <vala/valaexpression.h>
@@ -37,8 +35,10 @@ enum  {
 	VALA_THROW_STATEMENT_ERROR_EXPRESSION
 };
 static void vala_throw_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_throw_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_throw_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
 static gpointer vala_throw_statement_parent_class = NULL;
+static ValaStatementIface* vala_throw_statement_vala_statement_parent_iface = NULL;
 static void vala_throw_statement_dispose (GObject * obj);
 
 
@@ -51,16 +51,12 @@ static void vala_throw_statement_dispose (GObject * obj);
  */
 ValaThrowStatement* vala_throw_statement_new (ValaExpression* error_expression, ValaSourceReference* source_reference)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaThrowStatement * self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (error_expression), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	(__params_it->name = "error-expression", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, error_expression), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source_reference), __params_it++);
-	self = g_object_newv (VALA_TYPE_THROW_STATEMENT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_THROW_STATEMENT, 0, NULL);
+	vala_throw_statement_set_error_expression (self, error_expression);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -68,25 +64,31 @@ ValaThrowStatement* vala_throw_statement_new (ValaExpression* error_expression,
 static void vala_throw_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaThrowStatement * self;
-	self = VALA_THROW_STATEMENT (base);
+	self = ((ValaThrowStatement*) base);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_visitor_visit_throw_statement (visitor, self);
+}
+
+
+static void vala_throw_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
+{
+	ValaThrowStatement * self;
+	self = ((ValaThrowStatement*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	vala_code_visitor_visit_begin_throw_statement (visitor, self);
 	if (vala_throw_statement_get_error_expression (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_throw_statement_get_error_expression (self)), visitor);
-		vala_code_visitor_visit_end_full_expression (visitor, vala_throw_statement_get_error_expression (self));
 	}
-	vala_code_visitor_visit_end_throw_statement (visitor, self);
 }
 
 
 static void vala_throw_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
 	ValaThrowStatement * self;
-	self = VALA_THROW_STATEMENT (base);
+	self = ((ValaThrowStatement*) base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_throw_statement_get_error_expression (self)) == old_node) {
-		(vala_throw_statement_set_error_expression (self, VALA_EXPRESSION (new_node)), vala_throw_statement_get_error_expression (self));
+		vala_throw_statement_set_error_expression (self, VALA_EXPRESSION (new_node));
 	}
 }
 
@@ -100,14 +102,14 @@ ValaExpression* vala_throw_statement_get_error_expression (ValaThrowStatement* s
 
 void vala_throw_statement_set_error_expression (ValaThrowStatement* self, ValaExpression* value)
 {
-	ValaExpression* __temp2;
-	ValaExpression* __temp1;
+	ValaExpression* _tmp2;
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_THROW_STATEMENT (self));
-	__temp2 = NULL;
-	__temp1 = NULL;
-	self->priv->_error_expression = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_error_expression == NULL ? NULL : (self->priv->_error_expression = (g_object_unref (self->priv->_error_expression), NULL))), __temp2);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_error_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_error_expression == NULL ? NULL : (self->priv->_error_expression = (g_object_unref (self->priv->_error_expression), NULL))), _tmp2);
 	if (self->priv->_error_expression != NULL) {
-		(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_error_expression), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_error_expression)));
+		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_error_expression), VALA_CODE_NODE (self));
 	}
 }
 
@@ -120,6 +122,9 @@ static void vala_throw_statement_get_property (GObject * object, guint property_
 		case VALA_THROW_STATEMENT_ERROR_EXPRESSION:
 		g_value_set_object (value, vala_throw_statement_get_error_expression (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -132,6 +137,9 @@ static void vala_throw_statement_set_property (GObject * object, guint property_
 		case VALA_THROW_STATEMENT_ERROR_EXPRESSION:
 		vala_throw_statement_set_error_expression (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -144,11 +152,18 @@ static void vala_throw_statement_class_init (ValaThrowStatementClass * klass)
 	G_OBJECT_CLASS (klass)->set_property = vala_throw_statement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_throw_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_throw_statement_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_throw_statement_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace = vala_throw_statement_real_replace;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_THROW_STATEMENT_ERROR_EXPRESSION, g_param_spec_object ("error-expression", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
+static void vala_throw_statement_vala_statement_interface_init (ValaStatementIface * iface)
+{
+	vala_throw_statement_vala_statement_parent_iface = g_type_interface_peek_parent (iface);
+}
+
+
 static void vala_throw_statement_init (ValaThrowStatement * self)
 {
 	self->priv = VALA_THROW_STATEMENT_GET_PRIVATE (self);
@@ -168,12 +183,14 @@ static void vala_throw_statement_dispose (GObject * obj)
 }
 
 
-GType vala_throw_statement_get_type ()
+GType vala_throw_statement_get_type (void)
 {
 	static GType vala_throw_statement_type_id = 0;
 	if (G_UNLIKELY (vala_throw_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaThrowStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_throw_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaThrowStatement), 0, (GInstanceInitFunc) vala_throw_statement_init };
-		vala_throw_statement_type_id = g_type_register_static (VALA_TYPE_STATEMENT, "ValaThrowStatement", &g_define_type_info, 0);
+		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_throw_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
+		vala_throw_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaThrowStatement", &g_define_type_info, 0);
+		g_type_add_interface_static (vala_throw_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
 	}
 	return vala_throw_statement_type_id;
 }
