@@ -137,10 +137,10 @@ ValaBlock* vala_try_statement_get_body (ValaTryStatement* self)
 
 void vala_try_statement_set_body (ValaTryStatement* self, ValaBlock* value)
 {
-	ValaBlock* __temp2;
+	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_TRY_STATEMENT (self));
-	__temp2 = NULL;
-	self->priv->_body = (__temp2 = g_object_ref (value), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp2);
+	_tmp1 = NULL;
+	self->priv->_body = (_tmp1 = g_object_ref (value), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp1);
 }
 
 
@@ -153,12 +153,12 @@ ValaBlock* vala_try_statement_get_finally_body (ValaTryStatement* self)
 
 void vala_try_statement_set_finally_body (ValaTryStatement* self, ValaBlock* value)
 {
-	ValaBlock* __temp5;
-	ValaBlock* __temp4;
+	ValaBlock* _tmp2;
+	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_TRY_STATEMENT (self));
-	__temp5 = NULL;
-	__temp4 = NULL;
-	self->priv->_finally_body = (__temp5 = (__temp4 = value, (__temp4 == NULL ? NULL : g_object_ref (__temp4))), (self->priv->_finally_body == NULL ? NULL : (self->priv->_finally_body = (g_object_unref (self->priv->_finally_body), NULL))), __temp5);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_finally_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_finally_body == NULL ? NULL : (self->priv->_finally_body = (g_object_unref (self->priv->_finally_body), NULL))), _tmp2);
 }
 
 
@@ -173,6 +173,9 @@ static void vala_try_statement_get_property (GObject * object, guint property_id
 		case VALA_TRY_STATEMENT_FINALLY_BODY:
 		g_value_set_object (value, vala_try_statement_get_finally_body (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
@@ -188,6 +191,9 @@ static void vala_try_statement_set_property (GObject * object, guint property_id
 		case VALA_TRY_STATEMENT_FINALLY_BODY:
 		vala_try_statement_set_finally_body (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
