@@ -22,12 +22,12 @@
 
 #ifndef __VALATYPEPARAMETER_H__
 #define __VALATYPEPARAMETER_H__
-typedef struct _ValaTypeParameterPrivate ValaTypeParameterPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <vala/valasymbol.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -40,25 +40,24 @@ G_BEGIN_DECLS
 #define VALA_IS_TYPE_PARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPE_PARAMETER))
 #define VALA_TYPE_PARAMETER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPE_PARAMETER, ValaTypeParameterClass))
 
+typedef struct _ValaTypeParameterPrivate ValaTypeParameterPrivate;
 
 /**
  * Represents a generic type parameter in the source code.
  */
 struct _ValaTypeParameter {
-	ValaCodeNode parent;
+	ValaSymbol parent;
 	ValaTypeParameterPrivate * priv;
 	ValaDataType* type;
 };
 struct _ValaTypeParameterClass {
-	ValaCodeNodeClass parent;
+	ValaSymbolClass parent;
 };
 
 ValaTypeParameter* vala_type_parameter_new (const char* _name, ValaSourceReference* source);
 ValaArray* vala_type_parameter_get_array (ValaTypeParameter* self, gint rank);
 gboolean vala_type_parameter_equals (ValaTypeParameter* self, ValaTypeParameter* param2);
-char* vala_type_parameter_get_name (ValaTypeParameter* self);
-void vala_type_parameter_set_name (ValaTypeParameter* self, const char* value);
-GType vala_type_parameter_get_type ();
+GType vala_type_parameter_get_type (void);
 
 G_END_DECLS
 
